/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.util;

import java.lang.reflect.Method;
import java.rmi.AccessException;
import java.security.Principal;
import java.sql.Timestamp;
import java.util.HashMap;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.Set;

import javax.naming.CommunicationException;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.security.auth.Subject;
import javax.security.auth.login.AppConfigurationEntry;
import javax.security.auth.login.Configuration;
import javax.security.auth.login.LoginContext;
import javax.security.auth.login.LoginException;

import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.jface.action.IContributionItem;
import org.eclipse.jface.action.IStatusLineManager;
import org.eclipse.jface.dialogs.ErrorDialog;
import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.IActionBars;
import org.eclipse.ui.IWorkbench;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.internal.WorkbenchWindow;
import org.eclipse.ui.internal.util.StatusLineContributionItem;
import org.jboss.naming.NamingContextFactory;
import org.jboss.security.auth.callback.UsernamePasswordHandler;
import org.jnp.interfaces.NamingContext;

import com.clustercontrol.ClusterControlPlugin;
import com.clustercontrol.accesscontrol.dialog.LoginDialog;
import com.clustercontrol.accesscontrol.ejb.session.AccessCheck;
import com.clustercontrol.accesscontrol.ejb.session.AccessCheckHome;
import com.clustercontrol.accesscontrol.etc.action.LogoutAction;
import com.clustercontrol.accesscontrol.util.LocalSession;
import com.clustercontrol.preference.ClusterControlCorePreferencePage;

/**
 * ログインマネージャクラス<BR>
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class LoginManager {
    public static final String KEY_EJB_URL = "ejbUrl";
    public static final String VALUE_EJB_URL = "jnp://localhost:1099";
    public static final String KEY_EJB_UID = "ejbUid";
    public static final String VALUE_EJB_UID = "hinemos";
    public static final String KEY_INTERVAL = "managerPollingInterval";
    public static final int VALUE_INTERVAL = 60;
    
    public static final String USER_OBJECT_ID = "com.clustercontrol.accesscontrol.user";
    public static final String URL_OBJECT_ID = "com.clustercontrol.accesscontrol.url";
    
    public static final String ACTION_SET_ID    = "com.clustercontrol.accesscontrol.ActionSet";
    public static final String ACTION_ID_LOGIN  = "com.clustercontrol.accesscontrol.etc.action.LoginAction";
    public static final String ACTION_ID_LOGOUT = "com.clustercontrol.accesscontrol.etc.action.LogoutAction";
    
    private static LoginManager m_instance = null;
    private NamingContext m_namingcontext = null;
    private LoginContext m_loginContext = null;
    private String m_url = null;
    private String m_uid = null;
    private String m_password = null;

    private Display m_dislpay = null;
    private IStatusLineManager m_lineManager = null; 
    
	/** ダイアログ表示制御用 */
	private static boolean openInformation = false;
	
    /**
     * このオブジェクトを取得します。 シングルトン
     * 
     * @return LoginManager ログインマネージャ
     * 
	 * @version 2.0.0
	 * @since 2.0.0
     */
    public static LoginManager getContextManager() {
        if (m_instance == null) {
            m_instance = new LoginManager();
        }
        return m_instance;
    }

    /**
     * コンストラクタ
     * 
   	 * @version 2.0.0
	 * @since 2.0.0
     */
    private LoginManager() {
        try {
           Configuration.setConfiguration(new HinemosClientConfig());
        } catch(Exception e) {
        }
    }
        
    /**
     * ログイン(接続先URLあり)
     * 
     * @param uid
     * @param password
     * @throws NamingException
     * @throws LoginException
     * 
	 * @version 2.0.0
	 * @since 2.0.0
     */
    public synchronized void login(String uid, String password,String url) throws Exception {
    	//ログアウト
    	logout();
    	
    	m_uid = uid;
    	m_password = password;
    	
    	//NamingContext取得
    	m_namingcontext = getContext(url);
    	
    	try {
        	//ログインチェック
        	AccessCheckHome home = (AccessCheckHome)m_namingcontext.lookup(AccessCheckHome.JNDI_NAME);
        	
			AccessCheck accessCheck = home.create();
			
			accessCheck.checkLogin();
			
			// ステータスバーへユーザIDを登録
			IWorkbench workbench = PlatformUI.getWorkbench();
			WorkbenchWindow workbenchWindow = (WorkbenchWindow)workbench.getActiveWorkbenchWindow();
			IActionBars bars = workbenchWindow.getActionBars();
			m_lineManager = bars.getStatusLineManager();
			m_dislpay = workbench.getDisplay();

			StatusLineContributionItem statusLine = new StatusLineContributionItem(USER_OBJECT_ID,100);
			statusLine.setText(Messages.getString("hinemos.user") + " : " + m_uid + "     " 
					              + Messages.getString("connection.url") + " : " + m_url   );
			
			m_lineManager.add(statusLine);
			m_lineManager.update(true);
			
			
			//UIDと接続先をプレファレンスに書き戻す。			
	        //セッションに接続先URLを格納
			
	        IPreferenceStore store = ClusterControlPlugin.getDefault()
                      .getPreferenceStore();
	        store.setValue(ClusterControlCorePreferencePage.EJB_URL,url);
	        store.setValue(ClusterControlCorePreferencePage.EJB_UID,uid);
	        
	        
			// クライアント側で保持するローカル情報の削除処理
			LocalSession.getLocalSession().clearSessionData();
			// マネージャの死活監視開始
			LocalSession.getLocalSession().startChecktask(getInterval());
			
		} catch (Exception e) {
			logout();
			throw e;
		}
    }
    
    
    /**
     * ログアウト
     * 
     * @throws NamingException
     * 
	 * @version 2.0.0
	 * @since 2.0.0
     */
    public synchronized void logout() throws NamingException {
    	if(m_loginContext instanceof LoginContext){
    		try {
				m_loginContext.logout();
				
				m_uid = null;
				
				// ステータスバーからユーザIDを削除
				if(m_lineManager != null){
					IContributionItem item = m_lineManager.find(USER_OBJECT_ID);
					m_lineManager.remove(item);
					m_lineManager.update(true);
				}
				
				LocalSession.getLocalSession().clearSessionData();
				LocalSession.getLocalSession().stopChecktask();

			} catch (LoginException e) {
				e.printStackTrace();
			}
    	}
		m_loginContext = null;
		m_namingcontext = null;
    }
    
    /**
     * ログインチェック
     * 
     * @return
     * 
	 * @version 2.0.0
	 * @since 2.0.0
     */
    public boolean isLogin() {
    	boolean isLogin = false;
    	
    	if(m_loginContext instanceof LoginContext){
			isLogin = true;
			
			Subject subject = m_loginContext.getSubject();
			Set pri = subject.getPrincipals();
			
			// System.out.println("getPrincipals size = " + pri.size());
			Iterator itr = pri.iterator();
			while (itr.hasNext()) {
				Principal principal = (Principal) itr.next();
				//System.out.println("principal = " + principal.getName());
				
			}
    	}
    	
    	return isLogin;
    }
    
    /**
     * RepositoryCollectorを取得します。
     * 
     * @return RepositoryCollector
     * 
     * @version 2.0.0
	 * @since 2.0.0
     */
    public synchronized NamingContext getNamingContext() throws NamingException {
    	if(!isLogin()){
    		
			Shell shell = PlatformUI.getWorkbench().getActiveWorkbenchWindow().getShell();
			
    		//ログインダイアログ表示
            LoginDialog dialog = new LoginDialog(shell);
            
            //ダイアログ表示
            if (dialog.open() == IDialogConstants.OK_ID) {
            	try {
            		
    			//	login(dialog.getUserid(), dialog.getPassword());
            		login(dialog.getUserid(), dialog.getPassword(),dialog.getUrl());
            		
    	            // ログイン成功ダイアログを生成
                	MessageDialog.openInformation(
                			null, 
                			Messages.getString("successful"), 
                			Messages.getString("message.accesscontrol.5"));
    			} catch (CommunicationException e) {
                    // 接続失敗ダイアログを生成
                	Status status = new Status(
                			IStatus.ERROR,
                			ClusterControlPlugin.getPluginId(),
                			IStatus.OK,
                			Messages.getString("message.accesscontrol.22"), 
                			e);

                	ErrorDialog.openError(
                			null, 
                			Messages.getString("failed"),
							Messages.getString("message.accesscontrol.21"),
							status);
				} catch (AccessException e) {
                    // ログイン失敗ダイアログを生成
                	MessageDialog.openWarning(
                			null, 
                			Messages.getString("failed"), 
                			Messages.getString("message.accesscontrol.6"));
    			} catch (Exception e) {
                    // 予期せぬエラーダイアログを生成
                	Status status = new Status(
                			IStatus.ERROR,
                			ClusterControlPlugin.getPluginId(),
                			IStatus.OK,
                			Messages.getString("message.accesscontrol.23"), 
                			e);

                	ErrorDialog.openError(
                			null, 
                			Messages.getString("failed"), 
                			Messages.getString("message.accesscontrol.6"),
                			status
                			);
    			}
            }
    	}
    	return m_namingcontext;
    }

    /**
     * NamingContextを取得します。
     * 
     * @return
     * @throws NamingException
     * @throws LoginException
     * 
 	 * @version 2.0.0
	 * @since 2.0.0
     */
    @SuppressWarnings("unchecked")
	private NamingContext getContext() throws NamingException, LoginException {
        //接続先URL取得
        String url = getUrl();

        return getContext(url); 
    }
    
    
    /**
     * NamingContextを取得します。
     * 
     * @return
     * @throws NamingException
     * @throws LoginException
     * 
 	 * @version 2.0.0
	 * @since 2.0.0
     */
    @SuppressWarnings("unchecked")
	private NamingContext getContext(String url) throws NamingException, LoginException {
        //接続先URL取得
        m_url = url;

        Hashtable props = new Hashtable();
        props.put(InitialContext.PROVIDER_URL, m_url);
        
    	UsernamePasswordHandler handler = new UsernamePasswordHandler(m_uid, m_password.toCharArray());
		m_loginContext = new LoginContext("hinemosClient", handler);
		m_loginContext.login();
		
        NamingContextFactory ncf = new NamingContextFactory();
        NamingContext namingContext = (NamingContext) ncf
                .getInitialContext(props);
        
        return namingContext;
    }
    
    
    
    /**
     * 接続先URLを取得します。
     * 
     * @return String 接続先URL
  	 * @version 2.0.0
	 * @since 2.0.0
     */
    private String getUrl() {

        //リソースストアから接続先URLを取得
        IPreferenceStore store = ClusterControlPlugin.getDefault()
                .getPreferenceStore();
        String url = store.getString(KEY_EJB_URL);
        if (url.compareTo("") == 0) {
            url = VALUE_EJB_URL;
        }

        return url;
    }
    
    /**
     * 
     * @return
     */
    public static int getInterval() {

    	//リソースストアから接続先の死活間隔を取得
        IPreferenceStore store = ClusterControlPlugin.getDefault()
                .getPreferenceStore();
        int interval = store.getInt(KEY_INTERVAL);

        //System.out.println("LoginManager.getInterval() interval = " + interval);
        return interval;
    }
    
    public String getUserId() {
    	return m_uid;
    }
    
    /**
	 * HinemosClient用のコンフィギュレーションクラス
	 * 
	 * @version 2.0.0
	 * @since 2.0.0
     */
    class HinemosClientConfig extends Configuration
    {
    	/* (non-Javadoc)
    	 * @see javax.security.auth.login.Configuration#refresh()
    	 */
    	@Override
		public void refresh() {
    		
    	}
    	
    	/* (non-Javadoc)
    	 * @see javax.security.auth.login.Configuration#getAppConfigurationEntry(java.lang.String)
    	 */
    	@Override
		public AppConfigurationEntry[] getAppConfigurationEntry(String name) {
    		AppConfigurationEntry[] entry = null;
    		try {
    			Class[] parameterTypes = {};
    			Method m = getClass().getDeclaredMethod(name, parameterTypes);
    			Object[] args = {};
    			entry = (AppConfigurationEntry[]) m.invoke(this, args);
    		} catch(Exception e) {
    		}
    		return entry;
    	}
    	
    	/**
    	 * Hinemos Client Configuration
    	 * 
    	 * http://community.jboss.org/wiki/ClientLoginModule
    	 * 
    	 * @return
    	 */
    	@SuppressWarnings("unchecked")
    	AppConfigurationEntry[] hinemosClient() {
    		String name = "org.jboss.security.ClientLoginModule";
    		HashMap options = new HashMap();
    		options.put("multi-threaded", "false"); // login credential is global variables (all thread) 
    		options.put("restore-login-identity", "true");
    		AppConfigurationEntry ace = new AppConfigurationEntry(name,
    				AppConfigurationEntry.LoginModuleControlFlag.REQUIRED, options);
    		AppConfigurationEntry[] entry = {ace};
    		return entry;
    	}
    }
    
    /**
     * LocalSession.SessionCheckTaskからのダイアログ&ログアウト処理を受け付けるスレッド生成用メソッド
     * @param r
     * @return
     */
	private boolean checkAsyncExec(Runnable r){
		 
		if(m_dislpay == null){
			//System.out.println("LoginManager.checkAsyncExec() m_dislpay is null");
			return false;
		}
		
		if(!m_dislpay.isDisposed()){
			//System.out.println("LoginManager.checkAsyncExec() is true");
			m_dislpay.asyncExec(r);
			return true;
		}
		else{
			//System.out.println("LoginManager.checkAsyncExec() is false");
			return false;
		}
	}
	
	
	/**
	 * マネージャ切断をダイアログ表示してログアウト処理を行う
	 */
	public void disconnectManager(){
		checkAsyncExec(new Runnable(){public void run() {
			// ログアウトダイアログの表示
			//System.out.println("LoginManager.disconnectManager() start openInformation = " + openInformation);
    		if(!openInformation){
    			//System.out.println("LoginManager.disconnectManager() OpenDialog");
    			
    			openInformation = true;
    			
    			// ダイアログ表示
    			String[] args = {new Timestamp(System.currentTimeMillis()).toString()};
    			MessageDialog.openError(
    					null, 
    					Messages.getString("failed"), 
    					Messages.getString("message.force.disconnect",args));
    			
            	// ログアウト処理
            	(new LogoutAction()).runLogout();
            	
    			openInformation = false;
    		}else{
    			//System.out.println("LoginManager.disconnectManager() Not OpenDialog");    			
    		}
			//System.out.println("LoginManager.disconnectManager() stop openInformation = " + openInformation);
		}}
		);
		
	}
	
	/**
	 * 定期的な監視を再実行
	 * @param interval 間隔(分)
	 */
	public static void restartChecktask(int interval){
		//System.out.println("LoginManager.restartChecktask() interval = " + interval);
		LocalSession.getLocalSession().restartChecktask(interval);
	}
}