/*

Copyright (C) 2006 NTT DATA Corporation

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.

 */

package com.clustercontrol.accesscontrol.dialog;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.TableTree;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.graphics.Point;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Shell;

import com.clustercontrol.accesscontrol.action.AddUserProperty;
import com.clustercontrol.accesscontrol.action.GetUserProperty;
import com.clustercontrol.accesscontrol.action.ModifyUserProperty;
import com.clustercontrol.accesscontrol.bean.RoleConstant;
import com.clustercontrol.accesscontrol.bean.UserConstant;
import com.clustercontrol.accesscontrol.bean.UserRoleList;
import com.clustercontrol.accesscontrol.factory.UserProperty;

import com.clustercontrol.bean.Property;
import com.clustercontrol.bean.PropertyConstant;
import com.clustercontrol.bean.PropertyTreeItem;
import com.clustercontrol.composite.PropertySheet;
import com.clustercontrol.dialog.CommonDialog;
import com.clustercontrol.dialog.ValidateResult;
import com.clustercontrol.util.Messages;
import com.clustercontrol.util.PropertyUtil;

/**
 * アクセス[ユーザの作成・変更]ダイアログクラスです。
 * 
 * @version 2.2.0
 * @since 2.0.0
 */
public class UserDialog extends CommonDialog {
	/** ユーザID */
	private String uid = ""; //$NON-NLS-1$

	/** 変更用ダイアログ判別フラグ */
	private boolean isModifyDialog = false;

	/** ユーザ用プロパティシート */
	private PropertySheet propertySheet = null;


	private Button buttonRead = null;
	private Button buttonWrite = null;
	private Button buttonExec = null;
	private Button buttonAll = null;
	private Button buttonClear = null;

	private final UserRoleList _userRoleList;

	/**
	 * コンストラクタ
	 * 
	 * @param parent 親シェル
	 * @param uid ユーザID
	 * @param isModifyDialog 変更用ダイアログとして利用する場合は、true
	 */
	public UserDialog(Shell parent, String uid, boolean isModifyDialog) {
		super(parent);

		this.uid = uid;
		this.isModifyDialog = isModifyDialog;
		
		_userRoleList = new GetUserProperty().getUserRoleList();
	}

	/**
	 * ダイアログの初期サイズを返します。
	 * 
	 * @return 初期サイズ
	 * 
	 * @see org.eclipse.jface.window.Window#getInitialSize()
	 */
	@Override
	protected Point getInitialSize() {
		return new Point(500, 600);
	}

	/**
	 * ダイアログエリアを生成します。
	 * 
	 * @param parent 親コンポジット
	 * 
	 * @see com.clustercontrol.dialog.CommonDialog#customizeDialog(org.eclipse.swt.widgets.Composite)
	 */
	@Override
	protected void customizeDialog(Composite parent) {
		Shell shell = this.getShell();

		// タイトル
		shell.setText(Messages
				.getString("dialog.accesscontrol.user.create.modify")); //$NON-NLS-1$

		// レイアウト
		GridLayout layout = new GridLayout(1, true);
		layout.marginWidth = 10;
		layout.marginHeight = 10;
		layout.numColumns = 8;
		parent.setLayout(layout);

		/*
		 * 属性プロパティシート
		 */

		// ラベル
		Label label = new Label(parent, SWT.LEFT);
		GridData gridData = new GridData();
		gridData.horizontalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		gridData.horizontalSpan = 6;
		label.setLayoutData(gridData);
		label.setText(Messages.getString("attribute") + " : "); //$NON-NLS-1$ //$NON-NLS-2$


		// プロパティシート
		TableTree table = new TableTree(parent, SWT.H_SCROLL | SWT.V_SCROLL
				| SWT.FULL_SELECTION | SWT.MULTI | SWT.BORDER);
		gridData = new GridData();
		gridData.horizontalAlignment = GridData.FILL;
		gridData.verticalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		gridData.grabExcessVerticalSpace = true;
		gridData.horizontalSpan = 6;
		table.setLayoutData(gridData);

		this.propertySheet = new PropertySheet(table);

		// プロパティ取得及び設定
		Property property = null;
		if (this.isModifyDialog) {
			property = new GetUserProperty().getProperty(this.uid,
					PropertyConstant.MODE_MODIFY);
		} else {
			property = new GetUserProperty().getProperty(this.uid,
					PropertyConstant.MODE_ADD);
		}
		this.propertySheet.setInput(property);
		this.propertySheet.expandAll();




		/*
		 * 操作ボタン
		 */

		 Composite composite = new Composite(parent, SWT.NONE);
		layout = new GridLayout(1, true);
		layout.numColumns = 1;
		composite.setLayout(layout);
		gridData = new GridData();
		gridData.horizontalAlignment = GridData.FILL;
		gridData.verticalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		gridData.grabExcessVerticalSpace = true;
		gridData.horizontalSpan = 2;
		composite.setLayoutData(gridData);


		// すべてボタン
		@SuppressWarnings("unused") 
		Label dummy = new Label(composite, SWT.NONE);
		this.buttonAll = this
		.createButton(composite, Messages.getString("UserDialog.all_prerogative")); //$NON-NLS-1$
		this.buttonAll.addSelectionListener(new SelectionAdapter() {
			@Override
			public void widgetSelected(SelectionEvent e) {


				Property prop = getInputData(); 
				//データを取得します。
				Object[] items =  prop.getChildren();            
				for(int j = 0 ; j < items.length; j++){
					//アクセス権のプロパティを探します。
					if(((PropertyTreeItem)items[j]).getID().equals("access")){ //$NON-NLS-1$

						//アクセス権の部分を取り出します。
						items  = (((Property)items[j]).getChildren());
						//各権限がにチェックを入れます。
						for (int k = 0 ; k <items.length ;  k++){
							((Property)items[k]).setValue(true);
						}	  
						//アクセス権を探す処理をExit
						break;
					}

				}
				propertySheet.setInput(prop);
				propertySheet.expandAll();

			}
		});

		// すべての参照権限

		dummy = new Label(composite, SWT.NONE);
		this.buttonRead = this
		.createButton(composite, Messages.getString("UserDialog.read_prerogative")); //$NON-NLS-1$
		this.buttonRead.addSelectionListener(new SelectionAdapter() {
			@Override
			public void widgetSelected(SelectionEvent e) {

				Property prop = getInputData(); 
				//データを取得します。(一番上位の項目)
				Object[] items =  prop.getChildren();


				List<String> readRoles = _userRoleList.getReadRoles();


				for(int j = 0 ; j < items.length; j++){
					//アクセス権のプロパティを探します。
					if(((PropertyTreeItem)items[j]).getID().equals("access")){ //$NON-NLS-1$
						//アクセス権の部分を取り出します。
						items  = (((Property)items[j]).getChildren());
						//各権限がにチェックを入れます。
						for (int k = 0 ; k <items.length ;  k++){
							for (int i= 0 ; i < readRoles.size(); i++){
								if(((PropertyTreeItem)items[k]).getID().equals(readRoles.get(i))){
									((Property)items[k]).setValue(true);	
									break;
								}
							}	  
						}
						//アクセス権を探す処理をExit
						break;
					}
				}
				propertySheet.setInput(prop);
				propertySheet.expandAll();


			}
		});

		// すべての設定権限

		dummy = new Label(composite, SWT.NONE);
		this.buttonWrite = this.createButton(composite, Messages.getString("UserDialog.write_prerogative")); //$NON-NLS-1$
		this.buttonWrite.addSelectionListener(new SelectionAdapter() {
			@Override
			public void widgetSelected(SelectionEvent e) {

				Property prop = getInputData(); 
				//データを取得します。(一番上位の項目)
				Object[] items =  prop.getChildren();


				List<String> writeRoles= _userRoleList.getWriteRoles();


				for(int j = 0 ; j < items.length; j++){
					//アクセス権のプロパティを探します。
					if(((PropertyTreeItem)items[j]).getID().equals("access")){ //$NON-NLS-1$
						//アクセス権の部分を取り出します。
						items  = (((Property)items[j]).getChildren());
						//各権限がにチェックを入れます。
						for (int k = 0 ; k <items.length ;  k++){
							for (int i= 0 ; i < writeRoles.size(); i++){
								if(((PropertyTreeItem)items[k]).getID().equals(writeRoles.get(i))){
									((Property)items[k]).setValue(true);	
									break;
								}
							}	  
						}
						//アクセス権を探す処理をExit
						break;
					}
				}
				propertySheet.setInput(prop);
				propertySheet.expandAll();


			}
		});

		// 実行権限ボタン
		dummy = new Label(composite, SWT.NONE);
		this.buttonExec = this.createButton(composite, Messages.getString("UserDialog.exec_prerogative")); //$NON-NLS-1$
		this.buttonExec.addSelectionListener(new SelectionAdapter() {
			@Override
			public void widgetSelected(SelectionEvent e) {

				Property prop = getInputData(); 
				//データを取得します。(一番上位の項目)
				Object[] items =  prop.getChildren();


				List<String> execRoles= _userRoleList.getExecRoles();


				for(int j = 0 ; j < items.length; j++){
					//アクセス権のプロパティを探します。
					if(((PropertyTreeItem)items[j]).getID().equals(UserConstant.ACCESS)){
						//アクセス権の部分を取り出します。
						items  = (((Property)items[j]).getChildren());
						//各権限にチェックを入れます。
						for (int k = 0 ; k <items.length ;  k++){
							for (int i= 0 ; i < execRoles.size(); i++){
								if(((PropertyTreeItem)items[k]).getID().equals(execRoles.get(i))){
									((Property)items[k]).setValue(true);	
									break;
								}
							}	  
						}
						//アクセス権を探す処理をExit
						break;
					}
				}
				propertySheet.setInput(prop);
				propertySheet.expandAll();



			}
		});

		// クリアボタン
		dummy = new Label(composite, SWT.NONE);
		this.buttonClear = this.createButton(composite, Messages.getString("UserDialog.clear")); //$NON-NLS-1$
		this.buttonClear.addSelectionListener(new SelectionAdapter() {
			@Override
			public void widgetSelected(SelectionEvent e) {
				Property prop = getInputData(); 
				//データを取得します。
				Object[] items =  prop.getChildren();            
				for(int j = 0 ; j < items.length; j++){
					//アクセス権のプロパティを探します。
					if(((PropertyTreeItem)items[j]).getID().equals("access")){ //$NON-NLS-1$
						//アクセス権の部分を取り出します。
						items  = (((Property)items[j]).getChildren());
						//各権限がにチェックを入れます。
						for (int k = 0 ; k <items.length ;  k++){
							if(!((PropertyTreeItem)items[k]).getID().equals(RoleConstant.REPOSITORY_READ)){
								((Property)items[k]).setValue(false);
							}
						}	  
						//アクセス権を探す処理をExit
						break;
					}

				}
				propertySheet.setInput(prop);
				propertySheet.expandAll();
			}
		});

		// ラインを引く
		Label line = new Label(parent, SWT.SEPARATOR | SWT.HORIZONTAL);
		gridData = new GridData();
		gridData.horizontalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		gridData.horizontalSpan = 8;
		line.setLayoutData(gridData);




		// 画面中央に
		Display display = shell.getDisplay();
		shell.setLocation((display.getBounds().width - shell.getSize().x) / 2,
				(display.getBounds().height - shell.getSize().y) / 2);


	}

	/**
	 * 入力値チェックをします。
	 * 
	 * @return 検証結果
	 * 
	 * @see com.clustercontrol.dialog.CommonDialog#validate()
	 */
	@Override
	protected ValidateResult validate() {
		ValidateResult result = null;

		//ユーザIDの入力チェック
		ArrayList values = PropertyUtil.getPropertyValue(getInputData(), UserConstant.UID);
		String value = (String)values.get(0);
		if(value.compareTo("") == 0){ //$NON-NLS-1$
			result = new ValidateResult();
			result.setID(Messages.getString("message.hinemos.1")); //$NON-NLS-1$
			result.setMessage(Messages.getString("message.accesscontrol.1")); //$NON-NLS-1$
			result.setValid(false);
			return result;
		}

		return result;
	}

	/**
	 * 入力値をマネージャに登録します。
	 * 
	 * @return true：正常、false：異常
	 * 
	 * @see com.clustercontrol.dialog.CommonDialog#action()
	 */
	@Override
	protected boolean action() {
		boolean result = false;

		Property property = this.getInputData();
		if(property != null){
			if(!this.isModifyDialog){
				// 作成の場合
				result = new AddUserProperty().add(property);
			}
			else{
				// 変更の場合
				result = new ModifyUserProperty().edit(property);
			}
		}

		return result;
	}

	/**
	 * 変更用ダイアログなのかを返します。
	 * 
	 * @return 変更用ダイアログの場合、true
	 */
	public boolean isModifyDialog() {
		return this.isModifyDialog;
	}

	/**
	 * ユーザ用プロパティを返します。
	 * 
	 * @return ユーザ用プロパティ
	 */
	public Property getInputData() {
		return (Property) this.propertySheet.getInput();
	}

	/**
	 * ユーザ用プロパティを設定します。
	 * 
	 * @param property ユーザ用プロパティ
	 */
	public void setInputData(Property property) {
		propertySheet.setInput(property);
	}

	/**
	 * ユーザIDを返します。
	 * 
	 * @return ユーザID
	 */
	public String getUid() {
		return this.uid;
	}

	/**
	 * ＯＫボタンのテキストを返します。
	 * 
	 * @return ＯＫボタンのテキスト
	 */
	@Override
	protected String getOkButtonText() {
		if (isModifyDialog()) {
			return Messages.getString("modify"); //$NON-NLS-1$
		} else {
			return Messages.getString("register"); //$NON-NLS-1$
		}
	}

	/**
	 * キャンセルボタンのテキストを返します。
	 * 
	 * @return キャンセルボタンのテキスト
	 */
	@Override
	protected String getCancelButtonText() {
		return Messages.getString("cancel"); //$NON-NLS-1$
	}

	/**
	 * OKボタンを押されたときの処理
	 * 
	 * @see org.eclipse.jface.dialogs.Dialog#okPressed()
	 */
	@Override
	protected void okPressed() {
		ValidateResult result = this.validate();

		if (result == null || result.isValid()) {

			//変更時
			if(this.isModifyDialog){
				super.okPressed();
			}
			//作成時
			else{
				this.action();
			}

		} else {
			this.displayError(result);
		}
	}


	/**
	 * 共通のボタンを生成します。
	 * 
	 * @param parent
	 *            親のコンポジット
	 * @param label
	 *            ボタンのラベル
	 * @return 生成されたボタン
	 */
	private Button createButton(Composite parent, String label) {
		Button button = new Button(parent, SWT.NONE);

		GridData gridData = new GridData(GridData.FILL_HORIZONTAL);
		gridData.horizontalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		button.setLayoutData(gridData);

		button.setText(label);

		return button;
	}

}