/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.hinemosagent.action;

import java.rmi.AccessException;
import java.rmi.RemoteException;

import javax.transaction.InvalidTransactionException;

import org.eclipse.jface.dialogs.MessageDialog;

import com.clustercontrol.HinemosUnknownException;
import com.clustercontrol.MonitorDuplicateException;
import com.clustercontrol.hinemosagent.ejb.session.MonitorAgentController;
import com.clustercontrol.hinemosagent.util.EjbConnectionManager;
import com.clustercontrol.monitor.run.bean.MonitorInfo;
import com.clustercontrol.util.Messages;

/**
 * Hinemos Agent監視情報をマネージャに登録するクラス<BR>
 * 
 * @version 2.2.0
 * @since 2.0.0
 */
public class AddAgent {

    /**
     * Hinemos Agent監視情報を追加します。<BR>
     * 
     * @param info Hinemos Agent監視情報
     * @return 登録に成功した場合、true
     */
    public boolean add(MonitorInfo info) {
    	
    	MonitorAgentController agent = EjbConnectionManager.getConnectionManager().getAgentController();

        boolean result = false;
        String[] args = { info.getMonitorId() };
        try {
        	result = agent.addAgent(info);
        } catch (InvalidTransactionException e) {
		} catch (IllegalStateException e) {
		} catch (RemoteException e) {
			if(e instanceof AccessException){
				// アクセス権なしの場合、エラーダイアログを表示する
	            MessageDialog.openInformation(null, Messages.getString("message"),
	                    Messages.getString("message.accesscontrol.16"));
			}
		} catch (MonitorDuplicateException e) {
			// 監視項目IDが重複している場合、エラーダイアログを表示する
	        MessageDialog.openInformation(
	        		null, 
	        		Messages.getString("message"),
	        		Messages.getString("message.monitor.53", args));
	        	return result;
		} catch (HinemosUnknownException e) {
		}
		
		if(result){
        	MessageDialog.openInformation(
        			null, 
        			Messages.getString("successful"), 
        			Messages.getString("message.monitor.33", args));
		}
		else{
        	MessageDialog.openError(
        			null, 
        			Messages.getString("failed"), 
        			Messages.getString("message.monitor.34", args));
		}
    	
    	return result;
    }
}