/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.http;

import java.io.StringWriter;
import java.text.MessageFormat;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.ui.plugin.AbstractUIPlugin;
import org.osgi.framework.Bundle;
import org.osgi.framework.BundleContext;

/**
 * HTTP監視機能プラグインクラス<BR>
 * 
 * @version 2.1.0
 * @since 2.1.0
 */
public class HttpPlugin extends AbstractUIPlugin {

    // ----- static フィールド ----- //

    /** プラグインのインスタンス */
	private static HttpPlugin plugin;
	
    //  ----- static メソッド ----- //
    
    /**
     * 自身のインスタンスを返します。
     * 
     * @return 自身のインスタンス
     */
	public static HttpPlugin getDefault() {
		return plugin;
	}

    /**
     * プラグインのリソースバンドルより、指定した文字列を返します。
     * 
     * @param key
     *            キー文字列
     * @return 指定した文字列。リソースバンドルが無い場合、もしくは指定した文字列 が存在しない場合は、keyを返します。
     */
    public static String getResourceString(String key) {
        ResourceBundle bundle = getDefault().getResourceBundle();
        try {
            return (bundle != null) ? bundle.getString(key) : key;
        } catch (MissingResourceException e) {
            return key;
        }
    }
    
    /**
     * プラグインのリソースバンドルより、指定した文字列を返します。
     * <p>
     * 
     * @param key
     *            キー文字列
     * @param arguments
     *            置き換える文字列
     * @return 指定した文字列。リソースバンドルが無い場合、もしくは指定した文字列 が存在しない場合は、keyを返します。
     * @see java.text.MessageFormat
     */
    public static String getResourceString(String key, Object[] arguments) {
        ResourceBundle bundle = getDefault().getResourceBundle();
        try {
            String message = (bundle != null) ? bundle.getString(key) : key;
            return MessageFormat.format(message, arguments);
        } catch (MissingResourceException e) {
            return key;
        }
    }
    
    /*
     * 参考サイトにて、実装を推奨していたメソッド群です。
     */

    /**
     * ログを出力します。
     * 
     * @param message
     *            ログメッセージ文字列
     * @param e
     *            発生した例外
     */
    public static void log(String message, Exception e) {
        IStatus status = new Status(IStatus.ERROR, getPluginId(),
                IStatus.ERROR, message, e);
        getDefault().getLog().log(status);
    }

    /**
     * ログを出力します。
     * 
     * @param message
     *            ログメッセージ文字列
     */
    public static void log(String message) {
        log(message, null);
    }

    /**
     * ログを出力します。
     * 
     * @param e
     *            発生した例外
     */
    public static void log(Exception e) {
        StringWriter stringWriter = new StringWriter();
        String message = stringWriter.getBuffer().toString();
        log(message, e);
    }

    /**
     * プラグインIDとして利用できる、固有のIDを返します。
     * 
     * @return プラグインID
     * @see Bundle#getSymbolicName()
     */
    public static String getPluginId() {
        return getDefault().getBundle().getSymbolicName();
    }

    // ----- instance フィールド ----- //

    /** リソースバンドル */
    private ResourceBundle resourceBundle = null;

    // ----- コンストラクタ ----- //
    
    /**
     * インスタンスを返します。
     */
	public HttpPlugin() {
		super();
		plugin = this;
        try {
            resourceBundle = ResourceBundle
                    .getBundle("com.clustercontrol.http.HttpPluginResources");
        } catch (MissingResourceException x) {
            resourceBundle = null;
        }
	}
	
    // ----- instance メソッド ----- //

    /**
     * プラグインの活性化の際に呼ばれます。
     * 
     * @param context
     *            BundleContextオブジェクト
     * @throws Exception
     *             例外発生時
     */
	@Override
	public void start(BundleContext context) throws Exception {
		super.start(context);
	}

    /**
     * プラグインの非活性化の際に呼ばれます。
     * 
     * @param context
     *            BundleContextオブジェクト
     * @throws Exception
     *             例外発生時
     */
	@Override
	public void stop(BundleContext context) throws Exception {
		super.stop(context);
	}
	
    /**
     * プラグインが保持するリソースバンドルを返します。
     * 
     * @return リソースバンドル
     */
    public ResourceBundle getResourceBundle() {
        return resourceBundle;
    }
}
