/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.jobmanagement.action;

import java.util.ArrayList;
import java.util.HashMap;

import com.clustercontrol.bean.DataRangeConstant;
import com.clustercontrol.bean.EndStatusConstant;
import com.clustercontrol.bean.JudgmentObjectConstant;
import com.clustercontrol.bean.Property;
import com.clustercontrol.bean.PropertyConstant;
import com.clustercontrol.jobmanagement.composite.JobPropertyDefine;
import com.clustercontrol.util.Messages;

/**
 * 待ち条件用プロパティを作成するクライアント側アクションクラス<BR>
 * 
 * @version 2.1.0
 * @since 1.0.0
 */
public class WaitRuleProperty {
	
	/** 名前 */
	public static final String ID_JUDGMENT_OBJECT = "judgmentObject";
	
	/** ジョブID */
	public static final String ID_JOB_ID = "jobId";
	
	/** 値（終了状態） */
	public static final String ID_CONDITION_END_STATUS = "conditionEndStatus";
	
	/** 値（終了値） */
	public static final String ID_CONDITION_END_VALUE = "conditionEndValue";
	
	/** 時刻 */
	public static final String ID_TIME = "time";
	
	/**
	 * 待ち条件用プロパティを取得します。<BR>
	 * 
	 * <p>
	 * <ol>
	 *  <li>待ち条件の設定項目毎にID, 名前, 処理定数（{@link com.clustercontrol.bean.PropertyConstant}）を指定し、
	 *      プロパティ（{@link com.clustercontrol.bean.Property}）を生成します。</li>
	 *  <li>各設定項目のプロパティをツリー状に定義します。</li>
	 * </ol>
	 * 
	 * <p>プロパティに定義する待ち条件設定項目は、下記の通りです。
	 * <p>
	 * <ul>
	 *  <li>プロパティ（親。ダミー）
	 *  <ul>
	 *   <li>名前（子。コンボボックス）
	 *   <ul>
	 *    <li>ジョブ(終了状態)（名前の選択肢）
	 *    <ul>
	 *     <li>ジョブID（孫。ダイアログ）
	 *     <li>値（孫。コンボボックス）
	 *    </ul>
	 *    <li>ジョブ(終了値)（名前の選択肢）
	 *    <ul>
	 *     <li>ジョブID（孫。ダイアログ）
	 *     <li>値（孫。テキスト）
	 *    </ul>
	 *    <li>時刻（名前の選択肢）
	 *    <ul>
	 *     <li>時刻（孫。テキスト）
	 *    </ul>
	 *   </ul>
	 *  </ul>
	 * </ul>
	 * 
	 * @param parentJobId 親ジョブID
	 * @param jobId ジョブID
	 * @param type ジョブ変数の種別
	 * @return 待ち条件用プロパティ
	 * 
	 * @see com.clustercontrol.bean.Property
	 * @see com.clustercontrol.bean.PropertyConstant
	 * @see com.clustercontrol.bean.JudgmentObjectConstant
	 * @see com.clustercontrol.bean.EndStatusConstant
	 */
	@SuppressWarnings("unchecked")
	public Property getProperty(String parentJobId, String jobId, String jobunitId, int type) {
		//プロパティ項目定義
		Property judgmentObject = new Property(ID_JUDGMENT_OBJECT, 
				Messages.getString("name"), PropertyConstant.EDITOR_SELECT);
		Property job = new Property(ID_JOB_ID, 
				Messages.getString("job.id"), PropertyConstant.EDITOR_JOB);
		Property conditionEndStatus = new Property(ID_CONDITION_END_STATUS, 
				Messages.getString("value"), PropertyConstant.EDITOR_SELECT);
		Property conditionEndValue = new Property(ID_CONDITION_END_VALUE, 
				Messages.getString("value"), PropertyConstant.EDITOR_NUM, DataRangeConstant.SMALLINT_HIGH, DataRangeConstant.SMALLINT_LOW);
		Property time = new Property(ID_TIME, 
				Messages.getString("wait.rule.time.example"), PropertyConstant.EDITOR_TIME);
		
		//JobPropertyDefineクラスはClusterControlでは定義されていない
		JobPropertyDefine define = new JobPropertyDefine(parentJobId, jobId, jobunitId);
		job.setDefine(define);
		
		//ジョブ終了状態
		ArrayList jobEndStatusPropertyList = new ArrayList();
		jobEndStatusPropertyList.add(job);
		jobEndStatusPropertyList.add(conditionEndStatus);
		
		HashMap jobEndStatusMap = new HashMap();
		jobEndStatusMap.put("value", JudgmentObjectConstant.STRING_JOB_END_STAUS);
		jobEndStatusMap.put("property", jobEndStatusPropertyList);
		
		//ジョブ終了値
		ArrayList jobEndValuePropertyList = new ArrayList();
		jobEndValuePropertyList.add(job);
		jobEndValuePropertyList.add(conditionEndValue);
		
		HashMap jobEndValueMap = new HashMap();
		jobEndValueMap.put("value", JudgmentObjectConstant.STRING_JOB_END_VALUE);
		jobEndValueMap.put("property", jobEndValuePropertyList);
		
		//時刻
		ArrayList timePropertyList = new ArrayList();
		timePropertyList.add(time);
		
		HashMap timeMap = new HashMap();
		timeMap.put("value", JudgmentObjectConstant.STRING_TIME);
		timeMap.put("property", timePropertyList);
		
		//判定対象コンボボックスの選択項目
		Object judgmentObjectValues[][] = {
				{ JudgmentObjectConstant.STRING_JOB_END_STAUS,
					JudgmentObjectConstant.STRING_JOB_END_VALUE,
					JudgmentObjectConstant.STRING_TIME },
					{ jobEndStatusMap, jobEndValueMap, timeMap } };
		
		Object conditionEndStatuss[][] = {
				{ EndStatusConstant.STRING_NORMAL,
					EndStatusConstant.STRING_WARNING,
					EndStatusConstant.STRING_ABNORMAL },
					{ EndStatusConstant.STRING_NORMAL,
						EndStatusConstant.STRING_WARNING,
						EndStatusConstant.STRING_ABNORMAL } };
		
		judgmentObject.setSelectValues(judgmentObjectValues);
		conditionEndStatus.setSelectValues(conditionEndStatuss);
		
		//値を初期化
		judgmentObject.setValue("");
		job.setValue("");
		conditionEndStatus.setValue("");
		time.setValue("");
		
		//変更の可/不可を設定
		judgmentObject.setModify(PropertyConstant.MODIFY_OK);
		job.setModify(PropertyConstant.MODIFY_OK);
		conditionEndStatus.setModify(PropertyConstant.MODIFY_OK);
		conditionEndValue.setModify(PropertyConstant.MODIFY_OK);
		time.setModify(PropertyConstant.MODIFY_OK);
		
		Property property = new Property(null, null, null);
		
		if (type == JudgmentObjectConstant.TYPE_JOB_END_STAUS) {
			judgmentObject.setValue(JudgmentObjectConstant.STRING_JOB_END_STAUS);
			
			// 初期表示ツリーを構成。
			property.removeChildren();
			property.addChildren(judgmentObject);
			
			// 判定対象ツリー
			judgmentObject.removeChildren();
			judgmentObject.addChildren(job);
			judgmentObject.addChildren(conditionEndStatus);
		}
		else if (type == JudgmentObjectConstant.TYPE_JOB_END_VALUE) {
			judgmentObject.setValue(JudgmentObjectConstant.STRING_JOB_END_VALUE);
			
			// 初期表示ツリーを構成。
			property.removeChildren();
			property.addChildren(judgmentObject);
			
			// 判定対象ツリー
			judgmentObject.removeChildren();
			judgmentObject.addChildren(job);
			judgmentObject.addChildren(conditionEndValue);
		}
		else {
			judgmentObject.setValue(JudgmentObjectConstant.STRING_TIME);
			
			// 初期表示ツリーを構成。
			property.removeChildren();
			property.addChildren(judgmentObject);
			
			// 判定対象ツリー
			judgmentObject.removeChildren();
			judgmentObject.addChildren(time);
		}
		
		return property;
	}
}