/*
 
 Copyright (C) 2006 NTT DATA Corporation
 
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License 
 as published by the Free Software Foundation, version 2.
 
 This program is distributed in the hope that it will be
 useful, but WITHOUT ANY WARRANTY; without even the implied 
 warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
 PURPOSE.  See the GNU General Public License for more details.
 
 */

package com.clustercontrol.jobmanagement.common.action;

import java.rmi.AccessException;
import java.rmi.RemoteException;
import java.util.Locale;

import org.eclipse.jface.dialogs.MessageDialog;

import com.clustercontrol.HinemosUnknownException;
import com.clustercontrol.JobMasterNotFoundException;
import com.clustercontrol.NotifyNotFoundException;
import com.clustercontrol.UserNotFoundException;
import com.clustercontrol.jobmanagement.bean.JobTreeItem;
import com.clustercontrol.jobmanagement.common.util.EjbConnectionManager;
import com.clustercontrol.jobmanagement.ejb.session.JobController;
import com.clustercontrol.util.Messages;

/**
 * ジョブ階層情報を取得するクライアント側アクションクラス<BR>
 * 
 * サーバからジョブ階層情報を取得します。<BR>
 * 
 * @version 2.1.0
 * @since 2.1.0
 */
public class GetJobTree {
	
	/**
	 * ジョブ階層情報取得処理
	 * 
	 * @return ジョブ階層情報
	 * @since 2.1.0
	 */
	public JobTreeItem getJobTree(boolean treeOnly) {
		JobController job = 
			EjbConnectionManager.getConnectionManager().getJobController();
		
		JobTreeItem item = null;
		try {
			item = job.getJobTree(treeOnly, Locale.getDefault());
		} catch (RemoteException e) {
			if(e instanceof AccessException){
				// アクセス権なしの場合、エラーダイアログを表示する
				MessageDialog.openInformation(null, Messages.getString("message"),
						Messages.getString("message.accesscontrol.16"));
			}
		} catch (HinemosUnknownException e) {
			e.printStackTrace();
		} catch (NotifyNotFoundException e) {
			e.printStackTrace();
		} catch (JobMasterNotFoundException e) {
			e.printStackTrace();
		} catch (UserNotFoundException e) {
			e.printStackTrace();
		}
		return item;
	}
}
