/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.jobmanagement.composite;

import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.RowData;
import org.eclipse.swt.layout.RowLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Group;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Text;

import com.clustercontrol.ClusterControlPlugin;
import com.clustercontrol.bean.DataRangeConstant;
import com.clustercontrol.bean.FacilityConstant;
import com.clustercontrol.bean.FacilityPath;
import com.clustercontrol.bean.FacilityTreeItem;
import com.clustercontrol.bean.ProcessingMethodConstant;
import com.clustercontrol.bean.SizeConstant;
import com.clustercontrol.bean.YesNoConstant;
import com.clustercontrol.composite.StringVerifyListener;
import com.clustercontrol.dialog.ScopeTreeDialog;
import com.clustercontrol.dialog.ValidateResult;
import com.clustercontrol.jobmanagement.bean.JobFileInfo;
import com.clustercontrol.util.Messages;

/**
 * ファイル転送タブ用のコンポジットクラスです。
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class FileComposite extends Composite {
	/** 転送スコープ */
	protected Text m_srcScope = null;
	/** 転送ファイル */
	protected Text m_srcFile = null;
	
//	protected Text m_srcWorkDir = null;
	/** 受信スコープ */
	protected Text m_destScope = null;
	/** 受信ディレクトリ */
	protected Text m_destDirectory = null;
	
//	protected Text m_destWorkDir = null;
	/** 実効ユーザ */
	protected Text m_user = null;
	/** 転送スコープ参照ボタン */
	protected Button m_srcScopeSelect = null;
	/** 受信スコープ参照ボタン */
	protected Button m_destScopeSelect = null;
	/** 全てのノードで受信用ラジオボタン */
	protected Button m_allNode = null;
	/** 1ノードで受信用ラジオボタン */
	protected Button m_oneNode = null;
	/** ファイル転送時圧縮用チェックボタン */
	protected Button m_compressionCondition = null;
	/** 転送ファイルチェック用チェックボタン */
	protected Button m_checkFileCondition = null;
	/** 転送ファシリティID */
	protected String m_srcFacilityId = null;
	/** 転送ファシリティパス */
	protected String m_srcFacilityPath = null;
	/** 受信ファシリティID */
	protected String m_destFacilityId = null;
	/** 受信ファシリティパス */
	protected String m_destFacilityPath = null;
	/** ジョブファイル転送情報 */
	protected JobFileInfo m_jobFileInfo = null;
	/** シェル */
	protected Shell m_shell = null;
	
	/**
	 * コンストラクタ
	 * 
     * @param parent 親コンポジット
     * @param style スタイル
     * 
     * @see org.eclipse.swt.SWT
     * @see org.eclipse.swt.widgets.Composite#Composite(Composite parent, int style)
     * @see #initialize()
	 */
	public FileComposite(Composite parent, int style) {
		super(parent, style);
		initialize();
		m_shell = this.getShell();
	}
	
	/**
	 * コンポジットを配置します。
	 */
	private void initialize() {
		RowLayout layout = new RowLayout();
		layout.type = SWT.VERTICAL;
		layout.spacing = 10;
		layout.marginWidth = 10;
		layout.marginHeight = 10;
		layout.fill = true;
		this.setLayout(layout);
		
		Composite composite = null;
		RowLayout rowLayout = null;
		
		//転送元用グループ
		Group group = new Group(this, SWT.NONE);
		group.setText(Messages.getString("forward.source"));
		rowLayout = new RowLayout();
		rowLayout.type = SWT.VERTICAL;
		rowLayout.marginWidth = 10;
		rowLayout.marginHeight = 10;
		group.setLayout(rowLayout);
		
		//転送元スコープ用コンポジット
		composite = new Composite(group, SWT.NONE);
		rowLayout = new RowLayout();
		rowLayout.type = SWT.HORIZONTAL;
		rowLayout.spacing = 10;
		composite.setLayout(rowLayout);
		
		Label srcScopeTitle = new Label(composite, SWT.NONE);
		srcScopeTitle.setText(Messages.getString("scope") + " : ");
		srcScopeTitle.setLayoutData(new RowData(100,
				SizeConstant.SIZE_LABEL_HEIGHT));
		
		m_srcScope = new Text(composite, SWT.BORDER | SWT.READ_ONLY);
		m_srcScope.setLayoutData(new RowData(200, SizeConstant.SIZE_TEXT_HEIGHT));
		m_srcScope.setText("");
		
		m_srcScopeSelect = new Button(composite, SWT.NONE);
		m_srcScopeSelect.setText(Messages.getString("refer"));
		m_srcScopeSelect.setLayoutData(new RowData(80,
				SizeConstant.SIZE_BUTTON_HEIGHT));
		m_srcScopeSelect.addSelectionListener(new SelectionAdapter() {
			@Override
			public void widgetSelected(SelectionEvent e) {
				ScopeTreeDialog dialog = new ScopeTreeDialog(m_shell);
				if (dialog.open() == IDialogConstants.OK_ID) {
					FacilityTreeItem selectItem = dialog.getSelectItem();
					if (selectItem.getData().getFacilityType() == FacilityConstant.TYPE_COMPOSITE || 
							selectItem.getData().getFacilityType() == FacilityConstant.TYPE_SCOPE) {
						m_srcFacilityPath = "";
						m_srcFacilityId = "";
					} else {
						FacilityPath path = new FacilityPath(
								ClusterControlPlugin.getDefault()
								.getSeparator());
						m_srcFacilityPath = path.getPath(selectItem);
						m_srcFacilityId = selectItem.getData().getFacilityId();
					}
					
					m_srcScope.setText(m_srcFacilityPath);
				}
			}
		});
		
		//転送ファイル用コンポジット
		composite = new Composite(group, SWT.NONE);
		rowLayout = new RowLayout();
		rowLayout.type = SWT.HORIZONTAL;
		rowLayout.spacing = 10;
		composite.setLayout(rowLayout);
		
		Label fileTitle = new Label(composite, SWT.NONE);
		fileTitle.setText(Messages.getString("file") + " : ");
		fileTitle.setLayoutData(new RowData(100,
				SizeConstant.SIZE_LABEL_HEIGHT));
		
		m_srcFile = new Text(composite, SWT.BORDER);
		m_srcFile.setLayoutData(new RowData(200, SizeConstant.SIZE_TEXT_HEIGHT));
		m_srcFile.addVerifyListener(
        		new StringVerifyListener(DataRangeConstant.VARCHAR_4096));
		m_srcFile.setText("");
		
		//転送元作業ディレクトリ用コンポジット
//		composite = new Composite(group, SWT.NONE);
//		rowLayout = new RowLayout();
//		rowLayout.type = SWT.HORIZONTAL;
//		rowLayout.spacing = 10;
//		composite.setLayout(rowLayout);
//		
//		Label srcWorkDirTitle = new Label(composite, SWT.NONE);
//		srcWorkDirTitle.setText(Messages.getString("work.directory") + " : ");
//		srcWorkDirTitle.setLayoutData(new RowData(100,
//				SizeConstant.SIZE_LABEL_HEIGHT));
//		
//		m_srcWorkDir = new Text(composite, SWT.BORDER);
//		m_srcWorkDir.setLayoutData(new RowData(200, SizeConstant.SIZE_TEXT_HEIGHT));
//		m_srcWorkDir.setText("");
		
		//転送先用グループ
		group = new Group(this, SWT.NONE);
		group.setText(Messages.getString("forward.destination"));
		rowLayout = new RowLayout();
		rowLayout.type = SWT.VERTICAL;
		rowLayout.marginWidth = 10;
		rowLayout.marginHeight = 10;
		group.setLayout(rowLayout);
		
		//転送先スコープ用コンポジット
		composite = new Composite(group, SWT.NONE);
		rowLayout = new RowLayout();
		rowLayout.type = SWT.HORIZONTAL;
		rowLayout.spacing = 10;
		composite.setLayout(rowLayout);
		
		Label destScopeTitle = new Label(composite, SWT.NONE);
		destScopeTitle.setText(Messages.getString("scope") + " : ");
		destScopeTitle.setLayoutData(new RowData(100,
				SizeConstant.SIZE_LABEL_HEIGHT));
		
		m_destScope = new Text(composite, SWT.BORDER | SWT.READ_ONLY);
		m_destScope.setLayoutData(new RowData(200, SizeConstant.SIZE_TEXT_HEIGHT));
		m_destScope.setText("");
		
		m_destScopeSelect = new Button(composite, SWT.NONE);
		m_destScopeSelect.setText(Messages.getString("refer"));
		m_destScopeSelect.setLayoutData(new RowData(80,
				SizeConstant.SIZE_BUTTON_HEIGHT));
		m_destScopeSelect.addSelectionListener(new SelectionAdapter() {
			@Override
			public void widgetSelected(SelectionEvent e) {
				ScopeTreeDialog dialog = new ScopeTreeDialog(m_shell);
				if (dialog.open() == IDialogConstants.OK_ID) {
					FacilityTreeItem selectItem = dialog.getSelectItem();
					if (selectItem.getData().getFacilityType() == FacilityConstant.TYPE_COMPOSITE) {
						m_destFacilityPath = "";
						m_destFacilityId = "";
					} else {
						FacilityPath path = new FacilityPath(
								ClusterControlPlugin.getDefault()
								.getSeparator());
						m_destFacilityPath = path.getPath(selectItem);
						m_destFacilityId = selectItem.getData().getFacilityId();
					}
					
					m_destScope.setText(m_destFacilityPath);
				}
			}
		});
		
		//処理方式グループ
		Group methodGroup = new Group(group, SWT.NONE);
		methodGroup.setText(Messages.getString("process.method"));
		rowLayout = new RowLayout();
		rowLayout.type = SWT.VERTICAL;
		rowLayout.marginWidth = 10;
		rowLayout.marginHeight = 10;
		methodGroup.setLayout(rowLayout);
		
		m_allNode = new Button(methodGroup, SWT.RADIO);
		m_allNode.setText(Messages.getString("forward.all.nodes"));
		m_allNode.setLayoutData(
				new RowData(350, SizeConstant.SIZE_BUTTON_HEIGHT));
		m_oneNode = new Button(methodGroup, SWT.RADIO);
		m_oneNode.setText(Messages.getString("forward.one.node"));
		m_oneNode.setLayoutData(
				new RowData(350, SizeConstant.SIZE_BUTTON_HEIGHT));
		
		//転送先ディレクトリ用コンポジット
		composite = new Composite(group, SWT.NONE);
		rowLayout = new RowLayout();
		rowLayout.type = SWT.HORIZONTAL;
		rowLayout.spacing = 10;
		composite.setLayout(rowLayout);
		
		Label forwardDirTitle = new Label(composite, SWT.NONE);
		forwardDirTitle.setText(Messages.getString("directory") + " : ");
		forwardDirTitle.setLayoutData(new RowData(100,
				SizeConstant.SIZE_LABEL_HEIGHT));
		
		m_destDirectory = new Text(composite, SWT.BORDER);
		m_destDirectory.setLayoutData(new RowData(200,
				SizeConstant.SIZE_TEXT_HEIGHT));
		m_destDirectory.addVerifyListener(
        		new StringVerifyListener(DataRangeConstant.VARCHAR_4096));
		
		//転送元作業ディレクトリ用コンポジット
//		composite = new Composite(group, SWT.NONE);
//		rowLayout = new RowLayout();
//		rowLayout.type = SWT.HORIZONTAL;
//		rowLayout.spacing = 10;
//		composite.setLayout(rowLayout);
//		
//		Label destWorkDirTitle = new Label(composite, SWT.NONE);
//		destWorkDirTitle.setText(Messages.getString("work.directory") + " : ");
//		destWorkDirTitle.setLayoutData(new RowData(100,
//				SizeConstant.SIZE_LABEL_HEIGHT));
//		
//		m_destWorkDir = new Text(composite, SWT.BORDER);
//		m_destWorkDir.setLayoutData(new RowData(200, SizeConstant.SIZE_TEXT_HEIGHT));
//		m_destWorkDir.setText("");
		
		//ファイル圧縮用コンポジット
		composite = new Composite(this, SWT.NONE);
		rowLayout = new RowLayout();
		rowLayout.type = SWT.HORIZONTAL;
		composite.setLayout(rowLayout);
		
		m_compressionCondition = new Button(composite, SWT.CHECK);
		m_compressionCondition.setText(Messages.getString("forward.compression.file"));
		m_compressionCondition.setLayoutData(new RowData(220,
				SizeConstant.SIZE_BUTTON_HEIGHT));
		
		//ファイル整合性チェック用コンポジット
		composite = new Composite(this, SWT.NONE);
		rowLayout = new RowLayout();
		rowLayout.type = SWT.HORIZONTAL;
		composite.setLayout(rowLayout);
		
		m_checkFileCondition = new Button(composite, SWT.CHECK);
		m_checkFileCondition.setText(Messages.getString("forward.file.check"));
		m_checkFileCondition.setLayoutData(new RowData(250,
				SizeConstant.SIZE_BUTTON_HEIGHT));
		
		//実効ユーザ用コンポジット
		composite = new Composite(this, SWT.NONE);
		rowLayout = new RowLayout();
		rowLayout.type = SWT.HORIZONTAL;
		rowLayout.spacing = 10;
		composite.setLayout(rowLayout);
		
		Label userTitle = new Label(composite, SWT.NONE);
		userTitle.setText(Messages.getString("effective.user") + " : ");
		userTitle
		.setLayoutData(new RowData(100, SizeConstant.SIZE_LABEL_HEIGHT));
		
		m_user = new Text(composite, SWT.BORDER);
		m_user.setLayoutData(new RowData(200, SizeConstant.SIZE_TEXT_HEIGHT));
		m_user.addVerifyListener(
        		new StringVerifyListener(DataRangeConstant.VARCHAR_64));
	}
	
	/**
	 * ジョブファイル転送情報をコンポジットに反映します。
	 * 
	 * @see com.clustercontrol.jobmanagement.bean.JobFileInfo
	 */
	public void reflectFileInfo() {
		if (m_jobFileInfo instanceof JobFileInfo) {
			//転送元スコープ設定
			m_srcFacilityPath = m_jobFileInfo.getSrcScope();
			m_srcFacilityId = m_jobFileInfo.getSrcFacilityID();
			if (m_srcFacilityPath != null && m_srcFacilityPath.length() > 0) {
				m_srcScope.setText(m_srcFacilityPath);
			}
			//転送元ファイル設定
			if (m_jobFileInfo.getSrcFile() != null
					&& m_jobFileInfo.getSrcFile().length() > 0) {
				m_srcFile.setText(m_jobFileInfo.getSrcFile());
			}
			//転送元作業ディレクトリ設定
//			if (m_jobFileInfo.getSrcWorkDir() != null
//					&& m_jobFileInfo.getSrcWorkDir().length() > 0) {
//				m_srcWorkDir.setText(m_jobFileInfo.getSrcWorkDir());
//			}
			//転送先スコープ設定
			m_destFacilityPath = m_jobFileInfo.getDestScope();
			m_destFacilityId = m_jobFileInfo.getDestFacilityID();
			if (m_destFacilityPath != null && m_destFacilityPath.length() > 0) {
				m_destScope.setText(m_destFacilityPath);
			}
			//転送先ファイル設定
			if (m_jobFileInfo.getDestDirectory() != null
					&& m_jobFileInfo.getDestDirectory().length() > 0) {
				m_destDirectory.setText(m_jobFileInfo.getDestDirectory());
			}
			//転送先作業ディレクトリ設定
//			if (m_jobFileInfo.getDestWorkDir() != null
//					&& m_jobFileInfo.getDestWorkDir().length() > 0) {
//				m_destWorkDir.setText(m_jobFileInfo.getDestWorkDir());
//			}
			//処理方法設定
			if (m_jobFileInfo.getProcessingMethod() == ProcessingMethodConstant.TYPE_ALL_NODE) {
				m_allNode.setSelection(true);
			} else {
				m_oneNode.setSelection(true);
			}
			//ファイル圧縮
			m_compressionCondition.setSelection(
					YesNoConstant.typeToBoolean(m_jobFileInfo.getCompressionFlg()));
			//整合性チェック
			m_checkFileCondition.setSelection(
					YesNoConstant.typeToBoolean(m_jobFileInfo.getCheckFlg()));
			//ユーザー設定
			if (m_jobFileInfo.getUser() != null && m_jobFileInfo.getUser().length() > 0) {
				m_user.setText(m_jobFileInfo.getUser());
			}
		} else {
			m_srcScope.setText("");
			m_srcFile.setText("");
//			m_srcWorkDir.setText("");
			m_destScope.setText("");
			m_destDirectory.setText("");
//			m_destWorkDir.setText("");
			m_allNode.setSelection(true);
			m_compressionCondition.setSelection(false);
			m_checkFileCondition.setSelection(false);
			m_user.setText("");
		}
	}
	
	/**
	 * ジョブファイル転送情報を設定します。
	 * 
	 * @param jobFileInfo ジョブファイル転送情報
	 */
	public void setFileInfo(JobFileInfo jobFileInfo) {
		m_jobFileInfo = jobFileInfo;
	}
	
	/**
	 * ジョブファイル転送情報を返します。
	 * 
	 * @return ジョブファイル転送情報
	 */
	public JobFileInfo getFileInfo() {
		return m_jobFileInfo;
	}
	
	/**
	 * コンポジットの情報から、ジョブファイル転送情報を作成する。
	 * 
	 * @return 入力値の検証結果
	 * 
	 * @see com.clustercontrol.jobmanagement.bean.JobFileInfo
	 */
	public ValidateResult createFileInfo() {
		ValidateResult result = null;
		
		//ファイル転送情報クラスのインスタンスを作成・取得
		m_jobFileInfo = new JobFileInfo();
		
		//転送元スコープ取得
		if (m_srcFacilityId != null && m_srcFacilityId.length() > 0) {
			m_jobFileInfo.setSrcFacilityID(m_srcFacilityId);
			m_jobFileInfo.setSrcScope(m_srcFacilityPath);
		} else {
			result = new ValidateResult();
			result.setValid(false);
			result.setID(Messages.getString("message.hinemos.1"));
			result.setMessage(Messages.getString("forward.source") + 
					Messages.getString("message.hinemos.3"));
			return result;
		}
		
		//転送元ファイル
		if (m_srcFile.getText().length() > 0) {
			m_jobFileInfo.setSrcFile(m_srcFile.getText());
		} else {
			result = new ValidateResult();
			result.setValid(false);
			result.setID(Messages.getString("message.hinemos.1"));
			result.setMessage(Messages.getString("forward.source") + 
					Messages.getString("message.job.45"));
			return result;
		}
		
		//転送元作業ディレクトリ
		m_jobFileInfo.setSrcWorkDir("");
//		if (m_srcWorkDir.getText().length() > 0) {
//			m_jobFileInfo.setSrcWorkDir(m_srcWorkDir.getText());
//		} else {
//			result = new ValidateResult();
//			result.setValid(false);
//			result.setID(Messages.getString("message.hinemos.1"));
//			result.setMessage(Messages.getString("forward.source") + 
//					Messages.getString("message.job.47"));
//			return result;
//		}
		
		//転送先スコープ取得
		if (m_destFacilityId != null && m_destFacilityId.length() > 0) {
			m_jobFileInfo.setDestFacilityID(m_destFacilityId);
			m_jobFileInfo.setDestScope(m_destFacilityPath);
		} else {
			result = new ValidateResult();
			result.setValid(false);
			result.setID(Messages.getString("message.hinemos.1"));
			result.setMessage(Messages.getString("forward.destination") + 
					Messages.getString("message.hinemos.3"));
			return result;
		}
		
		//転送先ディレクトリ
		if (m_destDirectory.getText().length() > 0 && m_destDirectory.getText().endsWith("/")) {
			m_jobFileInfo.setDestDirectory(m_destDirectory.getText());
			
		// 転送先ディレクトリが指定されていない場合
		} else if (m_destDirectory.getText().length() <= 0) {
			result = new ValidateResult();
			result.setValid(false);
			result.setID(Messages.getString("message.hinemos.1"));
			result.setMessage(Messages.getString("forward.destination") + 
					Messages.getString("message.job.46"));
			return result;
			
		// 転送先ディレクトリ指定文字列の末尾が / でない場合
		} else if (!m_destDirectory.getText().endsWith("/")) {
			result = new ValidateResult();
			result.setValid(false);
			result.setID(Messages.getString("message.hinemos.1"));
			result.setMessage(Messages.getString("forward.destination") + 
					Messages.getString("message.job.62"));
			return result;
			
		}

		
		//転送先作業ディレクトリ
		m_jobFileInfo.setDestWorkDir("");
//		if (m_destWorkDir.getText().length() > 0) {
//			m_jobFileInfo.setDestWorkDir(m_destWorkDir.getText());
//		} else {
//			result = new ValidateResult();
//			result.setValid(false);
//			result.setID(Messages.getString("message.hinemos.1"));
//			result.setMessage(Messages.getString("forward.destination") + 
//					Messages.getString("message.job.47"));
//			return result;
//		}
		
		//処理方法取得
		if (m_allNode.getSelection()) {
			m_jobFileInfo.setProcessingMethod(
					ProcessingMethodConstant.TYPE_ALL_NODE);
		} else {
			m_jobFileInfo.setProcessingMethod(
					ProcessingMethodConstant.TYPE_RETRY);
		}
		
		//ファイル圧縮
		m_jobFileInfo.setCompressionFlg(
				YesNoConstant.booleanToType(m_compressionCondition.getSelection()));
		
		//整合性チェック
		m_jobFileInfo.setCheckFlg(
				YesNoConstant.booleanToType(m_checkFileCondition.getSelection()));
		
		//ユーザー取得
		if (m_user.getText().length() > 0) {
			m_jobFileInfo.setUser(m_user.getText());
		} else {
			result = new ValidateResult();
			result.setValid(false);
			result.setID(Messages.getString("message.hinemos.1"));
			result.setMessage(Messages.getString("message.job.5"));
			return result;
		}
		
		return null;
	}
}