/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.jobmanagement.composite;

import java.util.ArrayList;

import org.eclipse.jface.viewers.LabelProvider;
import org.eclipse.swt.graphics.Image;

import com.clustercontrol.bean.JobConstant;
import com.clustercontrol.bean.JobImageConstant;
import com.clustercontrol.jobmanagement.bean.JobInfo;
import com.clustercontrol.jobmanagement.bean.JobManagementUserInfo;
import com.clustercontrol.jobmanagement.bean.JobTreeItem;
import com.clustercontrol.util.LoginManager;

/**
 * ジョブツリー用コンポジットのツリービューア用のLabelProviderクラスです。
 * 
 * @version 2.0.0
 * @since 1.0.0
 */
class JobTreeLabelProvider extends LabelProvider {

    /**
     * ジョブツリーアイテムから表示名を作成し返します。
     * 
     * @param ジョブツリーアイテム
     * @return 表示名
     * 
     * @see org.eclipse.jface.viewers.ILabelProvider#getText(java.lang.Object)
     */
    @Override
	public String getText(Object element) {
        JobInfo info = ((JobTreeItem) element).getData();

        int type = info.getType();
        if (type == JobConstant.TYPE_COMPOSITE) {
            return info.getName();
        } else {
            return info.getName() + " (" + info.getId() + ")";
        }
    }

    /**
     * ジョブツリーアイテムのジョブ種別に該当するイメージを返します。
     * 
     * @param ジョブツリーアイテム
     * @return イメージ
     * 
     * @see org.eclipse.jface.viewers.ILabelProvider#getImage(java.lang.Object)
     */
    @Override
	public Image getImage(Object element) {
    	
    	boolean isReferableJobunit = false;
    	
    	JobTreeItem item = (JobTreeItem) element;
        int type = item.getData().getType();
        
        //ジョブユニットの場合、参照可能かチェックする
        if (type == JobConstant.TYPE_JOBUNIT) {
        	ArrayList<JobManagementUserInfo> userInfo = item.getData().getManagementUser();
        	if (userInfo == null || userInfo.size() == 0) {
        		isReferableJobunit = true;
        	} else {
        		for (JobManagementUserInfo i : userInfo) {
        			String loginUser = LoginManager.getContextManager().getUserId();
        			if (loginUser.equals(i.getUserId())) {
        				isReferableJobunit = true;
        				break;
        			}
        		}
        	}
        } else {
        	isReferableJobunit = true;
        }
        
        // ログインユーザで参照できないジョブユニットの場合はアイコンを変える
        if (!isReferableJobunit) {
        	return JobImageConstant.typeToImage(JobConstant.TYPE_JOBUNIT_UNREFERABLE);
        } else {
        	return JobImageConstant.typeToImage(type);
        }
    }
}