/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.jobmanagement.composite.action;

import java.util.ArrayList;

import org.eclipse.jface.viewers.DoubleClickEvent;
import org.eclipse.jface.viewers.IDoubleClickListener;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.PlatformUI;

import com.clustercontrol.bean.CommonTableTreeItem;
import com.clustercontrol.jobmanagement.action.GetSessionJobInfo;
import com.clustercontrol.jobmanagement.bean.HistoryTableDefine;
import com.clustercontrol.jobmanagement.bean.JobDetailTableDefine;
import com.clustercontrol.jobmanagement.bean.JobTreeItem;
import com.clustercontrol.jobmanagement.composite.DetailComposite;
import com.clustercontrol.jobmanagement.composite.HistoryComposite;
import com.clustercontrol.jobmanagement.dialog.JobDialog;

/**
 * ジョブ[履歴]ビューまたはジョブ[ジョブ詳細]ビューのテーブルビューア用のDoubleClickListenerです。
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class SessionJobDoubleClickListener implements IDoubleClickListener {
    /** ジョブ[履歴]ビューまたはジョブ[ジョブ詳細]ビュー用のコンポジット */
	protected Composite m_composite;

    /**
     * コンストラクタ
     * 
     * @param composite ジョブ[履歴]ビューまたはジョブ[ジョブ詳細]ビュー用のコンポジット
     */
    public SessionJobDoubleClickListener(Composite composite) {
        m_composite = composite;
    }
    
    /**
     * ダブルクリック時に呼び出されます。<BR>
     * ジョブ[履歴]ビューまたはジョブ[ジョブ詳細]ビューのテーブルビューアをダブルクリックした際に、選択した行の内容をダイアログで表示します。
     * <P>
     * <ol>
	 * <li>イベントから選択行を取得し、選択行からセッションIDとジョブIDを取得します。</li>
	 * <li>セッションIDとジョブIDからジョブ情報を取得し、ダイアログで表示します。</li>
	 * </ol>
	 * 
     * @param event イベント
     * 
	 * @see org.eclipse.jface.viewers.IDoubleClickListener#doubleClick(org.eclipse.jface.viewers.DoubleClickEvent)
	 */
	public void doubleClick(DoubleClickEvent event) {
        String sessionId = null;
        String jobunitId = null;
        String jobId = null;

		if(m_composite instanceof HistoryComposite){
	        //セッションIDとジョブIDを取得
	        if (((StructuredSelection) event.getSelection()).getFirstElement() != null) {
	            ArrayList info = (ArrayList) ((StructuredSelection) event
	                    .getSelection()).getFirstElement();
	            sessionId = (String)info.get(HistoryTableDefine.SESSION_ID);
	            jobunitId = (String)info.get(HistoryTableDefine.JOBUNIT_ID);
	            jobId = (String)info.get(HistoryTableDefine.JOB_ID);
	        }
		}
		else if(m_composite instanceof DetailComposite){
	        //セッションIDとジョブIDを取得
	        if (((StructuredSelection) event.getSelection()).getFirstElement() != null) {
	            CommonTableTreeItem item = (CommonTableTreeItem) ((StructuredSelection) event
	                    .getSelection()).getFirstElement();
	            ArrayList info = item.getData();
	            sessionId = ((DetailComposite)m_composite).getSessionId();
	            jobunitId = ((DetailComposite)m_composite).getJobunitId();
	            jobId = (String)info.get(JobDetailTableDefine.JOB_ID);
	        }
		}
		
		if(sessionId != null && sessionId.length() > 0 && 
				jobunitId != null && jobunitId.length() > 0 &&
				jobId != null && jobId.length() > 0){
		
			JobTreeItem item = new GetSessionJobInfo().getJobTree(sessionId, jobunitId, jobId);
			if(item != null){
		        JobDialog dialog = new JobDialog(
		        		PlatformUI.getWorkbench().getActiveWorkbenchWindow().getShell(), 
		        		true);
		        
		        dialog.setJobTreeItem(item);
		        dialog.open();
			}
		}
	}

}
