/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.jobmanagement.view;

import org.eclipse.jface.action.ActionContributionItem;
import org.eclipse.jface.action.IMenuListener;
import org.eclipse.jface.action.IMenuManager;
import org.eclipse.jface.action.IToolBarManager;
import org.eclipse.jface.action.MenuManager;
import org.eclipse.jface.action.Separator;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.SashForm;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Menu;

import com.clustercontrol.bean.JobConstant;
import com.clustercontrol.jobmanagement.bean.JobTreeItem;
import com.clustercontrol.jobmanagement.composite.JobListComposite;
import com.clustercontrol.jobmanagement.composite.JobTreeComposite;
import com.clustercontrol.jobmanagement.composite.action.JobListSelectionChangedListener;
import com.clustercontrol.jobmanagement.composite.action.JobTreeSelectionChangedListener;
import com.clustercontrol.jobmanagement.util.JobUtil;
import com.clustercontrol.jobmanagement.view.action.CopyJobAction;
import com.clustercontrol.jobmanagement.view.action.CreateFileJobAction;
import com.clustercontrol.jobmanagement.view.action.CreateJobAction;
import com.clustercontrol.jobmanagement.view.action.CreateJobNetAction;
import com.clustercontrol.jobmanagement.view.action.CreateJobUnitAction;
import com.clustercontrol.jobmanagement.view.action.DeleteJobAction;
import com.clustercontrol.jobmanagement.view.action.ModifyJobAction;
import com.clustercontrol.jobmanagement.view.action.PasteJobAction;
import com.clustercontrol.jobmanagement.view.action.RunJobAction;
import com.clustercontrol.util.LoginManager;
import com.clustercontrol.view.CommonViewPart;

/**
 * ジョブ[一覧]ビュークラスです。
 * 
 * @version 2.0.0
 * @since 1.0.0
 */
public class JobListView extends CommonViewPart {
    /** ビューID */
	public static final String ID = "com.clustercontrol.jobmanagement.view.JobListView";
	/** サッシュ */
    protected SashForm m_sash = null;
    /** ジョブツリー用コンポジット */
    protected JobTreeComposite m_jobTree = null;
    /** ジョブ[一覧]ビュー用のコンポジット */
    protected JobListComposite m_jobList = null;
    /** ジョブツリーアイテム */
    protected JobTreeItem m_copyJobTreeItem = null;
    /** 更新フラグ */
    protected boolean m_update = false;

    /**
     * コンストラクタ
     */
    public JobListView() {
        super();
    }

    /**
     * ビューを構築します。
     * 
     * @param parent 親コンポジット
     * 
     * @see org.eclipse.ui.IWorkbenchPart#createPartControl(org.eclipse.swt.widgets.Composite)
     * @see #createContextMenu()
     * @see #update()
     */
    @Override
	public void createPartControl(Composite parent) {
        GridLayout layout = new GridLayout(1, true);
        parent.setLayout(layout);
        layout.marginHeight = 0;
        layout.marginWidth = 0;

        m_sash = new SashForm(parent, SWT.HORIZONTAL);
        GridData gridData = new GridData();
        gridData.horizontalAlignment = GridData.FILL;
        gridData.verticalAlignment = GridData.FILL;
        gridData.grabExcessHorizontalSpace = true;
        gridData.grabExcessVerticalSpace = true;
        m_sash.setLayoutData(gridData);

        //ジョブ階層ツリー作成
        m_jobTree = new JobTreeComposite(m_sash, SWT.NONE);

        //ジョブ一覧作成
        m_jobList = new JobListComposite(m_sash, SWT.NONE);

        //Sashの境界を調整 左部30% 右部70%
        m_sash.setWeights(new int[] { 30, 70 });

        m_jobTree.getTreeViewer().addSelectionChangedListener(
                new JobTreeSelectionChangedListener(m_jobTree, m_jobList));

        m_jobList.getTableViewer().addSelectionChangedListener(
                new JobListSelectionChangedListener(m_jobList));

        //ポップアップメニュー作成
        createContextMenu();

        //ビューを更新
        this.update();

        //ツリーを開く
        m_jobTree.getTreeViewer().expandToLevel(2);
    }

    /**
     * コンテキストメニューを作成します。
     * 
     * @see org.eclipse.jface.action.MenuManager
     * @see org.eclipse.swt.widgets.Menu
     */
    protected void createContextMenu() {
        MenuManager menuManager = new MenuManager();
        menuManager.setRemoveAllWhenShown(true);
        menuManager.addMenuListener(new IMenuListener() {
            /*
             * (non-Javadoc)
             * 
             * @see org.eclipse.jface.action.IMenuListener#menuAboutToShow(org.eclipse.jface.action.IMenuManager)
             */
            public void menuAboutToShow(IMenuManager manager) {
                
                //メニュー項目設定
                fillContextMenu(manager);
            }
        });
        Menu treeMenu = menuManager.createContextMenu(m_jobTree.getTree());
        m_jobTree.getTree().setMenu(treeMenu);

        Menu listMenu = menuManager.createContextMenu(m_jobList.getTable());
        m_jobList.getTable().setMenu(listMenu);
    }

    /**
     * コンテキストメニューに項目を追加します。
     * 
     * @param manager メニューマネージャ
     * 
     * @see org.eclipse.jface.action.IToolBarManager
     * @see org.eclipse.jface.action.IMenuManager
     */
    protected void fillContextMenu(IMenuManager manager) {
        //ビューのアクションのインスタンスを取得
        IToolBarManager toolbar = this.getViewSite().getActionBars()
                .getToolBarManager();
        ActionContributionItem createJobUnitAction = (ActionContributionItem) toolbar
                .find(CreateJobUnitAction.ID);
        ActionContributionItem createJobNetAction = (ActionContributionItem) toolbar
                .find(CreateJobNetAction.ID);
        ActionContributionItem createJobAction = (ActionContributionItem) toolbar
                .find(CreateJobAction.ID);
        ActionContributionItem createFileJobAction = (ActionContributionItem) toolbar
        		.find(CreateFileJobAction.ID);
        ActionContributionItem deleteJobAction = (ActionContributionItem) toolbar
                .find(DeleteJobAction.ID);
        ActionContributionItem modifyJobAction = (ActionContributionItem) toolbar
                .find(ModifyJobAction.ID);
        ActionContributionItem runJobAction = (ActionContributionItem) toolbar
                .find(RunJobAction.ID);

        //ポップアップメニューにアクションを追加
        //Ver2.0.0 コピーを追加
        CopyJobAction copyJobAction = new CopyJobAction(this);
        manager.add(copyJobAction);
        //Ver2.0.0 貼り付けを追加
        PasteJobAction pasteJobAction = new PasteJobAction(this);
        manager.add(pasteJobAction);
        manager.add(new Separator());
        manager.add(createJobUnitAction.getAction());
        manager.add(createJobNetAction.getAction());
        manager.add(createJobAction.getAction());
        manager.add(createFileJobAction.getAction());
        manager.add(modifyJobAction.getAction());
        manager.add(deleteJobAction.getAction());
        manager.add(runJobAction.getAction());
        
        //コピー・貼り付けアクションの使用可/不可を設定
        JobTreeItem select = getSelectJobTreeItem();
        if (select instanceof JobTreeItem) {
            //コピーアクションの使用可/不可を設定
            if(select.getData().getType() == JobConstant.TYPE_COMPOSITE){
                copyJobAction.setEnabled(false);
                
            } else if (select.getData().getType() == JobConstant.TYPE_JOBUNIT) {
            	if (JobUtil.isReferableJobunit(select, LoginManager.getContextManager().getUserId())) {
            		copyJobAction.setEnabled(true);
            	} else {
            		copyJobAction.setEnabled(false);
            	}
            } else{
            	copyJobAction.setEnabled(true);
            }
            //貼り付けアクションの使用可/不可を設定
            if(m_copyJobTreeItem != null && m_copyJobTreeItem instanceof JobTreeItem){
                pasteJobAction.setEnabled(true);
                
                if (select.getData().getType() == JobConstant.TYPE_JOBUNIT) {
                   	if (JobUtil.isReferableJobunit(select, LoginManager.getContextManager().getUserId())) {
                   		pasteJobAction.setEnabled(true);
                	} else {
                		pasteJobAction.setEnabled(false);
                	}
                }
                
            }  else{
                pasteJobAction.setEnabled(false);
            }
        }
    }

    /**
     * ビューを更新します。
     * 
     * @see com.clustercontrol.jobmanagement.composite.JobTreeComposite#update()
     * @see com.clustercontrol.jobmanagement.composite.JobTreeComposite#getSelectItem()
     * @see com.clustercontrol.jobmanagement.composite.JobListComposite#update(JobTreeItem)
     */
    public void update() {
        m_jobTree.update();

        JobTreeItem item = this.getJobTreeComposite().getSelectItem();

        m_jobList.update(item);
        
        m_update = false;
    }

    /**
     * ビューのアクションの有効/無効を設定します。
     * 
     * @param type ジョブ種別
     * @param selection ボタン（アクション）を有効にするための情報
     * 
     * @see com.clustercontrol.bean.JobConstant
     */
    public void setEnabledAction(int type, ISelection selection) {
        
        super.setEnabledAction(CreateJobUnitAction.ID, selection);
        super.setEnabledAction(CreateJobNetAction.ID, selection);
        super.setEnabledAction(CreateJobAction.ID, selection);
        super.setEnabledAction(CreateFileJobAction.ID, selection);
        super.setEnabledAction(DeleteJobAction.ID, selection);
        super.setEnabledAction(ModifyJobAction.ID, selection);
        super.setEnabledAction(RunJobAction.ID, selection);

        if (type == JobConstant.TYPE_COMPOSITE) {
            super.setEnabledAction(CreateJobUnitAction.ID, true);
            super.setEnabledAction(CreateJobNetAction.ID, false);
            super.setEnabledAction(CreateJobAction.ID, false);
            super.setEnabledAction(CreateFileJobAction.ID, false);
            super.setEnabledAction(DeleteJobAction.ID, false);
            super.setEnabledAction(ModifyJobAction.ID, false);
            super.setEnabledAction(RunJobAction.ID, false);
        } else if (type == JobConstant.TYPE_JOBUNIT) {
            super.setEnabledAction(CreateJobUnitAction.ID, false);
            super.setEnabledAction(CreateJobNetAction.ID, true);
            super.setEnabledAction(CreateJobAction.ID, true);
            super.setEnabledAction(CreateFileJobAction.ID, true);
            super.setEnabledAction(DeleteJobAction.ID, true);
            super.setEnabledAction(ModifyJobAction.ID, true);
            super.setEnabledAction(RunJobAction.ID, true);
        } else if (type == JobConstant.TYPE_JOBNET) {
            super.setEnabledAction(CreateJobUnitAction.ID, false);
            super.setEnabledAction(CreateJobNetAction.ID, true);
            super.setEnabledAction(CreateJobAction.ID, true);
            super.setEnabledAction(CreateFileJobAction.ID, true);
            super.setEnabledAction(DeleteJobAction.ID, true);
            super.setEnabledAction(ModifyJobAction.ID, true);
            super.setEnabledAction(RunJobAction.ID, true);
        } else if (type == JobConstant.TYPE_JOB) {
            super.setEnabledAction(CreateJobUnitAction.ID, false);
            super.setEnabledAction(CreateJobNetAction.ID, false);
            super.setEnabledAction(CreateJobAction.ID, false);
            super.setEnabledAction(CreateFileJobAction.ID, false);
            super.setEnabledAction(DeleteJobAction.ID, true);
            super.setEnabledAction(ModifyJobAction.ID, true);
            super.setEnabledAction(RunJobAction.ID, true);
        } else if (type == JobConstant.TYPE_FILEJOB) {
            super.setEnabledAction(CreateJobUnitAction.ID, false);
            super.setEnabledAction(CreateJobNetAction.ID, false);
            super.setEnabledAction(CreateJobAction.ID, false);
            super.setEnabledAction(CreateFileJobAction.ID, false);
            super.setEnabledAction(DeleteJobAction.ID, true);
            super.setEnabledAction(ModifyJobAction.ID, true);
            super.setEnabledAction(RunJobAction.ID, true);
        } else {
            super.setEnabledAction(CreateJobUnitAction.ID, false);
            super.setEnabledAction(CreateJobNetAction.ID, false);
            super.setEnabledAction(CreateJobAction.ID, false);
            super.setEnabledAction(CreateFileJobAction.ID, false);
            super.setEnabledAction(DeleteJobAction.ID, false);
            super.setEnabledAction(ModifyJobAction.ID, false);
            super.setEnabledAction(RunJobAction.ID, false);
        }

    }

    /**
     * ジョブツリー用のコンポジットを返します。
     * 
     * @return ジョブツリー用のコンポジット
     */
    public JobTreeComposite getJobTreeComposite() {
        return m_jobTree;
    }

    /**
     * ジョブ[一覧]ビュー用のコンポジットを返します。
     * 
     * @return ジョブ[一覧]ビュー用のコンポジット
     */
    public JobListComposite getJobListComposite() {
        return m_jobList;
    }

    /**
     * ジョブツリーを表示します。
     */
    public void show() {
        m_sash.setMaximizedControl(null);
    }

    /**
     * ジョブツリーを非表示にします。
     */
    public void hide() {
        m_sash.setMaximizedControl(m_jobList);
    }
    
    /**
     * 選択ジョブツリーアイテムを返します。
     * 
     * @return JobTreeItem 選択されたジョブツリーアイテム
     */
    public JobTreeItem getSelectJobTreeItem() {
        JobTreeItem select = null;
        if (m_jobTree.getTree().isFocusControl()) {
            select = m_jobTree.getSelectItem();
        } else if (m_jobList.getTable().isFocusControl()) {
            select = m_jobList.getSelectJobTreeItem();
        }
        return select;
    }
    
    /**
     * コピー元ジョブツリーアイテムを取得します。
     * 
     * @return コピー元ジョブツリーアイテム
     */
    public JobTreeItem getCopyJobTreeItem() {
        return m_copyJobTreeItem;
    }
    
    /**
     * コピー元ジョブツリーアイテムを設定します。
     * 
     * @param copy コピー元ジョブツリーアイテム
     */
    public void setCopyJobTreeItem(JobTreeItem copy) {
        m_copyJobTreeItem = copy;
    }
    
    /**
     * ジョブツリーアイテムの更新フラグを返します。
     * 
     * @return 更新フラグ
     */
    public boolean isUpdate() {
        return m_update;
    }
    
    /**
     * ジョブツリーアイテムの更新フラグを設定します。
     * 
     * @param update 更新フラグ
     */
    public void setUpdate(boolean update) {
        m_update = update;
    }
}