/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.notify.action;

import java.rmi.AccessException;
import java.rmi.RemoteException;
import java.util.ArrayList;

import org.eclipse.jface.dialogs.MessageDialog;

import com.clustercontrol.HinemosUnknownException;
import com.clustercontrol.NotifyNotFoundException;
import com.clustercontrol.notify.bean.NotifyInfo;
import com.clustercontrol.notify.ejb.session.NotifyController;
import com.clustercontrol.notify.util.EjbConnectionManager;
import com.clustercontrol.util.Messages;

/**
 * 通知情報を取得するクライアント側アクションクラス<BR>
 * 
 * @version 2.2.0
 * @since 1.0.0
 */
public class GetNotify {

    /**
     * 通知情報を返します。<BR>
     * マネージャにSessionBean経由でアクセスします。
     * 
     * @param notifyId 取得対象の通知ID
     * @return 通知情報
     * @throws HinemosUnknownException 
     * @throws NotifyNotFoundException 
     * 
     * @see com.clustercontrol.notify.util.EjbConnectionManager
	 * @see com.clustercontrol.notify.ejb.session.NotifyController
	 * @see com.clustercontrol.notify.ejb.session.NotifyControllerBean#getNotify(java.lang.String)
     */
    public NotifyInfo getNotify(String notifyId) {

        NotifyController notify = EjbConnectionManager.getConnectionManager()
                .getNotifyController();

        NotifyInfo info = null;
        try {
        	info = notify.getNotify(notifyId);
        } catch (RemoteException e) {
			if(e instanceof AccessException){
				// アクセス権なしの場合、エラーダイアログを表示する
	            MessageDialog.openInformation(null, Messages.getString("message"),
	                    Messages.getString("message.accesscontrol.16"));
			}
        } catch (NotifyNotFoundException e) {
        } catch (HinemosUnknownException e) {
        }
        return info;
    }
    
    /**
     * 通知ID一覧を返します。<BR>
     * マネージャにSessionBean経由でアクセスします。
     * 
     * @return 通知ID一覧
     * @throws HinemosUnknownException 
     * @throws NotifyNotFoundException 
     * 
     * @see com.clustercontrol.notify.util.EjbConnectionManager
	 * @see com.clustercontrol.notify.ejb.session.NotifyController
	 * @see com.clustercontrol.notify.ejb.session.NotifyControllerBean#getNotifyIdList()
     */
    public ArrayList getNotifyIdList() {

        NotifyController notify = EjbConnectionManager.getConnectionManager()
                .getNotifyController();

        ArrayList records = null;
        try {
            records = notify.getNotifyIdList();
        } catch (RemoteException e) {
			if(e instanceof AccessException){
				// アクセス権なしの場合、エラーダイアログを表示する
	            MessageDialog.openInformation(null, Messages.getString("message"),
	                    Messages.getString("message.accesscontrol.16"));
			}
        } catch (NotifyNotFoundException e) {
        } catch (HinemosUnknownException e) {
        }
        return records;
    }
    
    /**
     * 通知情報一覧を返します。<BR>
     * マネージャにSessionBean経由でアクセスします。
     * 
     * @return 通知情報一覧
     * @throws HinemosUnknownException 
     * @throws NotifyNotFoundException 
     * 
     * @see com.clustercontrol.notify.util.EjbConnectionManager
	 * @see com.clustercontrol.notify.ejb.session.NotifyController
	 * @see com.clustercontrol.notify.ejb.session.NotifyControllerBean#getNotifyList()
     */
    public ArrayList getNotifyList(){

        NotifyController notify = EjbConnectionManager.getConnectionManager()
                .getNotifyController();

        ArrayList records = null;
        try {
            records = notify.getNotifyList();
        } catch (RemoteException e) {
			if(e instanceof AccessException){
				// アクセス権なしの場合、エラーダイアログを表示する
	            MessageDialog.openInformation(null, Messages.getString("message"),
	                    Messages.getString("message.accesscontrol.16"));
			}
        } catch (NotifyNotFoundException e) {
        } catch (HinemosUnknownException e) {
        }
        return records;
    }
    
    /**
     * 障害検知用通知情報一覧を返します。<BR>
     * マネージャにSessionBean経由でアクセスします。
     * 
     * @return 通知情報一覧
     * @throws HinemosUnknownException 
     * @throws NotifyNotFoundException 
     * 
     * @see com.clustercontrol.notify.util.EjbConnectionManager
	 * @see com.clustercontrol.notify.ejb.session.NotifyController
	 * @see com.clustercontrol.notify.ejb.session.NotifyControllerBean#getNotifyList()
     */
    public ArrayList getTroubleDetectionNotifyList(){

        NotifyController notify = EjbConnectionManager.getConnectionManager()
                .getNotifyController();

        ArrayList records = null;
        try {
            records = notify.getTroubleDetectionNotifyList();
        } catch (RemoteException e) {
			if(e instanceof AccessException){
				// アクセス権なしの場合、エラーダイアログを表示する
	            MessageDialog.openInformation(null, Messages.getString("message"),
	                    Messages.getString("message.accesscontrol.16"));
			}
        } catch (NotifyNotFoundException e) {
        } catch (HinemosUnknownException e) {
        }
        return records;
    }
}