/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.notify.composite;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Table;
import org.eclipse.swt.widgets.TableItem;

import com.clustercontrol.bean.YesNoConstant;
import com.clustercontrol.composite.CommonTableViewer;
import com.clustercontrol.notify.action.GetNotify;
import com.clustercontrol.notify.action.GetNotifyListTableDefine;
import com.clustercontrol.notify.bean.NotifyRelationInfo;
import com.clustercontrol.notify.bean.NotifyTableDefine;
import com.clustercontrol.notify.bean.NotifyTypeConstant;

/**
 * 通知一覧コンポジットクラス<BR>
 * 
 * @version 3.0.0
 * @since 2.0.0
 */
public class NotifyListComposite extends Composite {

    /** テーブルビューアー。 */
    private CommonTableViewer tableViewer = null;
    
    /***/
    private boolean isSelect = false;
    
    private int notifyIdType = 0;
    
    /**/
    private Collection<NotifyRelationInfo> notify;

    /**
	 * インスタンスを返します。
	 * <p>
	 * 初期処理を呼び出し、コンポジットを配置します。
	 * 
	 * @param parent 親のコンポジット
	 * @param style スタイル
	 * 
	 * @see org.eclipse.swt.SWT
	 * @see org.eclipse.swt.widgets.Composite#Composite(Composite parent, int style)
	 * @see #initialize()
	 */
    public NotifyListComposite(Composite parent, int style ){
        super(parent, style);

        this.initialize(false);
    }

    /**
	 * インスタンスを返します。
	 * <p>
	 * 初期処理を呼び出し、コンポジットを配置します。
	 * 
	 * @param parent 親のコンポジット
	 * @param style スタイル
	 * 
	 * @see org.eclipse.swt.SWT
	 * @see org.eclipse.swt.widgets.Composite#Composite(Composite parent, int style)
	 * @see #initialize()
	 */
    public NotifyListComposite(Composite parent, int style,boolean flg) {
        super(parent, style);

        this.initialize(flg);
    }
    
    public NotifyListComposite(Composite parent, int style,boolean flg, int notifyIdType) {
        super(parent, style);

        this.notifyIdType = notifyIdType;
        this.initialize(flg);
    }
    
    /**
     * コンポジットを配置します。
     * 
     * @see com.clustercontrol.notify.action.GetNotifyListTableDefine#get()
     * @see #update()
     */
    private void initialize(boolean flg) {
        GridLayout layout = new GridLayout(1, true);
        this.setLayout(layout);
        layout.marginHeight = 0;
        layout.marginWidth = 0;

        final Table table = new Table(this, SWT.MULTI | SWT.H_SCROLL | SWT.V_SCROLL
                | SWT.FULL_SELECTION);
        table.setHeaderVisible(true);
        table.setLinesVisible(true);

        GridData gridData = new GridData();
        gridData.horizontalAlignment = GridData.FILL;
        gridData.verticalAlignment = GridData.FILL;
        gridData.grabExcessHorizontalSpace = true;
        gridData.grabExcessVerticalSpace = true;
        table.setLayoutData(gridData);

        // テーブルビューアの作成
        this.tableViewer = new CommonTableViewer(table);
        this.tableViewer.createTableColumn(GetNotifyListTableDefine.get(),
        		NotifyTableDefine.SORT_COLUMN_INDEX,
        		NotifyTableDefine.SORT_ORDER);

        gridData = new GridData();
        gridData.horizontalAlignment = GridData.FILL;
        gridData.verticalAlignment = GridData.FILL;

        
        if(flg){
        	
        	isSelect =flg;
        
        /**テーブルのレコードを選択するリスナー*/
        table.addSelectionListener(new SelectionAdapter(){
        	  @Override
			public void widgetSelected(SelectionEvent e) {

        		ArrayList al;
        		//選択されたTableColumnを取得します。
        		TableItem[] ti = table.getSelection();	
        		String notifyId;
        				for (int i = 0; i<ti.length; i++){
        					al = (ArrayList)ti[i].getData();
        					if((Boolean)al.get(0)){
        						//YESならNO
        						al.set(NotifyTableDefine.SELECTION, YesNoConstant.BOOLEAN_NO);
        					}else{
        						//NOならYES
        						al.set(NotifyTableDefine.SELECTION, YesNoConstant.BOOLEAN_YES);
        		
        					}
        				}	
        				//チェックボックスが入るので、再描画。
		    			 tableViewer.refresh();
        	  }
        });
        }
        
        this.update();
    }

    /**
     * このコンポジットが利用するテーブルビューアーを返します。
     * 
     * @return テーブルビューアー
     */
    public CommonTableViewer getTableViewer() {
    	return this.tableViewer;
    }

    /**
     * コンポジットを更新します。<BR>
     * 通知一覧情報を取得し、テーブルビューアーにセットします。
     * 
     * @see com.clustercontrol.notify.action.GetNotify#getNotifyList()
     */
    @Override
	public void update() {

    	// 通知一覧をマネージャから取得
    	ArrayList<ArrayList> list = null;
    	ArrayList<Object> info ;
    	
    	switch (notifyIdType) {
    		case NotifyTypeConstant.NOTIFY_ID_TYPE_TROUBLE_DETECTION : 
    			list = new GetNotify().getTroubleDetectionNotifyList();
    			break;
//    		case NotifyTypeConstant.NOTIFY_ID_TYPE_SELFCHECK : 
//    			list = new GetNotify().getSelfCheckNotifyList();
//    			break;
    		default :
    			list = new GetNotify().getNotifyList();
    	}

    	if(notify == null){
    		//変更でない場合などはnotifyを初期化する。
    		notify = new ArrayList<NotifyRelationInfo>();
    	}

    	if(list == null)
    	{
    		//通知一覧に設定されている通知がない場合
    		list = new ArrayList<ArrayList>();

    	}else if(isSelect){

    		//素の通知一覧ではなく、監視から選択可能な通知一覧の場合

    		String tableNotifyId;
    		boolean flg = false;

    		//変更の通知を通知一覧のチェックボックスに表示させる。

    		Iterator<NotifyRelationInfo> it = notify.iterator();
    		NotifyRelationInfo nri = null ;

    		while(it.hasNext()){

    			nri = it.next();
    			nri.setNotifyGroupId(null);
    			flg = false;
    			
    			for(int i = 0; i < list.size(); i++ ){
    				info = list.get(i);
    				tableNotifyId = (String)info.get(NotifyTableDefine.NOTIFY_ID);


    				if(tableNotifyId.equals(nri.getNotifyId())){
    					
    					info.set(NotifyTableDefine.SELECTION, YesNoConstant.BOOLEAN_YES);
    					flg=true;
    				}
    			}
    		
    		if(!flg){
    			//通知一覧になければ、設定済み通知からも削除
    			if(nri != null){
    				notify.remove(nri);
    			}
    		}
    		}

    	}    	
    	// テーブル更新
    	this.tableViewer.setInput(list);
    }
    
  
    /**
     * 監視に設定されている通知情報をセットします。
     * 
     * @param notify
     */
    public void setSlectNotify(Collection<NotifyRelationInfo> notify){
    	
    	if(notify != null){
    		this.notify =  new ArrayList<NotifyRelationInfo>();
    	}
    	this.notify = notify;
    }

    /**
     * 監視に設定する通知情報を返します。
     * 
     * @return 通知情報のコレクション
     */
	public Collection<NotifyRelationInfo> getSelectNotify(){
		return notify;
	}
    
	/**
	 * OKが押されたときに監視に設定する通知情報を
	 * 生成します。
	 * 
	 */
	public boolean makeNotifyData(){

		TableItem[] ti = this.tableViewer.getTable().getItems();
		ArrayList<Object> al;
		Collection<NotifyRelationInfo> ct = new ArrayList<NotifyRelationInfo>();;

		for (int i = 0; i<ti.length; i++){
			al = (ArrayList<Object>)ti[i].getData();
			
			if((Boolean)al.get(NotifyTableDefine.SELECTION)){

				NotifyRelationInfo nri = new NotifyRelationInfo(
						null,
						(String)al.get(NotifyTableDefine.NOTIFY_ID),
						(Integer)al.get(NotifyTableDefine.NOTIFY_TYPE),
						0);
				
				ct.add(nri);
			}
		}
		
		// 通知情報の設定
		notify.clear();
		notify.addAll(ct);
		return true;
		
//		// ステータス通知とイベント通知が2種類以上選択されていないかチェック
//		Iterator<NotifyRelationInfo> itr = ct.iterator();
//		int statusCount = 0;
//		int eventCount = 0;
//		while(itr.hasNext()){
//
//			NotifyRelationInfo info = itr.next();
//			if(info.getNotifyType() == NotifyTypeConstant.TYPE_STATUS){
//				statusCount++;
//			}
//			else if(info.getNotifyType() == NotifyTypeConstant.TYPE_EVENT){
//				eventCount++;
//			}
//		}
//		
//		if(statusCount < 2 && eventCount < 2){
//			// 通知情報のリフレッシュ
//			notify.clear();
//			notify.addAll(ct);
//			return true;
//		}
//		else{
//			return false;
//		}
		
	}
	
    /**
     * 選択された行の通知IDを取得する
     * 
     * @return 
     */
    public ArrayList<String> getSelectionData() {
    	
    	ArrayList<String> data = new ArrayList<String>();
    	
    	//選択されたアイテムを取得
    	StructuredSelection selection = 
    		(StructuredSelection)tableViewer.getSelection();
    	List list = selection.toList();
    	
    	if (list != null) {
    		
    		for(int index = 0; index < list.size(); index++){
    			
    			ArrayList info = (ArrayList)list.get(index);
    			if (info != null && info.size() > 0) {
    				String notifyId = (String)info.get(NotifyTableDefine.NOTIFY_ID);
    				data.add(notifyId);
    			}
    		}
    	}
    	
    	return data;
    }
}