/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
 */

package com.clustercontrol.notify.dialog;

import java.util.ArrayList;

import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.graphics.Color;
import org.eclipse.swt.graphics.RGB;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Group;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Text;

import com.clustercontrol.bean.DataRangeConstant;
import com.clustercontrol.bean.PriorityColorConstant;
import com.clustercontrol.bean.PriorityConstant;
import com.clustercontrol.bean.ValidConstant;
import com.clustercontrol.composite.StringVerifyListener;
import com.clustercontrol.composite.StyledTextComposite;
import com.clustercontrol.dialog.ValidateResult;
import com.clustercontrol.notify.action.AddNotify;
import com.clustercontrol.notify.action.GetNotify;
import com.clustercontrol.notify.action.ModifyNotify;
import com.clustercontrol.notify.bean.NotifyInfo;
import com.clustercontrol.notify.bean.NotifyInfoDetail;
import com.clustercontrol.notify.bean.NotifyCommandInfo;
import com.clustercontrol.notify.bean.NotifySubstitutionParameterConstant;
import com.clustercontrol.notify.ejb.entity.NotifyCommandInfoData;
import com.clustercontrol.util.Messages;

/**
 * 通知（コマンド）作成・変更ダイアログクラス<BR>
 * 
 * @version 3.0.0
 * @since 3.0.0
 */
public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
	// これらのカラム数の合計は、15でないといけない。
	
	/** カラム数（重要度）。 */
	private static final int WIDTH_PRIORITY = 1;

	/** カラム数（チェックボックス）。 */
	private static final int WIDTH_CHECK = 1;

	/** カラム数（ユーザ入力欄）。 */
	private static final int WIDTH_COMMAND_USER = 2;
	
	/** カラム数（コマンド入力欄）。 */
	private static final int WIDTH_COMMAND_TEXT = 10;

	/** カラム数（空欄）。 */
	private static final int WIDTH_BLANK = 1;

	// ----- instance フィールド ----- //

	/**
	 * 通知タイプ
	 * 
	 * @see com.clustercontrol.bean.NotifyTypeConstant
	 */
	private final int TYPE_COMMAND = 5;

	/** 入力値を保持するオブジェクト。 */
	private NotifyInfo inputData = null;

	/** 入力値の正当性を保持するオブジェクト。 */
	private ValidateResult validateResult = null;

	/** 実行（重要度：通知） チェックボックス。 */
	private Button m_checkExecInfo = null;
	/** 実行（重要度：警告） チェックボックス。 */
	private Button m_checkExecWarning = null;
	/** 実行（重要度：危険） チェックボックス。 */
	private Button m_checkExecCritical = null;
	/** 実行（重要度：不明） チェックボックス。 */
	private Button m_checkExecUnknown = null;

	/** 実効ユーザ（重要度：通知） テキスト。 */
	private Text m_textUserInfo = null;
	/** 実効ユーザ（重要度：警告） テキスト。 */
	private Text m_textUserWarning = null;
	/** 実効ユーザ（重要度：危険） テキスト。 */
	private Text m_textUserCritical = null;
	/** 実効ユーザ（重要度：不明） テキスト。 */
	private Text m_textUserUnknown = null;

	/** 実行コマンド（重要度：通知） テキスト。 */
	private StyledTextComposite m_textCommandInfo = null;
	/** 実行コマンド（重要度：警告） テキスト。 */
	private StyledTextComposite m_textCommandWarning = null;
	/** 実行コマンド（重要度：危険） テキスト。 */
	private StyledTextComposite m_textCommandCritical = null;
	/** 実行コマンド（重要度：不明） テキスト。 */
	private StyledTextComposite m_textCommandUnknown = null;

	// ----- コンストラクタ ----- //

	/**
	 * 作成用ダイアログのインスタンスを返します。
	 * 
	 * @param parent
	 *            親のシェルオブジェクト
	 */
	public NotifyCommandCreateDialog(Shell parent) {
		super(parent);
	}
	
	public NotifyCommandCreateDialog(Shell parent, int notifyIdType) {
		super(parent, notifyIdType);
	}

	/**
	 * 変更用ダイアログのインスタンスを返します。
	 * 
	 * @param parent
	 *            親のシェルオブジェクト
	 * @param notifyId
	 *            変更する通知情報の通知ID
	 * @param referenceFlg
	 *            参照フラグ（参照のみで変更不可の場合、<code> true </code>）
	 */
	public NotifyCommandCreateDialog(Shell parent, String notifyId,
			boolean referenceFlg) {
		super(parent, notifyId, referenceFlg);
	}

	// ----- instance メソッド ----- //

	/**
	 * ダイアログエリアを生成します。
	 * 
	 * @param parent
	 *            親のコンポジット
	 * 
	 * @see com.clustercontrol.notify.dialog.NotifyBasicCreateDialog#customizeDialog(Composite)
	 * @see com.clustercontrol.notify.action.GetNotify#getNotify(String)
	 * @see #setInputData(NotifyInfo)
	 */
	@Override
	protected void customizeDialog(Composite parent) {

		super.customizeDialog(parent);

		// 通知IDが指定されている場合、その情報を初期表示する。
		NotifyInfo info = null;
		if (this.notifyId != null) {
			info = new GetNotify().getNotify(this.notifyId);
		} else {
			info = new NotifyInfo();
		}
		this.setInputData(info);

	}

	/**
	 * 親のクラスから呼ばれ、各通知用のダイアログエリアを生成します。
	 * 
	 * @param parent
	 *            親のコンポジット
	 * 
	 * @see com.clustercontrol.notify.dialog.NotifyBasicCreateDialog#customizeDialog(Composite)
	 */
	@Override
	protected void customizeSettingDialog(Composite parent) {
		final Shell shell = this.getShell();

		// タイトル
		shell.setText(Messages.getString("dialog.notify.command.create.modify"));

		// 変数として利用されるラベル
		Label label = null;
		// 変数として利用されるグリッドデータ
		GridData gridData = null;

		// レイアウト
		GridLayout layout = new GridLayout(1, true);
		layout.marginWidth = 10;
		layout.marginHeight = 10;
		layout.numColumns = 15;
		parent.setLayout(layout);

		/*
		 * コマンド実行
		 */
		label = new Label(parent, SWT.NONE);
		gridData = new GridData();
		gridData.horizontalSpan = 15;
		gridData.horizontalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		label.setLayoutData(gridData);
		label.setText(Messages.getString("notifies.command") + " : ");

		/*
		 * 大グループ
		 */
		// コマンド設定グループ
		Group groupComamnd = new Group(parent, SWT.NONE);
		layout = new GridLayout(1, true);
		layout.marginWidth = 5;
		layout.marginHeight = 5;
		layout.numColumns = 15;
		groupComamnd.setLayout(layout);
		gridData = new GridData();
		gridData.horizontalSpan = 15;
		gridData.horizontalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		groupComamnd.setLayoutData(gridData);

		/*
		 * 重要度 ごとの設定
		 */
		// ラベル（重要度）
		label = new Label(groupComamnd, SWT.NONE);
		gridData = new GridData();
		gridData.horizontalSpan = WIDTH_PRIORITY;
		gridData.horizontalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		label.setLayoutData(gridData);
		label.setText(Messages.getString("priority"));

		// ラベル（実行）
		label = new Label(groupComamnd, SWT.NONE);
		gridData = new GridData();
		gridData.horizontalSpan = WIDTH_CHECK;
		gridData.horizontalAlignment = GridData.CENTER;
		gridData.grabExcessHorizontalSpace = true;
		label.setLayoutData(gridData);
		label.setText(Messages.getString("notify.attribute"));

		// ラベル（ユーザ入力欄）
		label = new Label(groupComamnd, SWT.NONE);
		gridData = new GridData();
		gridData.horizontalSpan = WIDTH_COMMAND_USER;
		gridData.horizontalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		label.setLayoutData(gridData);
		label.setText(Messages.getString("effective.user"));
		
		// ラベル（コマンド入力欄）
		label = new Label(groupComamnd, SWT.NONE);
		gridData = new GridData();
		gridData.horizontalSpan = WIDTH_COMMAND_TEXT;
		gridData.horizontalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		label.setLayoutData(gridData);
		label.setText(Messages.getString("command"));

		// ラベル（空欄）
		label = new Label(groupComamnd, SWT.NONE);
		gridData = new GridData();
		gridData.horizontalSpan = WIDTH_BLANK;
		gridData.horizontalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		label.setLayoutData(gridData);

		// 重要度：通知
		label = this.getLabelPriority(groupComamnd, Messages.getString("info"),
				PriorityColorConstant.COLOR_INFO);
		this.m_checkExecInfo = this.getCheckBox(groupComamnd);
		this.m_textUserInfo = this.getTextUser(groupComamnd);
		this.m_textCommandInfo = this.getTextCommand(groupComamnd);

		this.m_checkExecInfo.addSelectionListener(new SelectionAdapter() {
			@Override
			public void widgetSelected(SelectionEvent e) {
				setEnabled(m_checkExecInfo.getSelection(),
						m_textUserInfo, m_textCommandInfo);
			}
		});
		// ラベル（空欄）
		label = new Label(groupComamnd, SWT.NONE);
		gridData = new GridData();
		gridData.horizontalSpan = WIDTH_BLANK;
		gridData.horizontalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		label.setLayoutData(gridData);

		// 重要度：警告
		label = this.getLabelPriority(groupComamnd, Messages
				.getString("warning"), PriorityColorConstant.COLOR_WARNING);
		this.m_checkExecWarning = this.getCheckBox(groupComamnd);
		this.m_textUserWarning = this.getTextUser(groupComamnd);
		this.m_textCommandWarning = this.getTextCommand(groupComamnd);

		this.m_checkExecWarning.addSelectionListener(new SelectionAdapter() {
			@Override
			public void widgetSelected(SelectionEvent e) {
				setEnabled(m_checkExecWarning.getSelection(),
						m_textUserWarning, m_textCommandWarning);
			}
		});

		// ラベル（空欄）
		label = new Label(groupComamnd, SWT.NONE);
		gridData = new GridData();
		gridData.horizontalSpan = WIDTH_BLANK;
		gridData.horizontalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		label.setLayoutData(gridData);

		// 重要度：危険
		label = this.getLabelPriority(groupComamnd, Messages
				.getString("critical"), PriorityColorConstant.COLOR_CRITICAL);
		this.m_checkExecCritical = this.getCheckBox(groupComamnd);
		this.m_textUserCritical = this.getTextUser(groupComamnd);
		this.m_textCommandCritical = this.getTextCommand(groupComamnd);

		this.m_checkExecCritical
				.addSelectionListener(new SelectionAdapter() {
					@Override
					public void widgetSelected(SelectionEvent e) {
						setEnabled(m_checkExecCritical.getSelection(),
								m_textUserCritical, m_textCommandCritical);
					}
				});
		// ラベル（空欄）
		label = new Label(groupComamnd, SWT.NONE);
		gridData = new GridData();
		gridData.horizontalSpan = WIDTH_BLANK;
		gridData.horizontalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		label.setLayoutData(gridData);

		// 重要度：不明
		label = this.getLabelPriority(groupComamnd, Messages
				.getString("unknown"), PriorityColorConstant.COLOR_UNKNOWN);
		this.m_checkExecUnknown = this.getCheckBox(groupComamnd);
		this.m_textUserUnknown = this.getTextUser(groupComamnd);
		this.m_textCommandUnknown = this.getTextCommand(groupComamnd);

		this.m_checkExecUnknown
				.addSelectionListener(new SelectionAdapter() {
					@Override
					public void widgetSelected(SelectionEvent e) {
						setEnabled(m_checkExecUnknown.getSelection(),
								m_textUserUnknown, m_textCommandUnknown);
					}
				});
		
		// ラベル（空欄）
		label = new Label(groupComamnd, SWT.NONE);
		gridData = new GridData();
		gridData.horizontalSpan = WIDTH_BLANK;
		gridData.horizontalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		label.setLayoutData(gridData);

	}

	/**
	 * 入力値を保持した通知情報を返します。
	 * 
	 * @return 通知情報
	 */
	@Override
	public NotifyInfo getInputData() {
		return this.inputData;
	}

	/**
	 * 引数で指定された通知情報の値を、各項目に設定します。
	 * 
	 * @param notify
	 *            設定値として用いる通知情報
	 */
	@Override
	protected void setInputData(NotifyInfo notify) {

		this.inputData = notify;

		// 通知基本情報
		super.m_notifyBasic.setInputData(notify);

		// 初回通知情報
		super.m_notifyInitial.setInputData(notify);
		
		// 抑制情報
		super.m_notifyInhibition.setInputData(notify);

		// コマンド情報
		if (notify.getNotifyType() != null
				&& notify.getNotifyType().intValue() == TYPE_COMMAND
				&& notify.getNotifyInfoDetail() != null) {
			ArrayList<NotifyInfoDetail> list = notify.getNotifyInfoDetail();
			if (list != null) {
				for (int index = 0; index < list.size(); index++) {
					NotifyCommandInfo info = (NotifyCommandInfo) list.get(index);
					if (info != null) {
						// 通知の場合
						if (PriorityConstant.TYPE_INFO == info.getPriority()) {
							this.setInputDataDetail(
									info,
									this.m_checkExecInfo,
									this.m_textUserInfo,
									this.m_textCommandInfo);
						}
						// 警告の場合
						else if (PriorityConstant.TYPE_WARNING == info
								.getPriority()) {
							this.setInputDataDetail(
									info,
									this.m_checkExecWarning,
									this.m_textUserWarning,
									this.m_textCommandWarning);
						}
						// 危険の場合
						else if (PriorityConstant.TYPE_CRITICAL == info
								.getPriority()) {
							this.setInputDataDetail(
									info,
									this.m_checkExecCritical,
									this.m_textUserCritical,
									this.m_textCommandCritical);
						}
						// 不明の場合
						else if (PriorityConstant.TYPE_UNKNOWN == info
								.getPriority()) {
							this.setInputDataDetail(
									info,
									this.m_checkExecUnknown,
									this.m_textUserUnknown,
									this.m_textCommandUnknown);
						}
					}
				}
			}
		}

		// 有効／無効
		if (notify.getValidFlg() != null
				&& notify.getValidFlg() == ValidConstant.TYPE_INVALID) {
			this.m_confirmValid.setSelection(false);
		} else {
			this.m_confirmValid.setSelection(true);
		}

		// 入力制御
		if (this.referenceFlg) {
			this.setEnabled(false);
		} else {
			this.setEnabled(true);
		}
	}

	/**
	 * 引数で指定された通知ステータス情報の値を、各項目に設定します。
	 * 
	 * @param info
	 *            設定値として用いる通知コマンド情報
	 * @param checkBox
	 *            実行チェックボックス
	 * @param textCommand
	 *            コマンドテキストボックス
	 * @param checkExecInhibition
	 *            抑制チェックボックス
	 */
	private void setInputDataDetail(
			NotifyCommandInfo info,
			Button checkBox,
			Text textUser,
			StyledTextComposite textCommand) {
		// コマンド通知
		if (info.getValidFlg() != null
				&& info.getValidFlg().intValue() == ValidConstant.TYPE_VALID) {
			checkBox.setSelection(true);
		}
		// 実効ユーザ
		if (info.getCommand() != null) {
			textUser.setText(info.getEffectiveUser());
		}
		// 実行コマンド
		if (info.getCommand() != null) {
			textCommand.setText(info.getCommand());
		}
	}

	/**
	 * 入力値を設定した通知情報を返します。<BR>
	 * 入力値チェックを行い、不正な場合は<code>null</code>を返します。
	 * 
	 * @return 通知情報
	 * 
	 * @see #createInputData(ArrayList, int, Button, Text, Button)
	 * @see #setValidateResult(String, String)
	 */
	@Override
	protected NotifyInfo createInputData() {
		NotifyInfo info = new NotifyInfo();

		// 通知タイプの設定
		info.setNotifyType(TYPE_COMMAND);

		// 通知基本情報
		validateResult = super.m_notifyBasic.createInputData(info,
				this.notifyId);
		if (validateResult != null) {
			return null;
		}
		
		// 初回通知情報
		validateResult = super.m_notifyInitial.createInputData(info);
		if(validateResult != null){
			return null;
		}

		// 抑制情報
		validateResult = super.m_notifyInhibition.createInputData(info);
		if (validateResult != null) {
			return null;
		}

		// コマンド情報
		// 各重要度で１つも通知が選択されていない場合はエラー
		if (!this.m_checkExecInfo.getSelection()
				&& !this.m_checkExecWarning.getSelection()
				&& !this.m_checkExecCritical.getSelection()
				&& !this.m_checkExecUnknown.getSelection()) {
			this.setValidateResult(Messages.getString("message.hinemos.1"),
					Messages.getString("message.notify.13"));
			return null;
		}

		ArrayList<NotifyInfoDetail> list = new ArrayList<NotifyInfoDetail>();

		list = this.createInputData(
				list,
				info.getNotifyId(),
				PriorityConstant.TYPE_INFO,
				this.m_checkExecInfo,
				this.m_textUserInfo,
				this.m_textCommandInfo);
		list = this.createInputData(
				list, 
				info.getNotifyId(),
				PriorityConstant.TYPE_WARNING,
				this.m_checkExecWarning, 
				this.m_textUserWarning,
				this.m_textCommandWarning);
		list = this.createInputData(
				list, 
				info.getNotifyId(),
				PriorityConstant.TYPE_CRITICAL,
				this.m_checkExecCritical,
				this.m_textUserCritical,
				this.m_textCommandCritical);
		list = this.createInputData(
				list, 
				info.getNotifyId(),
				PriorityConstant.TYPE_UNKNOWN,
				this.m_checkExecUnknown, 
				this.m_textUserUnknown,
				this.m_textCommandUnknown);

		if (list == null) {
			return null;
		}
		info.setNotifyInfoDetail(list);

		// 有効/無効
		if (this.m_confirmValid.getSelection()) {
			info.setValidFlg(ValidConstant.TYPE_VALID);
		} else {
			info.setValidFlg(ValidConstant.TYPE_INVALID);
		}

		return info;
	}

	/**
	 * 入力値を設定した通知イベント情報を返します。<BR>
	 * 入力値チェックを行い、不正な場合は<code>null</code>を返します。
	 * 
	 * @return 通知コマンド情報
	 * 
	 * @see #setValidateResult(String, String)
	 */
	protected ArrayList<NotifyInfoDetail> createInputData(
			ArrayList<NotifyInfoDetail> list,
			String notifyId,
			int priority,
			Button checkBox,
			Text textUser,
			StyledTextComposite textCommand) {

		if (list == null)
			return null;

		NotifyCommandInfoData command = new NotifyCommandInfoData();
		// 環境変数を読み込むか否かのフラグ。デフォルトは有効とする。
		command.setSetEnvironment(ValidConstant.TYPE_VALID);

		// 通知IDを設定
		command.setNotifyId(notifyId);
		
		// 重要度
		command.setPriority(priority);
		// 実行チェックボックス
		if (checkBox.getSelection()) {
			command.setValidFlg(new Integer(ValidConstant.TYPE_VALID));
		} else {
			command.setValidFlg(new Integer(ValidConstant.TYPE_INVALID));
		}
		// 実効ユーザ
		if (textUser.getText() != null
				&& !"".equals((textUser.getText()).trim())) {
			command.setEffectiveUser(textUser.getText());
		} else {
			if (checkBox.getSelection()) {
				this.setValidateResult(Messages.getString("message.hinemos.1"),
						Messages.getString("message.notify.31"));
				return null;
			}
		}
		
		// タイムアウト値を設定（GUI上からは設定できない）
		command.setTimeout(15000l);
		
		// 実行コマンド
		if (textCommand.getText() != null
				&& !"".equals((textCommand.getText()).trim())) {
			command.setCommand(textCommand.getText());
		} else {
			if (checkBox.getSelection()) {
				this.setValidateResult(Messages.getString("message.hinemos.1"),
						Messages.getString("message.notify.32"));
				return null;
			}
		}

		list.add(command);
		return list;
	}

	/**
	 * 入力値チェックをします。
	 * 
	 * @return 検証結果
	 */
	@Override
	protected ValidateResult validate() {
		// 入力値生成
		this.inputData = this.createInputData();

		if (this.inputData != null) {
			return super.validate();
		} else {
			return validateResult;
		}
	}

	/**
	 * 入力値をマネージャに登録します。
	 * 
	 * @return true：正常、false：異常
	 * 
	 * @see com.clustercontrol.dialog.CommonDialog#action()
	 */
	@Override
	protected boolean action() {
		boolean result = false;

		NotifyInfo info = this.getInputData();
		if (info != null) {
			if (this.notifyId == null) {
				// 作成の場合
				result = new AddNotify().add(info);
			} else {
				// 変更の場合
				result = new ModifyNotify().modify(info);
			}
		}

		return result;
	}

	/**
	 * ＯＫボタンのテキストを返します。
	 * 
	 * @return ＯＫボタンのテキスト
	 */
	@Override
	protected String getOkButtonText() {
		return Messages.getString("ok");
	}

	/**
	 * キャンセルボタンのテキストを返します。
	 * 
	 * @return キャンセルボタンのテキスト
	 */
	@Override
	protected String getCancelButtonText() {
		return Messages.getString("cancel");
	}

	/**
	 * コンポジットの選択可/不可を設定します。
	 * 
	 * @param enable
	 *            選択可の場合、<code> true </code>
	 */
	@Override
	protected void setEnabled(boolean enable) {

		super.m_notifyBasic.setEnabled(enable);
		super.m_notifyInhibition.setEnabled(enable);

		this.setEnabledDetails(enable);
	}

	/**
	 * コマンド通知の通知関連コンポジットの選択可/不可を設定します。
	 * 
	 * @param enable
	 *            選択可の場合、<code> true </code>
	 * 
	 * @see #setEnabledDetail(boolean, Button, Text, Button)
	 */
	private void setEnabledDetails(boolean enable) {

		// 通知関連
		this.setEnabledDetail(enable,this.m_checkExecInfo,
				this.m_textUserInfo, this.m_textCommandInfo);
		this.setEnabledDetail(enable, this.m_checkExecWarning,
				this.m_textUserWarning, this.m_textCommandWarning);
		this.setEnabledDetail(enable, this.m_checkExecCritical,
				this.m_textUserCritical, this.m_textCommandCritical);
		this.setEnabledDetail(enable, this.m_checkExecUnknown,
				this.m_textUserUnknown, this.m_textCommandUnknown);
	}

	/**
	 * コマンド通知のコンポジットの選択可/不可を設定します。
	 * 
	 * @param enable
	 *            選択可の場合、<code> true </code>
	 * @param checkBox
	 *            実行チェックボックス
	 * @param textCommand
	 *            実行コマンドテキストボックス
	 * @param checkExecInhibition
	 *            抑制チェックボックス
	 */
	private void setEnabledDetail(boolean enable, Button checkBox,
			Text textUser, StyledTextComposite textCommand) {

		if (enable) {
			checkBox.setEnabled(true);

			textUser.setEnabled(checkBox.getSelection());
			textCommand.setEnabled(checkBox.getSelection());

		} else {
			checkBox.setEnabled(false);

			textUser.setEnabled(false);
			textCommand.setEnabled(false);

		}
	}

	/**
	 * 引数で指定されたコンポジットの選択可/不可を設定します。
	 * 
	 * @param enabled
	 *            選択可の場合、</code> true </code>
	 * @param textCommand
	 *            設定対象の実行コマンドテキストボックス
	 * @param checkInhibitionFlg
	 *            設定対象の抑制チェックボックス
	 */
	public void setEnabled(boolean enabled, Text textUser,
			StyledTextComposite textCommand) {
		textUser.setEnabled(enabled);
		textCommand.setEnabled(enabled);
	}

	/**
	 * 無効な入力値の情報を設定します。
	 * 
	 * @param id
	 *            ID
	 * @param message
	 *            メッセージ
	 */
	@Override
	protected void setValidateResult(String id, String message) {

		this.validateResult = new ValidateResult();
		this.validateResult.setValid(false);
		this.validateResult.setID(id);
		this.validateResult.setMessage(message);
	}

	/**
	 * ボタンを生成します。<BR>
	 * 参照フラグが<code> true </code>の場合は閉じるボタンを生成し、<code> false </code>の場合は、デフォルトのボタンを生成します。
	 * 
	 * @param parent
	 *            ボタンバーコンポジット
	 * 
	 * @see #createButtonsForButtonBar(Composite)
	 */
	@Override
	protected void createButtonsForButtonBar(Composite parent) {

		if (!this.referenceFlg) {
			super.createButtonsForButtonBar(parent);
		} else {
			// 閉じるボタン
			this.createButton(parent, IDialogConstants.CANCEL_ID,
					IDialogConstants.CLOSE_LABEL, false);
		}
	}

	/**
	 * 重要度のラベルを返します。
	 * 
	 * @param parent
	 *            親のコンポジット
	 * @param text
	 *            ラベルに表示するテキスト
	 * @param background
	 *            ラベルの背景色
	 * @return 生成されたラベル
	 */
	protected Label getLabelPriority(Composite parent, String text,
			Color background) {

		// ラベル（重要度）
		Label label = new Label(parent, SWT.NONE);
		GridData gridData = new GridData();
		gridData.horizontalSpan = WIDTH_PRIORITY;
		gridData.horizontalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		label.setLayoutData(gridData);
		label.setText(text + " : ");
		label.setBackground(background);

		return label;
	}

	/**
	 * 実行チェックボックスを返します。
	 * 
	 * @param parent
	 *            親のコンポジット
	 * @return 生成されたチェックボックス
	 */
	protected Button getCheckBox(Composite parent) {

		// チェックボックス（実行）
		Button button = new Button(parent, SWT.CHECK);
		GridData gridData = new GridData();
		gridData.horizontalSpan = WIDTH_CHECK;
		gridData.horizontalAlignment = GridData.CENTER;
		gridData.grabExcessHorizontalSpace = true;
		button.setLayoutData(gridData);

		return button;
	}

	/**
	 * 実行コマンド入力欄のテキストボックスを返します。 テキストボックスはカスタマイズされたもので、置換文字列は青色で表示されます。
	 * 
	 * @param parent
	 *            親のインスタンス
	 * @return 生成されたテキストボックス
	 */
	protected Text getTextUser(Composite parent) {

		// テキスト（送信先（セミコロン区切り））
		Text text = new Text(parent, SWT.BORDER);
		GridData gridData = new GridData();
		gridData.horizontalSpan = WIDTH_COMMAND_USER;
		gridData.horizontalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		text.setLayoutData(gridData);
		text.addVerifyListener(new StringVerifyListener(
				DataRangeConstant.VARCHAR_64));

		return text;
	}

	/**
	 * 実行コマンド入力欄のテキストボックスを返します。 テキストボックスはカスタマイズされたもので、置換文字列は青色で表示されます。
	 * 
	 * @param parent
	 *            親のインスタンス
	 * @return 生成されたテキストボックス
	 */
	protected StyledTextComposite getTextCommand(Composite parent) {

		// テキスト（送信先（セミコロン区切り））
		StyledTextComposite text = new StyledTextComposite(parent, SWT.BORDER);
		GridData gridData = new GridData();
		gridData.horizontalSpan = WIDTH_COMMAND_TEXT;
		gridData.horizontalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		text.setLayoutData(gridData);

		text.setColor(new Color(parent.getDisplay(), new RGB(0, 0, 255)));
		text
				.setKeywords(NotifySubstitutionParameterConstant
						.getParameterList());
		text.setInputUpper(DataRangeConstant.VARCHAR_1024);

		return text;
	}

//	/**
//	 * コマンド実行の抑制のチェックボックスを返します。
//	 * 
//	 * @param parent
//	 *            親のコンポジット
//	 * @return 生成されたチェックボックス
//	 */
//	protected Button getCheckExecInhibition(Composite parent) {
//
//		// チェックボックス（抑制する）
//		Button button = new Button(parent, SWT.CHECK);
//		GridData gridData = new GridData();
//		gridData.horizontalSpan = WIDTH_INHIBITION_FLG;
//		gridData.horizontalAlignment = GridData.CENTER;
//		gridData.grabExcessHorizontalSpace = true;
//		button.setLayoutData(gridData);
//
//		return button;
//	}

}