/*

 Copyright (C) 2006 NTT DATA Corporation

 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 */

package com.clustercontrol.performance.monitor.action;

import java.rmi.AccessException;
import java.rmi.RemoteException;
import java.util.ArrayList;

import org.eclipse.jface.dialogs.MessageDialog;

import com.clustercontrol.HinemosUnknownException;
import com.clustercontrol.MonitorNotFoundException;
import com.clustercontrol.monitor.run.bean.MonitorInfo;
import com.clustercontrol.performance.monitor.util.EjbConnectionManager;
import com.clustercontrol.performance.monitor.ejb.session.MonitorPerfController;
import com.clustercontrol.util.Messages;

/**
 * リソース監視を取得するクラス
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class GetPerformance {

    /**
     * 閾値監視情報を返します。
     * 
     * @param monitorId 状態監視ID
     * @return 閾値監視情報
     */
    public MonitorInfo getPerformance(String monitorId) {

    	MonitorPerfController ctr = EjbConnectionManager.getConnectionManager().getMonitorPerfController();

    	MonitorInfo info = null;
        try {
        	info = ctr.getPerformance(monitorId);
        } catch (RemoteException e) {
			if(e instanceof AccessException){
				// アクセス権なしの場合、エラーダイアログを表示する
	            MessageDialog.openInformation(null, Messages.getString("message"),
	                    Messages.getString("message.accesscontrol.16"));
			}
        } catch (MonitorNotFoundException e) {
		} catch (HinemosUnknownException e) {
		}
        return info;
    }
    
    /**
     * 閾値監視一覧を返します。
     * 
     * @return 閾値監視一覧
     */
    public ArrayList<MonitorInfo> getPerformanceList() {

    	MonitorPerfController ctr = EjbConnectionManager.getConnectionManager()
                .getMonitorPerfController();

        ArrayList<MonitorInfo> records = null;
        try {
            records = ctr.getPerformanceList();
        } catch (RemoteException e) {
			if(e instanceof AccessException){
				// アクセス権なしの場合、エラーダイアログを表示する
	            MessageDialog.openInformation(null, Messages.getString("message"),
	                    Messages.getString("message.accesscontrol.16"));
			}
        } catch (MonitorNotFoundException e) {
		} catch (HinemosUnknownException e) {
		}
        return records;
    }
}