/*
 
 Copyright (C) 2006 NTT DATA Corporation
 
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 */

package com.clustercontrol.performance.util;

//FIXME クラス全体に配列が多用されており解読が困難
/**
 * リアルタイムグラフの４つのグラフの情報を個々に保持するクラス
 * 
 * @version 1.0
 * @since 1.0
 */
public class RealtimeCollectorItemInfo extends RealtimeCollectorInfo {
	private int graphNum = 4;
	
	private int itemNum = 0;
	
	private String itemInfo[][] = null;

	// ダイアログ操作用 
	private String itemInfoForDialog[][] = null;

	private String itemInfoForCollector[][] = null;
	
	private boolean itemInfoBoolean[][] = null;
	// ダイアログ操作用 
	private boolean itemInfoForDialogBoolean[][] = null;

	private boolean itemInfoForCollectorBoolean[][] = null;

	private boolean isCollect[][] = null;

	private boolean hasDevice[][] = null;

    /**
     * コンストラクター
     * 
     * @param watchItem
     */
    public RealtimeCollectorItemInfo() {
        super();
        
        // 行数：グラフ表示の最大数。現行仕様は4で固定。
        // 列数：データの属性
        //			SelectedScope:スコープ代表値
        //			SubScope:サブスコープ値
        //			Detail:スコープ内訳値
        //			NonDisplay:非表示
        //				暫定仕様。ダイアログ画面でデータ項目が固定のバージョン用。
        //				将来はデータ項目を選択可能にすることを視野にいれる。
        
        // 下記の4について、
        // itemCode, displayType, displayName, displayFormの4つ。
        // 配列にするのは激しく微妙…。
        itemInfo = new String[graphNum][4];
        itemInfoForDialog = new String[graphNum][4];

      itemInfoBoolean = new boolean[graphNum][1];
      itemInfoForDialogBoolean = new boolean[graphNum][1];

      isCollect = new boolean[graphNum][1];
      for (int i = 0; i < graphNum; i++) {
    	  isCollect[i][0] = false; //初期値.
      }
      hasDevice = new boolean[graphNum][1];
      for (int i = 0; i < graphNum; i++) {
    	  hasDevice[i][0] = true; //初期値.
      }
    }

    
    /**
     * 収集項目情報を設定します。
     * @param i
     * @param itemCode
     * @param displayType
     * @param displayName
     * @param isDetailed
     */
    public void setItemInfo(int i, String itemCode, String displayType, String displayName,
    		 String displayForm, boolean isDetailed) {
    	itemInfo[i][0] = itemCode;
    	itemInfo[i][1] = displayType;
    	itemInfo[i][2] = displayName;
    	itemInfo[i][3] = displayForm;
    	itemInfoBoolean[i][0] = isDetailed;
    }
    
    /**
     * 収集項目コードを取得します。
     * @param i
     * @return
     */
    public String getItemCode(int i) {
    	return (itemInfo[i][0]) ;
    }
    
    /**
     * 表示種別を取得します。
     * @param i
     * @return
     */
    public String getDisplayType(int i) {
    	return (itemInfo[i][1]) ;
    }
    
    /**
     * リポジトリ表示名を取得します。
     * @param i
     * @return
     */
    public String getDisplayName(int i) {
    	return (itemInfo[i][2]) ;
    }
    
    /**
     * グラフの形を取得します。
     * @param i
     * @return
     */
    public String getDisplayForm(int i) {
    	return (itemInfo[i][3]) ;
    }
    
    /**
     * リポジトリ表示名を設定します。
     * @param i
     * @param displayName
     */
    public void setDisplayName(int i, String displayName) {
    	itemInfo[i][2] = displayName;
    }
    /**
     * 詳細か否かを設定します。
     * @param i
     * @return
     */
    public boolean getItemDetailed(int i) {
    	return (this.itemInfoBoolean[i][0]) ;
    }
    
    /**
     * 詳細か否かをチェックします。
     * @param i
     * @param isDetailed
     */
    public void isItemDetailed(int i, boolean isDetailed) {
    	this.itemInfoBoolean[i][0] = isDetailed;
    }
    
    /**
     * 収集中か否かをチェックします。
     * @param i
     * @return
     */
    public boolean isCollect(int i) {
    	return isCollect[i][0];
    }
    
    /**
     * 収集中であることを設定します。
     * @param i
     * @param isCollect
     */
    public void setIsCollect(int i, boolean isCollect) {
    	this.isCollect[i][0] = isCollect;
    }
    
    /**
     * デバイス情報を保持するかを確認します。
     * @param i
     * @return
     */
    public boolean hasDevice(int i) {
    	return hasDevice[i][0];
    }
    
    /**
     * デバイス情報を保持するかを設定します。
     * @param i
     * @param hasDevice
     */
    public void setHasDevice(int i, boolean hasDevice) {
    	this.hasDevice[i][0] = hasDevice;
    }
    
    /**
     * ダイアログ用に収集項目情報を設定します。
     * @param i
     * @param itemCode
     * @param displayType
     * @param displayName
     * @param displayForm
     * @param isDetailed
     */
    public void setItemInfoForDialog(int i, String itemCode, String displayType, String displayName,
    		String displayForm, boolean isDetailed) {
    	itemInfoForDialog[i][0] = itemCode;
    	itemInfoForDialog[i][1] = displayType;
    	itemInfoForDialog[i][2] = displayName;
    	itemInfoForDialog[i][3] = displayForm;
    	itemInfoForDialogBoolean[i][0] = isDetailed;
    }
    
    /**
     * 収集項目コードを取得します。
     * @param i
     * @return 収集項目コード
     */
    public String getItemCodeForDialog(int i) {
    	return (itemInfoForDialog[i][0]) ;
    }
    
    /**
     * 表示種別を取得します。
     * @param i
     * @return 表示種別
     */
    public String getDisplayTypeForDialog(int i) {
    	return (itemInfoForDialog[i][1]) ;
    }
    
    /**
     * リポジトリ表示名を取得します。
     * @param i
     * @return リポジトリ表示名
     */
    public String getDisplayNameForDialog(int i) {
    	return (itemInfoForDialog[i][2]) ;
    }
    
    /**
     * グラフの形を取得します。
     * @param i
     * @return 表示種別
     */
    public String getDisplayFormForDialog(int i) {
    	return (itemInfoForDialog[i][3]) ;
    }
    
    public void isItemDetailedForDialog(int i, boolean isDetailed) {
    	this.itemInfoForDialogBoolean[i][0] = isDetailed;
    }
    
    /**
     * 収集項目コードを設定します。
     * @param i
     * @param itemCode
     */
    public void setItemCodeForDialog(int i, String itemCode) {
    	itemInfoForDialog[i][0] = itemCode;
    }
    
    /**
     * 表示種別を設定します。
     * @param i
     * @param displayType
     */
    public void setDisplayTypeForDialog(int i, String displayType) {
    	itemInfoForDialog[i][1] = displayType;
    }
    
    /**
     * リポジトリ表示名を設定します。
     * @param i
     * @param displayName リポジトリ表示名
     */
    public void setDisplayNameForDialog(int i, String displayName) {
    	itemInfoForDialog[i][2] = displayName;
    }
    
    /**
     * グラフの形を設定します。
     * @param i
     * @param displayForm
     */
    public void setDisplayFormForDialog(int i, String displayForm) {
    	itemInfoForDialog[i][3] = displayForm;
    }
    
    /**
     * 収集項目情報を更新します。
     */
    public void refreshItemInfoForDialog() {
    	for (int i = 0; i < itemInfo.length ; i++) {
    		setItemInfoForDialog(i,
    				itemInfo[i][0],
    				itemInfo[i][1],
    				itemInfo[i][2],
    				itemInfo[i][3],
    				itemInfoBoolean[i][0]);
    	}
    }
    /**
     * 収集項目をコピーします。
     */
    public void copyItemInfoForDialog() {
    	for (int i = 0; i < itemInfo.length ; i++) {
    		setItemInfo(i,
    				itemInfoForDialog[i][0],
    				itemInfoForDialog[i][1],
    				itemInfoForDialog[i][2],
    				itemInfoForDialog[i][3],
    				itemInfoForDialogBoolean[i][0]);
    	}
    }
    
    /**
     * 収集項目コードを取得します。
     * @param i
     * @return　収集項目コード
     */
    public String getItemCodeForCollector(int i) {
    	return (itemInfoForCollector[i][0]) ;
    }
    
    /**
     * リポジトリ表示名を取得します。
     * @param i
     * @return リポジトリ表示名
     */
    public String getDisplayNameForCollector(int i) {
    	return (itemInfoForCollector[i][1]) ;
    }
    
    /**
     * 収集項目情報を設定します。
     * @param i
     * @param itemCode 収集項目コード
     * @param deviceIndex デバイスインデックス
     * @param displayName リポジトリ表示名
     * @param isDetailed 詳細か否かのフラグ
     */
    public void setItemInfoForCollector(int i, String itemCode, String displayName, boolean isDetailed) {
    	this.itemInfoForCollector[i][0] = itemCode;
    	if (displayName != null && ! displayName.equals("Non")) {
    		this.itemInfoForCollector[i][1] = displayName;
    	}
    	else {
    		this.itemInfoForCollector[i][1] = "";
    	}
    	this.itemInfoForCollectorBoolean[i][0] = isDetailed;
    }
    
    /**
     * 収集項目数分の収集項目設定を生成します。
     * @param itemNum 収集項目数
     */
    public void createItemInfoForCollector(int itemNum) {
    	this.itemNum = itemNum;
    	itemInfoForCollector = new String[itemNum][2];
    	itemInfoForCollectorBoolean  = new boolean[itemNum][1];
    }
    /**
     * 収集項目数を取得します。
     * @return 収集項目数
     */
    public int getItemNumForCollector() {
    	return (this.itemNum) ;
    }
    
    // FIXME 相応のメソッド名に変更の必要
    public void isItemDetailedForCollector(int i, boolean isDetailed) {
    	this.itemInfoForCollectorBoolean[i][0] = isDetailed;
    }
    public boolean getItemDetailedForCollector(int i) {
    	return (this.itemInfoForCollectorBoolean[i][0]) ;
    }
}