/*
 
 Copyright (C) 2006 NTT DATA Corporation
 
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 */

package com.clustercontrol.performance.view.action;

import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.IViewActionDelegate;
import org.eclipse.ui.IViewPart;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.PlatformUI;

import com.clustercontrol.performance.action.RecordController;
import com.clustercontrol.performance.dialog.RealtimeSetDialog;
import com.clustercontrol.performance.view.RealtimeGraphView;

/**
 * リアルタイムグラフの表示項目、グラフ種別、更新間隔設定を行うアクションクラス
 * 
 * @version 1.0
 * @since 1.0
 */
public class RealtimeSetGraphAction implements IViewActionDelegate {

	/** アクションID */
	public static final String ID = "com.clustercontrol.performance.view.action.RealtimeSetGraphAction";
	private RealtimeSetDialog dialog;

    /**
     * ビューを保持します。ワークベンチにロードされた際に呼ばれます。
     * 
     * @param view ビューのインスタンス
     * 
     * @see org.eclipse.ui.IViewActionDelegate#init(org.eclipse.ui.IViewPart)
     */
    public void init(IViewPart view) {
//        this.viewPart = view;
    }

    /**
     * リアルグラフの設定ダイアログ（リアルタイムグラフの表示項目、グラフ種別、更新間隔設定）を表示します。
     * 
     * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.com.realtimemonitor.action.IAction)
     */
    //グラフ表示する条件を登録するダイアログの表示とアクション。
    public void run(IAction action) {
		// アクセス権なしの場合、エラーダイアログを表示する
    	if(!RecordController.getInstance().checkPermissionExecute()){
    		MessageDialog.openInformation(null, com.clustercontrol.util.Messages.getString("message"),
    				com.clustercontrol.util.Messages.getString("message.accesscontrol.16"));
    		return;
    	}
    	
        /*
         * 呼び出し元のViewを持ってきます。
         */
        IWorkbenchPage page = PlatformUI.getWorkbench().getActiveWorkbenchWindow().getActivePage();
        RealtimeGraphView view = (RealtimeGraphView) page.findView(RealtimeGraphView.ID);

        Shell shell = new Shell();
        dialog = new RealtimeSetDialog(shell);
        
        dialog.setCollectorInfo(view.collectorInfo);
        dialog.setCollectorItemInfo(view.collectorItemInfo);
        dialog.setInterval(true);
        dialog.update();
        
        int ret = dialog.open();
        
        // 条件設定ダイアログでOKボタンが押下されたときの処理
        if (ret == IDialogConstants.OK_ID) {
        	view.update();
        } else if (ret == IDialogConstants.CANCEL_ID) {
        	// 何もしない.
        }
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.eclipse.ui.IActionDelegate#selectionChanged(org.eclipse.jface.com.realtimemonitor.action.IAction,
     *      org.eclipse.jface.viewers.ISelection)
     */
    public void selectionChanged(IAction action, ISelection selection) {

    }
}