/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.repository.action;

import java.rmi.AccessException;
import java.rmi.RemoteException;
import java.util.ArrayList;

import org.eclipse.jface.dialogs.MessageDialog;

import com.clustercontrol.bean.Property;
import com.clustercontrol.repository.bean.NodeInfo;
import com.clustercontrol.repository.ejb.session.RepositoryController;
import com.clustercontrol.repository.util.EjbConnectionManager;
import com.clustercontrol.repository.util.NodePropertyUtil;
import com.clustercontrol.util.Messages;
import com.clustercontrol.util.PropertyUtil;

/**
 * 登録ノードのリストを取得するクライアント側アクションクラス<BR>
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class GetNodeList {

    // ----- instance メソッド ----- //

    /**
     * 全てのノード一覧を取得します。
     * 
     * @return ノード一覧
     */
    public ArrayList<NodeInfo> getAll() {
        RepositoryController repository = EjbConnectionManager
                .getConnectionManager().getRepositoryController();

        ArrayList<NodeInfo> records = null;
        try {
            records = repository.getNodeList();
        } catch (RemoteException e) {
			if(e instanceof AccessException){
				// アクセス権なしの場合、エラーダイアログを表示する
	            MessageDialog.openInformation(null, Messages.getString("message"),
	                    Messages.getString("message.accesscontrol.16"));
			}
        }
        return records;
    }

    /**
     * propertyの条件にヒットするノードの一覧を返します。
     * 
     * @param property
     * @return ノード一覧
     */
    public ArrayList<NodeInfo> get(Property property) {
        PropertyUtil.deletePropertyDefine(property);

        RepositoryController repository = EjbConnectionManager
                .getConnectionManager().getRepositoryController();

        ArrayList<NodeInfo> records = null;
        try {
        	NodeInfo nodeInfo = null;
        	nodeInfo = NodePropertyUtil.property2node(property);
            records = repository.getFilterNodeList(nodeInfo);
        } catch (RemoteException e) {
			if(e instanceof AccessException){
				// アクセス権なしの場合、エラーダイアログを表示する
	            MessageDialog.openInformation(null, Messages.getString("message"),
	                    Messages.getString("message.accesscontrol.16"));
			}
        }
        return records;
    }

    /**
     * 指定したスコープに属するノードの一覧を返します。
     * 
     * @param facilityId
     *            スコープのファシリティID
     * @return ノード一覧
     */
    public ArrayList<NodeInfo> get(String facilityId) {
        RepositoryController repository = EjbConnectionManager
                .getConnectionManager().getRepositoryController();

        ArrayList<NodeInfo> records = null;
        try {
        	// RepositoryControllerBean.ONE_LEVEL = 1
            records = repository.getNodeList(facilityId, 1);
        } catch (RemoteException e) {
			if(e instanceof AccessException){
				// アクセス権なしの場合、エラーダイアログを表示する
	            MessageDialog.openInformation(null, Messages.getString("message"),
	                    Messages.getString("message.accesscontrol.16"));
			}
        }
        return records;
    }
}