/*
 
 Copyright (C) 2006 NTT DATA Corporation
 
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License 
 as published by the Free Software Foundation, version 2.
 
 This program is distributed in the hope that it will be
 useful, but WITHOUT ANY WARRANTY; without even the implied 
 warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
 PURPOSE.  See the GNU General Public License for more details.
 
 */

package com.clustercontrol.monitor.run.bean;

import java.util.ArrayList;
import java.util.Collection;

import com.clustercontrol.bean.MonitorBlockConstant;
import com.clustercontrol.bean.PriorityConstant;
import com.clustercontrol.bean.RunIntervalConstant;
import com.clustercontrol.bean.ValidConstant;
import com.clustercontrol.hinemosagent.bean.AgentCheckInfo;
import com.clustercontrol.http.bean.HttpCheckInfo;
import com.clustercontrol.notify.bean.NotifyRelationInfo;
import com.clustercontrol.performance.monitor.bean.PerfCheckInfo;
import com.clustercontrol.ping.bean.PingCheckInfo;
import com.clustercontrol.port.bean.PortCheckInfo;
import com.clustercontrol.process.bean.ProcessCheckInfo;
import com.clustercontrol.snmp.bean.SnmpCheckInfo;
import com.clustercontrol.sql.bean.SqlCheckInfo;

/**
 * 監視情報を保持するクラス<BR>
 * jaxbで利用するため、引数なしのコンストラクタが必要。
 * そのため、abstractにしない。
 * 
 * @version 3.0.0
 * @since 2.0.0
 */
public class MonitorInfo
implements java.io.Serializable
{
	private static final long serialVersionUID = 8016002145318844928L;
	
	/** アプリケーション。 */
	protected String m_application;
	
	/** カレンダID。 */
	protected String m_calendarId;
	
	/** 説明。 */
	protected String m_description;
	
	/** 判定ID（未使用）。 */
	protected String m_determinationId;
	
	/** スコープ。 */
	protected String m_scope;
	
	/** ファシリティID。 */
	protected String m_facilityId;
	
	
	/** 通知グループID*/
	protected String m_notifyGroupId;
	
	/**　通知IDのコレクション*/
	
	protected Collection<NotifyRelationInfo> m_notifyId;
	
	/** 
	 * 値失敗時の重要度。
	 * 
	 * @see com.clustercontrol.bean.PriorityConstant
	 */
	protected int m_failurePriority = PriorityConstant.TYPE_UNKNOWN;
	
	/**
	 * 監視単位。
	 * 
	 * @see com.clustercontrol.bean.MonitorBlockConstant
	 */
	protected int m_monitorBlock = MonitorBlockConstant.TYPE_ALL;
	
	/** 監視項目ID。 */
	protected String m_monitorId;
	
	/** 監視対象ID。 */
	protected String m_monitorTypeId;
	
	
	/**
	 * 実行間隔（秒）。
	 *
	 * @see com.clustercontrol.bean.RunIntervalConstant
	 */
	protected int m_runInterval = RunIntervalConstant.TYPE_MIN_01;
	
	/** 作成日時。 */
	protected long m_regDate;
	
	/** 最終変更日時。 */
	protected long m_updateDate;
	
	/**
	 * 有効/無効。
	 * 
	 * @see com.clustercontrol.bean.ValidConstant
	 */
	protected int m_valid = ValidConstant.TYPE_VALID;
	
	/** 
	 * 判定情報。
	 * {@link com.clustercontrol.monitor.run.bean.MonitorJudgementInfo}のリスト。
	 */
	protected ArrayList<MonitorNumericValueInfo> m_numericValueInfo;
	protected ArrayList<MonitorStringValueInfo> m_stringValueInfo;
	protected ArrayList<MonitorTruthValueInfo> m_truthValueInfo;
	
	/** チェック条件情報。 */
	protected AgentCheckInfo agentCheckInfo;
	protected HttpCheckInfo httpCheckInfo;
	protected PerfCheckInfo perfCheckInfo;
	protected PingCheckInfo pingCheckInfo;
	protected PortCheckInfo portCheckInfo;
	protected ProcessCheckInfo processCheckInfo;
	protected SnmpCheckInfo snmpCheckInfo;
	protected SqlCheckInfo sqlCheckInfo;
	
	/**
	 * 監視判定タイプ。
	 * 
	 * @see com.clustercontrol.bean.MonitorBlockConstant
	 */
	protected int m_monitorType;
	
	/** タイムアウト。 */
	protected int m_timeout;
	
	
	/** 値取得の失敗時のメッセージID（未使用）。 */
	protected String m_failureMessageId;
	
	/** 値取得の失敗時のメッセージ（未使用）。 */
	protected String m_failureMessage;
	
	
	/** 新規作成ユーザ。 */
	protected String m_regUser;
	
	/** 最終変更ユーザ。 */
	protected String m_updateUser;
	
	/**
	 * コンストラクタ。 
	 */
	public MonitorInfo() {
		super();
	}
	
	/**
	 * コンストラクタ。
	 * 
	 * @param application アプリケーション
	 * @param calendarId カレンダID
	 * @param description 説明
	 * @param determinationId 判定ID（未使用）
	 * @param scope スコープ
	 * @param facilityId ファシリティID
	 * @param failurePriority 値取得の失敗時の重要度
	 * @param monitorBlock 監視単位
	 * @param monitorId 監視項目ID
	 * @param monitorTypeId 監視対象ID
	 * @param monitorType 監視種別

	 * @param regDate 作成日時
	 * @param regUser 新規作成ユーザ
	 * @param runInterval 実行間隔（秒）
	 * @param timeout タイムアウト
	 * @param failureMessageId 値取得の失敗時のメッセージID（未使用）
	 * @param failureMessage  値取得の失敗時のメッセージ（未使用）
	 * @param notifyGroupId 通知グループID
	 * @param notifyId 通知IDのコレクション
	 * @param updateDate 最終変更日時
	 * @param updateUser 最終変更ユーザ
	 * @param valid 有効/無効
	 * @param judgementInfo 判定情報
	 * @param checkInfo チェック条件情報
	 */
	public MonitorInfo(
			String application,
			String calendarId,
			String description,
			String determinationId,
			String scope,
			String facilityId,
			int failurePriority,
			int monitorBlock,
			String monitorId,
			String monitorTypeId,
			int monitorType,
			long regDate,
			String regUser,
			int runInterval,
			int timeout,
			String failureMessageId, 
			String failureMessage,
			String notifyGroupId,
			Collection notifyId,
			long updateDate,
			String updateUser,
			int valid,
			ArrayList<MonitorNumericValueInfo> numericValueInfo,
			ArrayList<MonitorStringValueInfo> stringValueInfo,
			ArrayList<MonitorTruthValueInfo> truthValueInfo,
			AgentCheckInfo agentCheckInfo,
			HttpCheckInfo httpCheckInfo,
			PerfCheckInfo perfCheckInfo,
			PingCheckInfo pingCheckInfo,
			PortCheckInfo portCheckInfo,
			ProcessCheckInfo processCheckInfo,
			SnmpCheckInfo snmpCheckInfo,
			SqlCheckInfo sqlCheckInfo) {
		
		setApplication(application);
		setCalendarId(calendarId);
		setDescription(description);
		setDeterminationId(determinationId);
		setScope(scope);
		setFacilityId(facilityId);
		setFailurePriority(failurePriority);
		setMonitorBlock(monitorBlock);
		setMonitorId(monitorId);
		setMonitorTypeId(monitorTypeId);
		setMonitorType(monitorType);
		setRegDate(regDate);
		setRegUser(regUser);
		setRunInterval(runInterval);
		setTimeout(timeout);
		setFailureMessageId(failureMessageId);
		setFailureMessage(failureMessage);
		setNotifyGroupId(notifyGroupId);
		setNotifyId(notifyId);
		setUpdateDate(updateDate);
		setUpdateUser(updateUser);
		setValid(valid);
		setNumericValueInfo(numericValueInfo);
		setStringValueInfo(stringValueInfo);
		setTruthValueInfo(truthValueInfo);
		setAgentCheckInfo(agentCheckInfo);
		setHttpCheckInfo(httpCheckInfo);
		setPerfCheckInfo(perfCheckInfo);
		setPingCheckInfo(pingCheckInfo);
		setPortCheckInfo(portCheckInfo);
		setProcessCheckInfo(processCheckInfo);
		setSnmpCheckInfo(snmpCheckInfo);
		setSqlCheckInfo(sqlCheckInfo);
	}
	
	/**
	 * コンストラクタ。
	 * 
	 * @param otherData コピー元の監視情報
	 */
	public MonitorInfo( MonitorInfo otherData ) {
		
		setApplication(otherData.getApplication());
		setCalendarId(otherData.getCalendarId());
		setDescription(otherData.getDescription());
		setDeterminationId(otherData.getDeterminationId());
		setScope(otherData.getScope());
		setFacilityId(otherData.getFacilityId());
		setFailurePriority(otherData.getFailurePriority());
		setMonitorBlock(otherData.getMonitorBlock());
		setMonitorId(otherData.getMonitorId());
		setMonitorTypeId(otherData.getMonitorTypeId());
		setMonitorType(otherData.getMonitorType());
		setRegDate(otherData.getRegDate());
		setRegUser(otherData.getRegUser());
		setRunInterval(otherData.getRunInterval());
		setFailureMessageId(otherData.getFailureMessageId());
		setFailureMessage(otherData.getFailureMessage());
		setNotifyGroupId(otherData.getNotifyGroupId());
		setNotifyId(otherData.getNotifyId());
		setUpdateDate(otherData.getUpdateDate());
		setUpdateUser(otherData.getUpdateUser());
		setValid(otherData.getValid());
		setNumericValueInfo(otherData.getNumericValueInfo());
		setStringValueInfo(otherData.getStringValueInfo());
		setTruthValueInfo(otherData.getTruthValueInfo());
		setAgentCheckInfo(otherData.getAgentCheckInfo());
		setHttpCheckInfo(otherData.getHttpCheckInfo());
		setPerfCheckInfo(otherData.getPerfCheckInfo());
		setPingCheckInfo(otherData.getPingCheckInfo());
		setPortCheckInfo(otherData.getPortCheckInfo());
		setProcessCheckInfo(otherData.getProcessCheckInfo());
		setSnmpCheckInfo(otherData.getSnmpCheckInfo());
		setSqlCheckInfo(otherData.getSqlCheckInfo());
	}
	
	/**
	 * 通知グループIDを設定します。
	 * 
	 * @param notifyGroupId
	 */
	public void setNotifyGroupId(String notifyGroupId) {
		
		 m_notifyGroupId = notifyGroupId;
		
	}

	/**
	 * 通知グループIDを返します。
	 * 
	 * @return * 通知グループID
	 */
	public String getNotifyGroupId() {
		
		return m_notifyGroupId;
	}

	/**
	 * アプリケーションを返します。
	 * 
	 * @return アプリケーション
	 */
	public String getApplication(){
		return this.m_application;
	}
	
	/**
	 * アプリケーションを設定します。
	 * 
	 * @param application アプリケーション
	 */
	public void setApplication( String application ){
		this.m_application = application;
	}
	
	/**
	 * カレンダIDを返します。
	 * 
	 * @return カレンダID
	 */
	public String getCalendarId(){
		return this.m_calendarId;
	}
	
	/**
	 * カレンダIDを設定します。
	 * 
	 * @param calendarId カレンダID
	 */
	public void setCalendarId( String calendarId ){
		this.m_calendarId = calendarId;
	}
	
	/**
	 * 説明を返します。
	 * 
	 * @return 説明
	 */
	public String getDescription(){
		return this.m_description;
	}
	
	/**
	 * 説明を設定します。
	 * 
	 * @param description 説明
	 */
	public void setDescription( String description ){
		this.m_description = description;
	}
	
	/**
	 * 判定IDを返します（未使用）。
	 * 
	 * @return 判定ID
	 */
	public String getDeterminationId(){
		return this.m_determinationId;
	}
	
	/**
	 * 判定IDを設定します（未使用）。
	 * 
	 * @param determinationId 判定ID
	 */
	public void setDeterminationId( String determinationId ){
		this.m_determinationId = determinationId;
	}
	
	/**
	 * ファシリティIDを返します。
	 * 
	 * @return ファシリティID
	 */
	public String getFacilityId(){
		return this.m_facilityId;
	}
	
	/**
	 * ファシリティIDを設定します。
	 * 
	 * @param facilityId ファシリティID
	 */
	public void setFacilityId( String facilityId ){
		this.m_facilityId = facilityId;
	}
	
	/**
	 * 値取得の失敗時の重要度を返します。
	 * 
	 * @return 値取得の失敗時の重要度
	 * 
	 * @see com.clustercontrol.bean.PriorityConstant
	 */
	public int getFailurePriority(){
		return this.m_failurePriority;
	}
	
	/**
	 * 値取得の失敗時の重要度を設定します。
	 * 
	 * @param failurePriority 値取得の失敗時の重要度
	 * 
	 * @see com.clustercontrol.bean.PriorityConstant
	 */
	public void setFailurePriority( int failurePriority ){
		this.m_failurePriority = failurePriority;
	}
	
	/**
	 * 監視単位を返します。
	 * 
	 * @return 監視単位
	 * 
	 * @see com.clustercontrol.bean.MonitorBlockConstant
	 */
	public int getMonitorBlock(){
		return this.m_monitorBlock;
	}
	
	/**
	 * 監視単位を設定します。
	 * 
	 * @param monitorBlock 監視単位
	 * 
	 * @see com.clustercontrol.bean.MonitorBlockConstant
	 */
	public void setMonitorBlock( int monitorBlock ){
		this.m_monitorBlock = monitorBlock;
	}
	
	/**
	 * 監視項目IDを返します。
	 * 
	 * @return 監視項目ID
	 */
	public String getMonitorId(){
		return this.m_monitorId;
	}
	
	/**
	 * 監視項目IDを設定します。
	 * 
	 * @param monitorId 監視項目ID
	 */
	public void setMonitorId( String monitorId ){
		this.m_monitorId = monitorId;
	}
	
	/**
	 * 監視対象IDを返します。
	 * 
	 * @return 監視対象ID
	 */
	public String getMonitorTypeId(){
		return this.m_monitorTypeId;
	}
	
	/**
	 * 監視対象IDを設定します。
	 * 
	 * @param monitorTypeId 監視対象ID
	 */
	public void setMonitorTypeId( String monitorTypeId ){
		this.m_monitorTypeId = monitorTypeId;
	}
	
	/**
	 * 通知IDを返します。
	 * 
	 * @return 通知ID
	 */
	public Collection<NotifyRelationInfo> getNotifyId(){
		return this.m_notifyId;
	}
	
	/**
	 * 通知IDを設定します。
	 * 
	 * @param notifyId 通知ID
	 */
	public void setNotifyId( Collection<NotifyRelationInfo> notifyId ){
		this.m_notifyId = notifyId;
	}
	
	/**
	 * 作成日時を返します。
	 * 
	 * @return regDate 作成日時
	 */
	public long getRegDate(){
		return this.m_regDate;
	}
	
	/**
	 * 作成日時を設定します。
	 * 
	 * @param regDate 作成日時
	 */
	public void setRegDate( long regDate ){
		this.m_regDate = regDate;
	}
	
	/**
	 * 実行間隔を返します。
	 * 
	 * @return 実行間隔（秒）
	 * 
	 * @see com.clustercontrol.bean.RunIntervalConstant
	 */
	public int getRunInterval(){
		return this.m_runInterval;
	}
	
	/**
	 * 実行間隔を設定します。
	 * 
	 * @param runInterval 実行間隔（秒）
	 * 
	 * @see com.clustercontrol.bean.RunIntervalConstant
	 */
	public void setRunInterval( int runInterval ){
		this.m_runInterval = runInterval;
	}
	
	/**
	 * スコープを返します。
	 * 
	 * @return スコープ
	 */
	public String getScope(){
		return m_scope;
	}
	
	/**
	 * スコープを設定します。
	 * 
	 * @param scope スコープ
	 */
	public void setScope(String scope) {
		this.m_scope = scope;
	}
	
	/**
	 * 最終変更日時を返します。
	 * 
	 * @return 最終変更日時
	 */
	public long getUpdateDate(){
		return this.m_updateDate;
	}
	
	/**
	 * 最終変更日時を設定します。
	 * 
	 * @param updateDate 最終変更日時
	 */
	public void setUpdateDate( long updateDate ){
		this.m_updateDate = updateDate;
	}
	
	/**
	 * 有効/無効を返します。
	 * 
	 * @return 有効/無効
	 * 
	 * @see com.clustercontrol.bean.ValidConstant
	 */
	public int getValid() {
		return m_valid;
	}
	
	/**
	 * 有効/無効を設定します。
	 * 
	 * @param valid 有効/無効
	 * 
	 * @see com.clustercontrol.bean.ValidConstant
	 */
	public void setValid(int valid) {
		this.m_valid = valid;
	}
	
	/**
	 * 新規作成ユーザを返します。
	 * 
	 * @return 新規作成ユーザ
	 */
	public String getRegUser() {
		return m_regUser;
	}
	
	/**
	 * 新規作成ユーザを設定します。
	 * 
	 * @param user 新規作成ユーザ
	 */
	public void setRegUser(String user) {
		m_regUser = user;
	}
	
	/**
	 * 最終変更ユーザを返します。
	 * 
	 * @return 最終変更ユーザ
	 */
	public String getUpdateUser() {
		return m_updateUser;
	}
	
	/**
	 * 最終変更ユーザを設定します。
	 * 
	 * @param user 最終変更ユーザ 
	 */
	public void setUpdateUser(String user) {
		m_updateUser = user;
	}
	
	
	/**
	 * 値取得の失敗時のメッセージを返します（未使用）。
	 * 
	 * @return 値取得の失敗時のメッセージ
	 */
	public String getFailureMessage() {
		return m_failureMessage;
	}
	
	/**
	 * 値取得の失敗時のメッセージを設定します（未使用）。
	 * 
	 * @param message 値取得の失敗時のメッセージ
	 */
	public void setFailureMessage(String message) {
		m_failureMessage = message;
	}
	
	/**
	 * 値取得の失敗時のメッセージIDを返します（未使用）。
	 * 
	 * @return 値取得の失敗時のメッセージID
	 */
	public String getFailureMessageId() {
		return m_failureMessageId;
	}
	
	/**
	 * 値取得の失敗時のメッセージIDを設定します（未使用）。
	 * 
	 * @param messageId 値取得の失敗時のメッセージID
	 */
	public void setFailureMessageId(String messageId) {
		m_failureMessageId = messageId;
	}
	
	/**
	 * 監視種別を返します。
	 * 
	 * @return 監視種別
	 * 
	 * @see com.clustercontrol.monitor.run.bean.MonitorTypeConstant
	 */
	public int getMonitorType() {
		return m_monitorType;
	}
	
	/**
	 * 監視種別を設定します。
	 * 
	 * @param type 監視種別
	 * 
	 * @see com.clustercontrol.monitor.run.bean.MonitorTypeConstant
	 */
	public void setMonitorType(int type) {
		m_monitorType = type;
	}
	
	/**
	 * タイムアウトを返します（未使用）。
	 * 
	 * @return タイムアウト
	 */
	public int getTimeout() {
		return m_timeout;
	}
	
	/**
	 * タイムアウトを設定します（未使用）。
	 * 
	 * @param timeout タイムアウト
	 */
	public void setTimeout(int timeout) {
		this.m_timeout = timeout;
	}

	/**
	 * 判定情報を返します。
	 */
	public ArrayList<MonitorNumericValueInfo> getNumericValueInfo() {
		return m_numericValueInfo;
	}
	
	/**
	 * 判定情報を返します。
	 */
	public void setNumericValueInfo(ArrayList<MonitorNumericValueInfo> valueInfo) {
		m_numericValueInfo = valueInfo;
	}
	
	/**
	 * 判定情報を返します。
	 */
	public ArrayList<MonitorStringValueInfo> getStringValueInfo() {
		return m_stringValueInfo;
	}
	
	/**
	 * 判定情報を設定します。
	 */
	public void setStringValueInfo(ArrayList<MonitorStringValueInfo> valueInfo) {
		m_stringValueInfo = valueInfo;
	}

	/**
	 * 判定情報を設定します。
	 */
	public ArrayList<MonitorTruthValueInfo> getTruthValueInfo() {
		return m_truthValueInfo;
	}

	/**
	 * 判定情報を設定します。
	 */
	public void setTruthValueInfo(ArrayList<MonitorTruthValueInfo> valueInfo) {
		m_truthValueInfo = valueInfo;
	}
	
	public AgentCheckInfo getAgentCheckInfo() {
		return agentCheckInfo;
	}

	public void setAgentCheckInfo(AgentCheckInfo agentCheckInfo) {
		this.agentCheckInfo = agentCheckInfo;
	}

	public HttpCheckInfo getHttpCheckInfo() {
		return httpCheckInfo;
	}

	public void setHttpCheckInfo(HttpCheckInfo httpCheckInfo) {
		this.httpCheckInfo = httpCheckInfo;
	}

	public PerfCheckInfo getPerfCheckInfo() {
		return perfCheckInfo;
	}

	public void setPerfCheckInfo(PerfCheckInfo perfCheckInfo) {
		this.perfCheckInfo = perfCheckInfo;
	}

	public PingCheckInfo getPingCheckInfo() {
		return pingCheckInfo;
	}

	public void setPingCheckInfo(PingCheckInfo pingCheckInfo) {
		this.pingCheckInfo = pingCheckInfo;
	}

	public PortCheckInfo getPortCheckInfo() {
		return portCheckInfo;
	}

	public void setPortCheckInfo(PortCheckInfo portCheckInfo) {
		this.portCheckInfo = portCheckInfo;
	}

	public ProcessCheckInfo getProcessCheckInfo() {
		return processCheckInfo;
	}

	public void setProcessCheckInfo(ProcessCheckInfo processCheckInfo) {
		this.processCheckInfo = processCheckInfo;
	}

	public SnmpCheckInfo getSnmpCheckInfo() {
		return snmpCheckInfo;
	}

	public void setSnmpCheckInfo(SnmpCheckInfo snmpCheckInfo) {
		this.snmpCheckInfo = snmpCheckInfo;
	}

	public SqlCheckInfo getSqlCheckInfo() {
		return sqlCheckInfo;
	}

	public void setSqlCheckInfo(SqlCheckInfo sqlCheckInfo) {
		this.sqlCheckInfo = sqlCheckInfo;
	}
	
}
