/*
 
 Copyright (C) 2006 NTT DATA Corporation
 
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 */

package com.clustercontrol.performance.bean;

import com.clustercontrol.bean.FacilityTreeItem;
import com.clustercontrol.performance.bean.CollectorItemInfo;

/**
 * 実績データグラフ表示用設定情報クラス
 * 
 * @version 1.0
 * @since 1.0
 *  
 */
public class GraphProperty {

    /** 非表示 */
    public static final int INVISIBLE = 0;

    /** スコープ代表値 */
    public static final int TYPE1 = 1;

    /** 詳細(収集項目別) */
    public static final int TYPE2 = 2;

    /** 詳細(サブスコープ別) */
    public static final int TYPE3 = 3;

    
    /** 折れ線グラフ */
    public static final int FORM1 = 1;
    
    /** 積み上げ面グラフ */
    public static final int FORM2 = 2;
    

    // DBMSなどに格納する上で判りやすいように文字表記とする.
    public static final String DISPLAY_NO = "DISPLAY_NO";  // NonDisplay
    
    public static final String DISPLAY_SELECTED_SCOPE = "DISPLAY_NO";  // SelectedScope

    public static final String DISPLAY_SCOPE_DETAILS = "DISPLAY_SCOPE_DETAILS";  // Detail

    public static final String DISPLAY_SUBSCOPE = "DISPLAY_SUBSCOPE";  // SubScope
    
    // グラフ詳細表示の可否の判定用.stringかbooleanかは要検討.
    public static final String BREAKDOWN_OK = "BREAKDOWN_OK";
    public static final String BREAKDOWN_NG = "BREAKDOWN_NG";
    
    private CollectorItemInfo targetItem; // グラフ表示対象項目

    FacilityTreeItem targetFacility; // グラフ表示対象ファシリティ

    int graphType; // グラフ表示方法
    int graphForm; // グラフの形

    /**
     * コンストラクター
     * 
     * @param targetFacility 描画対象ファシリティ
     * @param targetItem 描画対象の収集項目
     * @param graphType グラフ種別
     */
    public GraphProperty(FacilityTreeItem targetFacility,
            CollectorItemInfo targetItem, int graphType, int graphForm) {

        this.targetFacility = targetFacility;
        this.targetItem = targetItem;
        this.graphType = graphType;
        this.graphForm = graphForm;
    }

    /**
     * グラフ種別を取得します。
     * 
     * @return graphType グラフ種別
     */
    public int getGraphType() {
        return graphType;
    }

    /**
     * グラフ種別を設定します。
     * 
     * @param graphType グラフ種別
     */
    public void setGraphType(int graphType) {
        this.graphType = graphType;
    }

    /**
     * グラフの形を取得します。
     * 
     * @return graphForm グラフ種別
     */
    public int getGraphForm() {
        return graphForm;
    }

    /**
     * グラフの形を設定します。
     * 
     * @param graphForm グラフの形
     */
    public void setGraphForm(int graphForm) {
        this.graphForm = graphForm;
    }

    /**
     * 描画対象ファシリティを取得します。
     * 
     * @return targetFacility 対象ファシリティ
     */
    public FacilityTreeItem getTargetFacility() {
        return targetFacility;
    }

    /**
     * 描画対象ファシリティを設定します。
     * 
     * @param targetFacility 対象ファシリティ
     */
    public void setTargetFacility(FacilityTreeItem targetFacility) {
        this.targetFacility = targetFacility;
    }

    /**
     * 描画対象収集項目を取得します。
     * 
     * @return targetItem 描画対象収集項目
     */
    public CollectorItemInfo getTargetItem() {
        return targetItem;
    }

    /**
     * 描画対象収集項目を設定します。
     * 
     * @param targetItem 描画対象収集項目
     */
    public void setTargetItem(CollectorItemInfo targetItem) {
        this.targetItem = targetItem;
    }
}