/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.calendar.ejb.session;

import java.rmi.RemoteException;
import java.security.Principal;
import java.util.ArrayList;
import java.util.Date;
import java.util.Locale;

import javax.ejb.CreateException;
import javax.ejb.EJBException;
import javax.ejb.FinderException;
import javax.ejb.RemoveException;
import javax.ejb.SessionContext;
import javax.naming.NamingException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.CalendarNotFountException;
import com.clustercontrol.bean.Property;
import com.clustercontrol.calendar.factory.AddProperty;
import com.clustercontrol.calendar.factory.CalendarProperty;
import com.clustercontrol.calendar.factory.ModifyCalendar;
import com.clustercontrol.calendar.factory.SelectCalendar;
import com.clustercontrol.calendar.factory.WeekdayProperty;

/**
 *
 * <!-- begin-user-doc --> カレンダー情報の制御を行うsession bean <!-- end-user-doc --> *
 *
 * <!-- begin-xdoclet-definition --> 
 * @ejb.bean name="CalendarController"	
 *    jndi-name="CalendarController"
 *    type="Stateless" 
 *    transaction-type="Container"
 * 
 * @jboss.depends name="jboss.j2ee:service=EJB,jndiName=CalendarInfoLocal"
 * @jboss.depends name="jboss.j2ee:service=EJB,jndiName=CalendarWeekdayInfoLocal"
 * @jboss.depends name="jboss.j2ee:service=EJB,jndiName=CalendarAddInfoLocal"
 * 
 * @ejb.permission
 *     unchecked="true"
 *     method-intf="Home"
 *     
 * @ejb.permission
 *     unchecked="true"
 *     method-intf="LocalHome"
 *     
 * @ejb.permission
 *     unchecked="true"
 *     method-intf="Local"
 * 
 * <!-- end-xdoclet-definition --> 
 * @generated
 */
public abstract class CalendarControllerBean implements javax.ejb.SessionBean {
    protected static Log m_log = LogFactory.getLog( CalendarControllerBean.class );
    
	@SuppressWarnings("unused")
	private SessionContext m_context;
	
	public void setSessionContext(SessionContext ctx) throws EJBException, RemoteException {
		m_context = ctx;
	}
	
	
	/**
	 * カレンダ一覧を取得します。<BR>
	 * 
	 * カレンダーデータの一覧を取得します。<br>
	 * 
	 * 戻り値のArrayListはArrayListのArrayListであり
	 * 内側のArrayListは以下のような情報がセットされます。
	 * 
	 * <pre>
	 *  ArrayList info = new ArrayList();
	 *	 info.add(cal.getCalendar_id());
	 *	 info.add(cal.getCalendar_name());
	 *   info.add(cal.getValid_time_from());
	 *	 info.add(cal.getValid_time_to());
	 *	 info.add(cal.getDescription());
	 *	 info.add(cal.getReg_user());
     *	 info.add(cal.getReg_date());
 	 *	 info.add(cal.getUpdate_user());
	 *	 info.add(cal.getUpdate_date());
	 *	 info.add(Boolean.valueOf(true));
	 *	
	 *    list.add(info);
	 * </pre>
	 * 
	 * @ejb.interface-method
     *     
	 * @ejb.permission
     *     role-name="CalendarRead"
     *     method-intf="Remote"
     *     
	 * @jboss.method-attributes
	 *     read-only="true"
	 * 
	 * @return オブジェクトの2次元配列
	 * @throws FinderException
	 * @throws NamingException
	 */
	public ArrayList getCalendarList() throws FinderException, NamingException {

		ArrayList list = null;
		try {
			SelectCalendar select = new SelectCalendar();
			list = select.getCalendarList();
		} catch (FinderException e) {
			m_log.debug("getCalendarList() -> " + e.getMessage());
			throw e;
		} catch (NamingException e) {
			throw e;
		}

		return list;
	}
	
	/**
	 * カレンダ曜日別情報一覧を取得します。<BR>
	 * 
	 * 戻り値はArrayListのArrayListであり
	 * 内側のArrayListは以下の情報がセットされます。
	 * 
	 * <pre>
	 *  ArrayList info = new ArrayList();
	 *	   info.add(cal.getWeekday());
	 *	   info.add(cal.getTime_from());
	 *	   info.add(cal.getTime_to());
	 *	   info.add(cal.getDescription());
	 *	   info.add(cal.getReg_user());
	 *	   info.add(cal.getReg_date());
	 *	   info.add(cal.getUpdate_user());
	 *	   info.add(cal.getUpdate_date());
	 * 
	 *     list.add(info);
	 * </pre>
	 * 
	 * @ejb.interface-method
     *     
	 * @ejb.permission
     *     role-name="CalendarRead"
     *     method-intf="Remote"
     *     
	 * @jboss.method-attributes
	 *     read-only="true"
	 * 
	 * @return オブジェクトの2次元配列
	 * @throws FinderException
	 * @throws NamingException
	 */
	public ArrayList getWeekdayList(String id) throws FinderException, NamingException {

		ArrayList list = null;
		try {
			SelectCalendar select = new SelectCalendar();
			list = select.getWeekdayList(id);
		} catch (FinderException e) {
			m_log.debug("getWeekdayList() -> " + e.getMessage());
			throw e;
		} catch (NamingException e) {
			throw e;
		}

		return list;
	}
	
	/**
	 * カレンダ追加情報一覧を取得します。<BR>
	 * 
	 * 戻り値はArrayListのArrayListであり
	 * 内側のArrayListは以下の情報がセットされます。
	 * 
	 * <pre>
	 *  ArrayList info = new ArrayList();
	 *	 info.add(Boolean.valueOf(RunConstant.typeToBoolean(cal.getExecute_flg().intValue())));
	 *	 info.add(cal.getTime_from());
	 *	 info.add(cal.getTime_to());
 	 *   info.add(cal.getDescription());
	 *   info.add(cal.getReg_user());
	 *	 info.add(cal.getReg_date());
	 *	 info.add(cal.getUpdate_user());
	 *	 info.add(cal.getUpdate_date());
	 *	
	 *   list.add(info);
	 * 
	 * </Pre>
	 * 
	 * @ejb.interface-method
     *     
	 * @ejb.permission
     *     role-name="CalendarRead"
     *     method-intf="Remote"
     *     
	 * @jboss.method-attributes
	 *     read-only="true"
	 * 
	 * @return オブジェクトの2次元配列
	 * @throws FinderException
	 * @throws NamingException
	 */
	public ArrayList getAddList(String id) throws FinderException, NamingException {

		ArrayList list = null;
		try {
			SelectCalendar select = new SelectCalendar();
			list = select.getAddList(id);
		} catch (FinderException e) {
			m_log.debug("getAddList() -> " + e.getMessage());
			throw e;
		} catch (NamingException e) {
			throw e;
		}

		return list;
	}
	
	/**
	 * 各カレンダの実行予定を取得します。<BR>
	 * 
	 * 戻り値はArrayListのArrayListであり
	 * 内側のArrayListはカレンダー毎の実行予定日(Dateインスタンス)
	 * が入っています。（内側のArrayListの先頭にはCalendar_id）
	 * 
	 * @ejb.interface-method
     *     
	 * @ejb.permission
     *     role-name="CalendarRead"
     *     method-intf="Remote"
     *     
	 * @jboss.method-attributes
	 *     read-only="true"
	 * 
	 * @return オブジェクトの2次元配列
	 * @throws NamingException
	 * @throws CalendarNotFountException 
	 */
	public ArrayList getSchedule(Date base) throws NamingException, CalendarNotFountException {

		SelectCalendar select = new SelectCalendar();
		ArrayList list = select.getSchedule(base);

		return list;
	}
	
	/**
	 * カレンダ用プロパティを取得します。<BR>
	 * 
	 * 引数で指定したカレンダーIDのカレンダー（基本）情報を
	 * 取得します。
	 * 
	 * @ejb.interface-method
	 * 
	 * @ejb.permission
     *     role-name="CalendarWrite"
     *     method-intf="Remote"
     *     
	 * @jboss.method-attributes
	 *     read-only="true"
	 * 
	 * @param id
	 * @param mode
	 * @param local
	 * @return idに対応するプロパティ情報
	 * @throws FinderException
	 * @throws NamingException
	 * 
	 * @see com.clustercontrol.calendar.factor.CalendarProperty
	 */
	public Property getCalendarProperty(String id, int mode, Locale locale) throws FinderException, NamingException {
		try {
			return new CalendarProperty().getProperty(id, mode, locale);
		} catch (FinderException e) {
			m_log.debug("getCalendarProperty() -> " + e.getMessage());
			throw e;
		} catch (NamingException e) {
			throw e;
		}
	}
	
	/**
	 * カレンダ（基本）情報を登録します。<BR>
	 * 
	 * 引数のプロパティの内容をマネージャに登録します。
	 * 
	 * @ejb.interface-method
	 * 
	 * @ejb.permission
     *     role-name="CalendarWrite"
     *     method-intf="Remote"
	 * 
	 * 
	 * @param property　登録するカレンダー（基本）情報
	 * @throws CreateException 
	 * @throws NamingException 
	 * 
	 * @see com.clustercontrol.calendar.factor.CalendarProperty
	 */
	public void addCalendar(Property property) throws NamingException, CreateException {

		Principal pri = m_context.getCallerPrincipal();
			
		ModifyCalendar modify = new ModifyCalendar();
		modify.addCalendar(property, pri.getName());

	}
	
	/**
	 * カレンダ（基本）情報を変更します。<BR>
	 * 
     * 引数のプロパティの内容で更新します。
	 * 
	 * @ejb.interface-method
	 * 
	 * @ejb.permission
     *     role-name="CalendarWrite"
     *     method-intf="Remote"
	 * 
	 * @param property
	 * @throws FinderException 
	 * @throws NamingException 
	 * 
	 * @see com.clustercontrol.calendar.factor.CalendarProperty
	 */
	public void modifyCalendar(Property property) throws NamingException, FinderException {
		try {
			Principal pri = m_context.getCallerPrincipal();
			
			ModifyCalendar modify = new ModifyCalendar();
			modify.modifyCalendar(property, pri.getName());
		} catch (NamingException e) {
			throw e;
		} catch (FinderException e) {
			m_log.debug("modifyCalendar() -> " + e.getMessage());
			throw e;
		}
	}
		
	/**
	 * カレンダ(基本）情報を 削除します。<BR>
	 * 
	 * 引数のIDに対応するカレンダー（基本）情報を削除します。
	 * 
	 * @ejb.interface-method
	 * 
	 * @ejb.permission
     *     role-name="CalendarWrite"
     *     method-intf="Remote"
	 * 
	 * @param id カレンダーID
	 * @throws FinderException 
	 * @throws RemoveException 
	 * @throws NamingException 
	 */
	public void deleteCalendar(String id) throws NamingException, RemoveException, FinderException  {
		try {
			ModifyCalendar modify = new ModifyCalendar();
			modify.deleteCalendar(id);
		} catch (NamingException e) {
			throw e;
		} catch (RemoveException e) {
			throw e;
		} catch (FinderException e) {
			m_log.debug("deleteCalendar() -> " + e.getMessage());
			throw e;
		}
	}
	
	/**
	 * カレンダ曜日別情報用プロパティを取得します。<BR>
	 * 
	 * 引数で指定したカレンダーIDのカレンダー（曜日別）情報を
	 * 取得します
	 * 
	 * @ejb.interface-method
	 * 
	 * @ejb.permission
     *     role-name="CalendarWrite"
     *     method-intf="Remote"
	 * 
	 * @jboss.method-attributes
	 *     read-only="true"
	 * 
	 * @param id
	 * @param mode
	 * @param local
	 * @return
	 * @throws FinderException
	 * @throws NamingException
	 * 
	 * @see com.clustercontrol.calendar.factory.WeekdayProperty
	 */
	public Property getWeekdayProperty(String id, Integer weekday, Date from, Date to, int mode, Locale locale) throws FinderException, NamingException {
		try {
			return new WeekdayProperty().getProperty(id, weekday, from, to, mode, locale);
		} catch (FinderException e) {
			m_log.debug("getWeekdayProperty() -> " + e.getMessage());
			throw e;
		} catch (NamingException e) {
			throw e;
		}
	}
	
	/**
	 * カレンダ曜日別情報を登録します。<BR>
	 * 
	 * 引数のプロパティの内容をマネージャに登録します。
	 * 
	 * @ejb.interface-method
	 * 
	 * @ejb.permission
     *     role-name="CalendarWrite"
     *     method-intf="Remote"
	 * 
	 * @param id
	 * @param property
	 * @throws FinderException 
	 * @throws CreateException 
	 * @throws NamingException 
	 * 
	 * @see com.clustercontrol.calendar.factory.WeekdayProperty
	 */
	public void addWeekday(String id, Property property) throws NamingException, CreateException, FinderException {
		try {
			Principal pri = m_context.getCallerPrincipal();
			
			ModifyCalendar modify = new ModifyCalendar();
			modify.addWeekday(id, property, pri.getName());
		} catch (NamingException e) {
			throw e;
		} catch (CreateException e) {
			throw e;
		} catch (FinderException e) {
			m_log.debug("addWeekday() -> " + e.getMessage());
			throw e;
		}
	}
	
	/**
	 * カレンダ曜日別情報を変更します。<BR>
	 * 
	 * @ejb.interface-method
	 * 
	 * @ejb.permission
     *     role-name="CalendarWrite"
     *     method-intf="Remote"
	 * 
	 * @param id
	 * @param weekday
	 * @param from
	 * @param to
	 * @param property
	 * @throws NamingException
	 * @throws FinderException
	 * @throws RemoveException
	 * @throws CreateException
	 * 
	 */
	public void modifyWeekday(String id, Integer weekday, Date from, Date to, Property property) throws NamingException, FinderException, RemoveException, CreateException {
		try {
			Principal pri = m_context.getCallerPrincipal();
			
			ModifyCalendar modify = new ModifyCalendar();
			modify.modifyWeekday(id, weekday, from, to, property, pri.getName());
		} catch (NamingException e) {
			throw e;
		} catch (RemoveException e) {
			throw e;
		} catch (CreateException e) {
			throw e;
		} catch (FinderException e) {
			m_log.debug("modifyWeekday() -> " + e.getMessage());
			throw e;
		}
	}
		
	/**
	 * カレンダ曜日別情報を削除します。
	 * 
	 * 
	 * @ejb.interface-method
	 * 
	 * @ejb.permission
     *     role-name="CalendarWrite"
     *     method-intf="Remote"
	 * 
	 * @param id カレンダーID
	 * @throws FinderException 
	 * @throws RemoveException 
	 * @throws NamingException 
	 */
	public void deleteWeekday(String id, Integer weekday, Date from, Date to) throws NamingException, RemoveException, FinderException  {
		try {
			ModifyCalendar modify = new ModifyCalendar();
			modify.deleteWeekday(id, weekday, from, to);
		} catch (NamingException e) {
			throw e;
		} catch (RemoveException e) {
			throw e;
		} catch (FinderException e) {
			m_log.debug("deleteWeekday() -> " + e.getMessage());
			throw e;
		}
	}
	
	/**
	 * カレンダ追加情報用プロパティを取得します。<BR>
	 * 
	 * 引数のカレンダーID、日時区間に対応するカレンダー（実行例外）情報を
	 * 取得します。
	 * 
	 * @ejb.interface-method
	 * 
	 * @ejb.permission
     *     role-name="CalendarWrite"
     *     method-intf="Remote"
	 * 
	 * @jboss.method-attributes
	 *     read-only="true"
	 * 
	 * @param id
	 * @param mode
	 * @param local
	 * @return
	 * @throws FinderException
	 * @throws NamingException
	 */
	public Property getAddInfoProperty(String id, Date from, Date to, int mode, Locale locale) throws FinderException, NamingException {
		try {
			return new AddProperty().getProperty(id, from, to, mode, locale);
		} catch (FinderException e) {
			m_log.debug("getAddInfoProperty() -> " + e.getMessage());
			throw e;
		} catch (NamingException e) {
			throw e;
		}
	}
	
	/**
	 * カレンダ追加情報を登録します。<BR>
	 * 
	 * idとプロパティの情報を元にカレンダー（実行例外）情報を
	 * マネージャに登録します。
	 * 
	 * @ejb.interface-method
	 * 
	 * @ejb.permission
     *     role-name="CalendarWrite"
     *     method-intf="Remote"
	 * 
	 * @param id
	 * @param property
	 * @throws FinderException 
	 * @throws CreateException 
	 * @throws NamingException 
	 * @see com.clustercontrol.calendar.factory.AddProperty
	 */
	public void addAddInfo(String id, Property property) throws NamingException, CreateException, FinderException {
		try {
			Principal pri = m_context.getCallerPrincipal();
			
			ModifyCalendar modify = new ModifyCalendar();
			modify.addAddInfo(id, property, pri.getName());
		} catch (NamingException e) {
			throw e;
		} catch (CreateException e) {
			throw e;
		} catch (FinderException e) {
			m_log.debug("addAddInfo() -> " + e.getMessage());
			throw e;
		}
	}
	
	/**
	 * カレンダ追加情報を変更します。<BR>
	 * 
	 * @ejb.interface-method
	 * 
	 * @ejb.permission
     *     role-name="CalendarWrite"
     *     method-intf="Remote"
	 * 
	 * @param id
	 * @param from
	 * @param to
	 * @param property
	 * @throws NamingException
	 * @throws FinderException
	 * @throws RemoveException
	 * @throws CreateException
	 * 
	 * @see com.clustercontrol.calendar.factory.AddProperty
	 */
	public void modifyAddInfo(String id, Date from, Date to, Property property) throws NamingException, FinderException, RemoveException, CreateException {
		try {
			Principal pri = m_context.getCallerPrincipal();
			
			ModifyCalendar modify = new ModifyCalendar();
			modify.modifyAddInfo(id, from, to, property, pri.getName());
		} catch (NamingException e) {
			throw e;
		} catch (RemoveException e) {
			throw e;
		} catch (CreateException e) {
			throw e;
		} catch (FinderException e) {
			m_log.debug("modifyAddInfo() -> " + e.getMessage());
			throw e;
		}
	}
		
	/**
	 * カレンダ追加情報を削除します。<BR
	 * 
	 * idで指定されたカレンダー（例外実行）情報を削除します。
	 * 
	 * @ejb.interface-method
	 * 
	 * @ejb.permission
     *     role-name="CalendarWrite"
     *     method-intf="Remote"
	 * 
	 * @param id
	 * @throws FinderException 
	 * @throws RemoveException 
	 * @throws NamingException 
	 */
	public void deleteAddInfo(String id, Date from, Date to) throws NamingException, RemoveException, FinderException  {
		try {
			ModifyCalendar modify = new ModifyCalendar();
			modify.deleteAddInfo(id, from, to);
		} catch (NamingException e) {
			throw e;
		} catch (RemoveException e) {
			throw e;
		} catch (FinderException e) {
			m_log.debug("deleteAddInfo() -> " + e.getMessage());
			throw e;
		}
	}
	
	/**
	 * カレンダが実行可能かチェックします。<BR>
	 * 
	 * 引数のカレンダーidが引数のタイムスタンプにおいて
	 * 実行可能であるかチェックします。
	 * 
	 * @ejb.interface-method
	 * 
	 * @ejb.transaction type="RequiresNew"
	 * 
	 * @ejb.permission
     *     role-name="CalendarRead"
     *     method-intf="Remote"
     *     
	 * @ejb.permission
     *     role-name="JobManagementRead"
     *     method-intf="Remote"
	 * 
	 * @jboss.method-attributes
	 *     read-only="true"
	 * 
	 * @param id
	 * @param checkTimestamp
	 * @return
	 * @throws NamingException
	 * @throws CalendarNotFountException 
	 */
	public Boolean isRun(String id, Date checkTimestamp) throws NamingException, CalendarNotFountException {
		try {
			SelectCalendar select = new SelectCalendar();
			return select.isRun(id, checkTimestamp);
		} catch (CalendarNotFountException e) {
			m_log.debug("isRun() -> " + e.getMessage());
			throw e;
		} catch (NamingException e) {
			throw e;
		}
	}
	
	/**
	 * カレンダIDのリストを取得します。
	 * 
	 * 引数のArrayListにはカレンダーidが含まれています。
	 * <p>
	 *	list.add(cal.getCalendar_id());
	 * </p>
	 * 
	 * @ejb.interface-method
	 * 
	 * @ejb.permission
     *     unchecked="true"
     *     method-intf="Remote"
	 * 
	 * @jboss.method-attributes
	 *     read-only="true"
	 * 
	 * @param id
	 * @param checkTimestamp
	 * @throws NamingException
	 * @throws CalendarNotFountException 
	 */
	public ArrayList<String> getCalendarIdList() throws NamingException, CalendarNotFountException {
		ArrayList<String> list = null;
		try {
			SelectCalendar select = new SelectCalendar();
			list = select.getCalendarIdList();
		} catch (CalendarNotFountException e) {
			m_log.debug("getCalendarIdList() -> " + e.getMessage());
			throw e;
		} catch (NamingException e) {
			throw e;
		}
		return list;
	}
}

