/*
 
 Copyright (C) 2006 NTT DATA Corporation
 
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License 
 as published by the Free Software Foundation, version 2.
 
 This program is distributed in the hope that it will be
 useful, but WITHOUT ANY WARRANTY; without even the implied 
 warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
 PURPOSE.  See the GNU General Public License for more details.
 
 */

package com.clustercontrol.http.factory;

import java.util.Date;

import javax.ejb.CreateException;
import javax.ejb.FinderException;
import javax.ejb.RemoveException;
import javax.jms.JMSException;
import javax.naming.NamingException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.bean.YesNoConstant;
import com.clustercontrol.http.ejb.entity.MonitorHttpInfoLocal;
import com.clustercontrol.http.ejb.entity.MonitorHttpInfoPK;
import com.clustercontrol.http.ejb.entity.MonitorHttpInfoUtil;
import com.clustercontrol.http.util.GetHttpResponse;
import com.clustercontrol.monitor.run.factory.RunMonitor;
import com.clustercontrol.monitor.run.factory.RunMonitorStringValueType;
import com.clustercontrol.util.Messages;

/**
 * HTTP監視 文字列監視を実行するクラス<BR>
 *
 * @version 2.1.0
 * @since 2.1.0
 */
public class RunMonitorHttpString extends RunMonitorStringValueType {
	
	protected static Log m_log = LogFactory.getLog( RunMonitorHttpString.class );
	
	public static final String MESSAGE_ID_UNKNOWN = "100";
	
//	/** ノード ネットワーク情報 */
//	protected static final ArrayList<String> m_attributeList = new ArrayList<String>();
//	static{
//		m_attributeList.add(FacilityAttributeConstant.IPNETWORKNUMBER);
//		m_attributeList.add(FacilityAttributeConstant.IPNETWORKNUMBERV6);
//	}
	
	/** HTTP監視情報 */
	protected MonitorHttpInfoLocal m_http = null;
	
	/** URL */
	protected String m_requestUrl = null;
	
	/** タイムアウト */
	protected int m_httpTimeout;
	
	/** URL置換 */
	protected int m_urlReplace = YesNoConstant.TYPE_NO;
	
	/** プロキシ設定 */
	protected int m_proxySet = YesNoConstant.TYPE_NO;
	
	/** プロキシ ホスト */
	protected String m_proxyHost;
	
	/** プロキシ ポート */
	protected int m_proxyPort;
	
	/** 不明メッセージ */
	protected String m_unKnownMessage = null;
	
	/** オリジナルメッセージ */
	protected String m_messageOrg = null;
	
	/**
	 * コンストラクタ
	 * 
	 */
	public RunMonitorHttpString() throws NamingException, JMSException, CreateException{
		super();
	}
	
	/**
	 * マルチスレッドを実現するCallableTaskに渡すためのインスタンスを作成するメソッド
	 * 
	 * @see com.clustercontrol.monitor.run.factory.RunMonitor#runMonitorInfo()
	 * @see com.clustercontrol.monitor.run.util.CallableTask
	 */
	@Override
	public RunMonitor createMonitorInstance() throws NamingException, JMSException, CreateException{
		return new RunMonitorHttpString();
	}
	
	/* (非 Javadoc)
	 * @see com.clustercontrol.monitor.run.factory.RunMonitor#runMonitorInfo()
	 */
	@Override
	public boolean runMonitorInfo() throws FinderException, RemoveException, JMSException, NamingException, CreateException {
		
		// 監視チェック情報を設定
		setCheckInfo();
		
		if(m_urlReplace == YesNoConstant.TYPE_YES){
			return super.runMonitorInfo();
		}
		else{
			m_now = new Date();
			
			try 
			{
				// 監視基本情報を設定
				boolean run = this.setMonitorInfo(m_monitorTypeId, m_monitorId);
				if(!run){
					// 処理終了
					return true;
				}
				
				// 判定情報を設定
				setJudgementInfo();
				
				// 監視値を収集
				boolean ret = collect(null);
				
				// 監視値より判定結果を取得
				int checkResult = getCheckResult(ret);
				
				// 監視管理へ通知
				notify(true, m_facilityId, checkResult, new Date(m_nodeDate));
				
				return true;
				
			} catch (FinderException e) {
				m_log.error("runMonitorInfo(): monitorTypeId:" + m_monitorTypeId + ",monitorId:" + m_monitorId  + ", " + e.getMessage());
				throw e;
			} catch (CreateException e) {
				m_log.error("runMonitorInfo(): monitorTypeId:" + m_monitorTypeId + ",monitorId:" + m_monitorId  + ", " + e.getMessage());
				throw e;
			} catch (JMSException e) {
				m_log.error("runMonitorInfo(): monitorTypeId:" + m_monitorTypeId + ",monitorId:" + m_monitorId  + ", " + e.getMessage());
				throw e;
			} catch (NamingException e) {
				m_log.error("runMonitorInfo(): monitorTypeId:" + m_monitorTypeId + ",monitorId:" + m_monitorId  + ", " + e.getMessage());
				throw e;
			}
		}
	}
	
	/**
	 * HTTP数を取得
	 * 
	 * @param facilityId ファシリティID
	 * @return 値取得に成功した場合、true
	 */
	@Override
	public boolean collect(String facilityId) {
		
		m_nodeDate = m_now.getTime();
		m_value = null;
		m_unKnownMessage = "";
		m_messageOrg = "";
		
		GetHttpResponse m_request = new GetHttpResponse();
		
//		String url = null;
//		if(m_urlReplace == YesNoConstant.TYPE_YES){
//			
//			String ipNetworkNumber = null; 
//			try{
//				// ノードの属性取得
//				HashMap facilityAttrMap = m_repository.getNodeDetail(facilityId, m_attributeList);
//				ipNetworkNumber = (String)facilityAttrMap.get(FacilityAttributeConstant.IPNETWORKNUMBER);
//				
//				// URL置換
//				if(ipNetworkNumber != null && !"".equals(ipNetworkNumber)){
//					
//					url = m_requestUrl.replaceAll("(http://|https://)([^/:]+)(([:/](([^\\s]+)|$))|$)","$1" + ipNetworkNumber + "$3");
//					m_log.debug("collect(): URL = " + url);
//				}
//				else{
//					String[] args = { facilityId };
//					m_unKnownMessage = Messages.getString("message.http.4", args);
//					return false;
//				}
//			}
//			catch(FinderException e){
//				m_log.debug("collect():" + e.getMessage());
//				
//				String[] args = { facilityId };
//				m_unKnownMessage = Messages.getString("message.http.4", args);
//				m_messageOrg = e.getMessage();
//				return false;
//			}
//			catch(NamingException e){
//				m_log.debug("collect():" + e.getMessage());
//				
//				String[] args = { facilityId };
//				m_unKnownMessage = Messages.getString("message.http.4", args);
//				m_messageOrg = e.getMessage();
//				return false;
//			}
//		}
//		else{
//			// URL固定
//			url = m_requestUrl;
//		}
		
		String url = m_requestUrl;
		boolean result = m_request.execute(url, m_httpTimeout*1000);
		
		if(result){
			m_value = m_request.getResponseBody();
			
			StringBuffer response = new StringBuffer();
			response.append(Messages.getString("status.code") + " : " + m_request.getStatusCode());
			if(m_request.getHeader() != null && !"".equals(m_request.getHeader().trim())){
				response.append("\n" + Messages.getString("header") + " :\n" + m_request.getHeader().trim());
			}
			if(m_request.getResponseBody() != null && !"".equals(m_request.getResponseBody().trim())){
				response.append("\n" + Messages.getString("response.body") + " :\n" + m_request.getResponseBody().trim());
			}
			m_messageOrg = response.toString();
		}
		else{
			m_unKnownMessage = Messages.getString("message.http.3");
			
			StringBuffer response = new StringBuffer();
			response.append(m_request.getErrorMessage());
			response.append("\n" + Messages.getString("status.code") + " :\n" + m_request.getStatusCode());
			if(m_request.getHeader() != null && !"".equals(m_request.getHeader().trim())){
				response.append("\n" + Messages.getString("header") + " :\n" + m_request.getHeader().trim());
			}
			m_messageOrg = response.toString();
		}
		return result;
	}
	
	/* (non-Javadoc)
	 * HTTP監視情報を設定
	 * @see com.clustercontrol.monitor.run.factory.OperationNumericValueInfo#setMonitorAdditionInfo()
	 */
	@Override
	public void setCheckInfo() throws FinderException, NamingException{
		
		if(m_http == null){
			// HTTP監視情報を取得
			MonitorHttpInfoPK pk = new MonitorHttpInfoPK(m_monitorId, m_monitorTypeId);
			m_http = MonitorHttpInfoUtil.getLocalHome().findByPrimaryKey(pk);
			
			// HTTP監視情報を設定
			m_requestUrl = m_http.getRequestUrl().trim();
			m_httpTimeout = m_http.getTimeout().intValue();
			m_urlReplace = m_http.getUrlReplace().intValue();
			m_proxySet = m_http.getProxySet().intValue();
			if(m_http.getProxyHost() != null){
				m_proxyHost = m_http.getProxyHost().trim();
			}
			m_proxyPort = m_http.getProxyPort().intValue();
		}
	}
	
	/* (非 Javadoc)
	 * ノード用メッセージIDを取得
	 * @see com.clustercontrol.monitor.run.factory.RunMonitor#getMessageId(int)
	 */
	@Override
	public String getMessageId(int id) {
		
		String messageId = super.getMessageId(id);
		if(messageId == null || "".equals(messageId)){
			return MESSAGE_ID_UNKNOWN;
		}
		return messageId;
	}
	
	/* (非 Javadoc)
	 * ノード用メッセージを取得
	 * @see com.clustercontrol.monitor.run.factory.RunMonitor#getMessage(int)
	 */
	@Override
	public String getMessage(int id) {
		
		String message = super.getMessage(id);
		if(message == null || "".equals(message)){
			return m_unKnownMessage;
		}
		return message;
	}
	
	/* (非 Javadoc)
	 * ノード用オリジナルメッセージを取得
	 * @see com.clustercontrol.monitor.run.factory.RunMonitor#getMessageOrg(int)
	 */
	@Override
	public String getMessageOrg(int id) {
		return m_messageOrg;
	}
}