/*
 
 Copyright (C) 2006 NTT DATA Corporation
 
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License 
 as published by the Free Software Foundation, version 2.
 
 This program is distributed in the hope that it will be
 useful, but WITHOUT ANY WARRANTY; without even the implied 
 warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
 PURPOSE.  See the GNU General Public License for more details.
 
 */

package com.clustercontrol.logtransfer.util;

import java.util.ArrayList;

import javax.jms.JMSException;
import javax.jms.ObjectMessage;
import javax.jms.TopicPublisher;
import javax.naming.NamingException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.commons.util.CommonSendTopic;
import com.clustercontrol.logtransfer.bean.LogTransferFileInfo;
import com.clustercontrol.util.Dummy;

/**
 * ファイルリストをログ転送エージェントに送信するクラス<BR>
 *
 * @version 2.1.0
 * @since 2.1.0
 */
public class SendTopic extends CommonSendTopic{
	protected static Log m_log = LogFactory.getLog( SendTopic.class );
	
	/**
	 * コンストラクタ
	 * 
	 * @param topicName
	 * @throws NamingException
	 * @throws JMSException
	 */
	public SendTopic(String topicName) throws NamingException, JMSException{
        super(topicName);
	}
	
	/**
	 * メッセージを送信します。
	 * 
	 * @param faciligyId
	 * @param fileInfoList
	 * @param initFlg
	 * @throws JMSException
	 */
	public void put(String facilityId, ArrayList<LogTransferFileInfo> fileInfoList, boolean initFlg) throws JMSException {
		TopicPublisher publisher = null;
		try{
			publisher = m_session.createPublisher(m_topic);
			
			// 送信メッセージ作成
			ObjectMessage message = m_session.createObjectMessage(fileInfoList);
			message.setStringProperty("FacilityId", facilityId);
			message.setBooleanProperty("Init", initFlg);
			
			// メッセージ送信
			publisher.publish(message);
			m_log.debug("put() topic: FacilityId = " + facilityId);
		}
		catch(JMSException e){
			throw e;
		}
		finally{
			try {
				if (publisher != null)
					publisher.close();
			}
			catch (JMSException e) {
			}
		}
	}

	/**
	 * メッセージを送信します。
	 * 
	 * @param faciligyId
	 * @param dummy
	 * @param initFlg
	 * @throws JMSException
	 */
	public void put(String facilityId, Dummy dummy, boolean initFlg) throws JMSException {
		TopicPublisher publisher = null;
		try{
			publisher = m_session.createPublisher(m_topic);
			
			// 送信メッセージ作成
			ObjectMessage message = m_session.createObjectMessage(dummy);
			message.setStringProperty("FacilityId", facilityId);
			message.setStringProperty("Agent", "log");
			message.setBooleanProperty("Init", initFlg);
			
			// メッセージ送信
			publisher.publish(message);
			m_log.debug("put() topic: FacilityId = " + facilityId);
		}
		catch(JMSException e){
			throw e;
		}
		finally{
			try {
				if (publisher != null)
					publisher.close();
			}
			catch (JMSException e) {
			}
		}
	}
}