/*
 
Copyright (C) 2007 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.maintenance.factory;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;

import javax.ejb.CreateException;
import javax.ejb.FinderException;
import javax.naming.NamingException;

import com.clustercontrol.maintenance.ejb.entity.MaintenanceTypeMstLocal;
import com.clustercontrol.maintenance.ejb.entity.MaintenanceTypeMstUtil;

/**
 * 
 * メンテナンス種別に関する情報を検索するためのクラスです。
 * 
 * @since	2.2.0
 * @version	2.2.0
 *
 */
public class SelectMaintenanceTypeMst {
	
	/**
	 * メンテナンス種別名IDを取得する
	 * @param type_id
	 * @return
	 * @throws FinderException
	 * @throws NamingException
	 */
	public String getMaintenanceTypeNameId(String type_id) throws FinderException,NamingException{
		
		MaintenanceTypeMstLocal mst = MaintenanceTypeMstUtil.getLocalHome().findByPrimaryKey(type_id);
		
		return mst.getName_id();
	}
	
	/**
	 * メンテナンス種別一覧を取得する
	 * @return
	 * @throws FinderException
	 * @throws NamingException
	 * @throws CreateException
	 */
	public ArrayList getMaintenanceTypeMst() throws FinderException, NamingException, CreateException {
		
		// メンテナンス種別マスタ一覧を取得
		Collection ct = MaintenanceTypeMstUtil.getLocalHome().findAll();
		
		// 2次元配列に変換
		ArrayList list = this.collectionToArray(ct);
		
		return list;
	}
	
	/**
	 * メンテナンス一覧をObjectの2次元配列に格納
	 * 
	 * @param ct
	 * @return Objectの2次元配列
	 */
	@SuppressWarnings("unchecked")
	private ArrayList collectionToArray(Collection ct) throws CreateException, FinderException, NamingException{
		
		ArrayList list = new ArrayList();
		Iterator itr = ct.iterator();
		while(itr.hasNext())
		{
			MaintenanceTypeMstLocal mst = (MaintenanceTypeMstLocal)itr.next();
			
			ArrayList info = new ArrayList();
			info.add(mst.getType_id());
			info.add(mst.getName_id());
			info.add(mst.getOrder_no());
			list.add(info);
		}
		return list;
	}
	
}
