/*
 
 Copyright (C) 2006 NTT DATA Corporation
 
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License 
 as published by the Free Software Foundation, version 2.
 
 This program is distributed in the hope that it will be
 useful, but WITHOUT ANY WARRANTY; without even the implied 
 warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
 PURPOSE.  See the GNU General Public License for more details.
 
 */

package com.clustercontrol.notify.ejb.mdb;

import java.rmi.RemoteException;

import javax.ejb.CreateException;
import javax.ejb.EJBException;
import javax.ejb.FinderException;
import javax.jms.JMSException;
import javax.jms.ObjectMessage;
import javax.naming.NamingException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.notify.bean.NotifyRequestMessage;
import com.clustercontrol.notify.util.NotifyExecutor;
import com.clustercontrol.notify.util.SendSyslog;

/**
 * ログエスカレーションを行う Message-Driven Bean <BR>
 *
 * <!-- begin-xdoclet-definition -->
 * @ejb.bean name="NotifyLogEscalationBean" 
 *     acknowledge-mode="Auto-acknowledge"
 *     destination-type="javax.jms.Queue"
 *     
 *     transaction-type="Container"
 *     destination-jndi-name="queue/clustercontrolNotifyLogEscalation"
 * 
 * @jboss.depends name="user:service=HinemosService,name=HinemosService"
 * 
 * @jboss.container-configuration
 *  name="Hinemos Notification Message Driven Bean"
 * 
 *--
 * Server Runtime Specific Tags
 * If you are not using a specific runtime, you can safely remove the tags below.
 * @jonas.message-driven-destination jndi-name="queue/clustercontrolNotifyLogEscalation"
 * @jboss.destination-jndi-name name="queue/clustercontrolNotifyLogEscalation"
 *
 *--
 * <!-- end-xdoclet-definition -->
 **/
public class NotifyLogEscalationBean implements javax.ejb.MessageDrivenBean, javax.jms.MessageListener {
	
	/** ログ出力のインスタンス。 */
	protected static Log m_log = LogFactory.getLog( NotifyLogEscalationBean.class );
	
	/** syslog送信 */
	private static SendSyslog m_sender = new SendSyslog();
	
	/** コンテキスト情報 */
	private javax.ejb.MessageDrivenContext messageContext = null;
	
	/**
	 * コンテキスト情報を設定します。<BR>
	 * Message-Driven Bean がインスタンスプールに格納される際に行う処理を実装します。
	 * @see javax.ejb.MessageDrivenBean#setMessageDrivenContext(javax.ejb.MessageDrivenContext)
	 */
	public void setMessageDrivenContext(
			javax.ejb.MessageDrivenContext messageContext)
	throws javax.ejb.EJBException {
		this.messageContext = messageContext;
	}
	
	/** 
	 * Message-Driven Bean が生成される際に行う処理を実装します。
	 * @ejb.create-method 
	 */
	public void ejbCreate() {
		//no specific action required for message-driven beans 
	}
	
	/** 
	 * Message-Driven Bean が削除される際に行う処理を実装します。
	 * @see javax.ejb.MessageDrivenBean#ejbRemove()
	 */
	public void ejbRemove() {
		messageContext = null;
	}
	
	/** 
	 * 引数で指定された受信メッセージを元に、ログエスカレーションをおこないます。<BR>
	 * Message-Driven Bean で行うビジネスロジックを実装します。
	 * 特定のメッセージを受信した場合のみ処理を行います。受信メッセージは下記の通りです。
	 * 
	 * <p><li>{@link com.clustercontrol.notify.message.OutputNotifyGroupInfo} : 
	 *
	 * @see javax.jms.MessageListener#onMessage(javax.jms.Message)
	 * 
	 * @see com.clustercontrol.noitfy.util.SendSyslog#sendSyslog(OutputNotifyGroupInfo)
	 * @see com.clustercontrol.notify.message.OutputNotifyGroupInfo
	 */
	@SuppressWarnings("unchecked")
	public void onMessage(javax.jms.Message message) {
		m_log.debug("Message Driven Bean got message " + message);

		if(message instanceof ObjectMessage) {
			ObjectMessage msg = (ObjectMessage)message;
			
			try {
				Object objMsg = msg.getObject();
				if(objMsg instanceof NotifyRequestMessage) {
					NotifyRequestMessage requestMessage = (NotifyRequestMessage)objMsg;
					NotifyExecutor.execNotify(m_sender, requestMessage);
				}
				else {
					m_log.debug("onMessage(): ObjectMessage is not an expected instance. " + objMsg.toString());
				}
			}
			catch(JMSException e) {
				m_log.error("onMessage():" + e.getMessage(), e);
			}
			catch(EJBException e) {
				m_log.error("onMessage():" + e.getMessage(), e);
			} 
			catch(RemoteException e) {
				m_log.error("onMessage():" + e.getMessage(), e);
			} 
			catch(NamingException e) {
				m_log.error("onMessage():" + e.getMessage(), e);
			} 
			catch(CreateException e) {
				m_log.error("onMessage():" + e.getMessage(), e);
			} 
			catch(FinderException e) {
				m_log.error("onMessage():" + e.getMessage(), e);
			}
			catch (Exception e) {
				m_log.error("onMessage():" + e.getMessage(), e);
			}
		}
	}
}