/*
 
 Copyright (C) 2008 NTT DATA Corporation
 
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License 
 as published by the Free Software Foundation, version 2.
 
 This program is distributed in the hope that it will be
 useful, but WITHOUT ANY WARRANTY; without even the implied 
 warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
 PURPOSE.  See the GNU General Public License for more details.
 
 */

package com.clustercontrol.snmptrap.factory;

import javax.ejb.CreateException;
import javax.ejb.FinderException;
import javax.naming.NamingException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.MonitorNotFoundException;
import com.clustercontrol.snmptrap.ejb.entity.SnmpTrapMibMasterData;
import com.clustercontrol.snmptrap.ejb.entity.SnmpTrapMibMasterLocal;
import com.clustercontrol.snmptrap.ejb.entity.SnmpTrapMibMasterPK;
import com.clustercontrol.snmptrap.ejb.entity.SnmpTrapMibMasterUtil;
import com.clustercontrol.util.apllog.AplLogger;

/**
 * MIBマスター情報検索クラス
 *
 * @version 3.0.0
 * @since 2.4.0
 * @author Yosuke
 */
public class SelectMibMaster {
	
	protected static Log m_log = LogFactory.getLog( SelectMibMaster.class );
	
   /**
    * MIBマスターの詳細情報を取得します。
    * 
    * @param mib マスター情報がほしいMIB
    * @return　MIBマスターの詳細情報
    * @throws NamingException
 * @throws MonitorNotFoundException 
    * @throws CreateException
    */
	public SnmpTrapMibMasterData getMibMasterData(String mib) throws NamingException, MonitorNotFoundException {
		
		SnmpTrapMibMasterData mibData = new SnmpTrapMibMasterData();
	
		try 
		{
			SnmpTrapMibMasterLocal mibMaster =  SnmpTrapMibMasterUtil.getLocalHome()
            .findByPrimaryKey(new SnmpTrapMibMasterPK(mib));

			mibData.setMib(mib);
			mibData.setOrderNo(mibMaster.getOrderNo());
			mibData.setRegDate(mibMaster.getRegDate());
			mibData.setUpdateDate(mibMaster.getUpdateDate());
			mibData.setRegUser(mibMaster.getRegUser());
			mibData.setUpdateUser(mibMaster.getUpdateUser());
			mibData.setDescription(mibMaster.getDescription());
			
	
		} catch (FinderException e) {
			AplLogger apllog = new AplLogger("TRAP", "trap");
			String[] args = null;
			apllog.put("SYS", "004", args);
			m_log.debug("getMibMasterData():" + e.getMessage());
			throw new MonitorNotFoundException(e.getMessage(), e);
		} catch (NamingException e) {
			AplLogger apllog = new AplLogger("TRAP", "trap");
			String[] args = null;
			apllog.put("SYS", "004", args);
			m_log.debug("getMibMasterData():" + e.getMessage());
			throw e;
		}
		
		return mibData;
	}
}
