/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.agent.util;

import java.util.Properties;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.jnp.interfaces.NamingContext;

import com.clustercontrol.repository.ejb.session.RepositoryController;
import com.clustercontrol.repository.ejb.session.RepositoryControllerHome;


/**
 * EJBとのコネクションを管理するクラス<BR>
 * 
 * 
 * エージェントはリポジトリ情報を定期的に取得します。
 * そのRepositoryController　EJBを呼び出すためのヘルパー
 * 
 * @version $Revision:2230 $
 * @since 1.0.0
 */
public class EjbConnectionManager {
    
	private NamingContext m_con = null;

	//ロガー
	static private Log log = LogFactory.getLog(EjbConnectionManager.class);

	/**
	 * コンストラクタ
	 * @param prop　プロパティファイル情報
	 */
	public EjbConnectionManager() {
	}
	
	/**
	 * RepositoryCollectorを取得します。
	 * @return　RepositoryCollector
	 */
	public synchronized RepositoryController getRepositoryController() throws Exception {

		try {
			if(m_con != null)
				LoginManager.getContextManager(AgentProperties.getProperties()).logout();
			m_con = LoginManager.getContextManager(AgentProperties.getProperties()).getNamingContext();
			
			RepositoryControllerHome home = (RepositoryControllerHome) m_con
		    	.lookup(RepositoryControllerHome.JNDI_NAME);
			return home.create();
		} catch (Exception e) {
			log.error(e);
			LoginManager.getContextManager(AgentProperties.getProperties()).logout();
			m_con = null;
			throw e;
		}
	}
}
